/*<TOAD_FILE_CHUNK>*/

/*******************************************************************************
 Package zum Lesen und Auswerten des Eingangskorbs
 Daten zu einem Protokolleintrag werden komplett zur Verfgung gestellt
*******************************************************************************/

-- Workaround fr Oracle 10 
-- von der DB angelegte Typen lschen
BEGIN
  -- nur fr Versionen vor Oracle 11
  $IF DBMS_DB_VERSION.VER_LE_11 $THEN 
    
    -- Nummer des Packages
    FOR c1 IN (
      SELECT object_id 
      FROM user_objects
      WHERE object_name = 'BLV_EIN'
      AND object_type = 'PACKAGE'
    ) LOOP
      -- Typen des Packages lschen
      FOR c2 IN (
        SELECT type_name
        FROM user_types
        WHERE type_name LIKE 'SYS_PLSQL_' || c1.object_id || '%'
        AND typecode IN( 'OBJECT', 'COLLECTION')
        ORDER BY typecode
      ) LOOP
        BEGIN
          --DBMS_OUTPUT.PUT_LINE( c2.type_BEZEICHNUNG );
          EXECUTE IMMEDIATE 'DROP TYPE ' || c2.type_name;
          EXCEPTION WHEN OTHERS THEN NULL;
        END;      
      END LOOP;
    END LOOP;
    -- Package lschen
    FOR c1 IN (
      SELECT object_name
      FROM user_objects
      WHERE object_name = 'BLV_EIN'
      AND object_type = 'PACKAGE'
    ) LOOP
      EXECUTE IMMEDIATE 'DROP PACKAGE ' || c1.object_name;
    END LOOP;  
  $ELSE
    NULL;
  $END  
END;
/

ALTER SESSION SET PLSQL_CODE_TYPE = NATIVE;
/

ALTER SESSION SET PLSQL_OPTIMIZE_LEVEL = 3;
/

/**
  alter session set plsql_warnings = 'Enable:All', 'Disable:(6002, 6006)'
  alter session set plsql_warnings = 'Disable:All'
**/

/*<TOAD_FILE_CHUNK>*/
CREATE OR REPLACE PACKAGE BLV_EIN AS
   
  TYPE tParams IS RECORD ( CODE VARCHAR2(30 CHAR), WERT VARCHAR2(50 CHAR));
  TYPE tbParams IS TABLE OF tParams;

  TYPE tAdr IS RECORD ( --adr D_ADRESSE%ROWTYPE), 
    id D_ADRESSE.ID%TYPE, 
    FreiText D_ADRESSE.FreiText%TYPE,
    Postbezeichnung D_ADRESSE.Postbezeichnung%TYPE, 
    WECHSELNDER_STANDORT D_ADRESSE.WECHSELNDER_STANDORT%TYPE, 
    gueltig_von D_ADRESSE.gueltig_von%TYPE, 
    gueltig_bis D_ADRESSE.gueltig_bis%TYPE, 
    TYP D_ADRESSE.TYP%TYPE, 
    ADRESSZUSATZ D_ADRESSE.ADRESSZUSATZ%TYPE, 
    --typ D_ADRESSE.TYPE%TYPE, 
    --bundesland D_ADRESSE.BUNDESLAND%TYPE, 
    --bezirk D_ADRESSE.BEZIRK%TYPE, 
    --kreis D_ADRESSE.KREIS%TYPE, 
    GEMEINDE D_ADRESSE.GEMEINDE%TYPE, 
    --fkz D_ADRESSE.GKZ%TYPE, 
    REGIONALSCHLUESSEL D_ADRESSE.REGIONALSCHLUESSEL%TYPE, 
    STRASSE D_ADRESSE.STRASSE%TYPE, 
    Hausnummer D_ADRESSE.Hausnummer%TYPE, 
    Hausnummernzusatz D_ADRESSE.Hausnummernzusatz%TYPE, 
    Postfach D_ADRESSE.Postfach%TYPE, 
    Staat D_ADRESSE.Staat%TYPE, 
    PLZ D_ADRESSE.PLZ%TYPE, 
    Ort D_ADRESSE.Ort%TYPE, 
    Ortsteil D_ADRESSE.Ortsteil%TYPE, 
    Teilort D_ADRESSE.Teilort%TYPE, 
    Flurnummer D_ADRESSE.Flurnummer%TYPE, 
    Flurstueck D_ADRESSE.Flurstueck%TYPE, 
    Gemarkung D_ADRESSE.Gemarkung%TYPE, 
    X_Wert D_ADRESSE.X_Wert%TYPE, 
    Y_Wert D_ADRESSE.Y_Wert%TYPE, 
    Rechtswert D_ADRESSE.Rechtswert%TYPE, 
    Hochwert D_ADRESSE.Hochwert%TYPE, 
    Koordinatenherkunft D_ADRESSE.Koordinatenherkunft%TYPE, 
    s09_sid D_ADRESSE.S09_SID%TYPE, 
    ins_date D_ADRESSE.INS_DATE%TYPE, 
    glo_a24_sid D_ADRESSE.GLO_A24_SID%TYPE,
    gkz D_ADRESSE.gkz%TYPE );

  TYPE tbAdr IS TABLE OF tAdr;
  
  TYPE tbABT IS TABLE OF d_abteilung%ROWTYPE;  
  
  TYPE tReg IS RECORD ( 
    ID          D_REGISTRIERUNG.ID%TYPE, 
    PRS_ID      D_REGISTRIERUNG.PRS_ID%TYPE, 
    BTS_ID      D_REGISTRIERUNG.BTS_ID%TYPE, 
    TYP         D_REGISTRIERUNG.TYP%TYPE,
    CODE        D_REGISTRIERUNG.CODE%TYPE,
    NUMMER      D_REGISTRIERUNG.NUMMER%TYPE,
    ZUSATZ      D_REGISTRIERUNG.ZUSATZ%TYPE,
    GUELTIG_VON D_REGISTRIERUNG.GUELTIG_VON%TYPE,
    GUELTIG_BIS D_REGISTRIERUNG.GUELTIG_BIS%TYPE,
    REF_ID      D_REGISTRIERUNG.REF_ID%TYPE,
    INS_DATE    D_REGISTRIERUNG.INS_DATE%TYPE
  );
  
  TYPE tbReg IS TABLE OF tReg;  
  
  TYPE tBar IS RECORD (
  ID                 d_betriebsart.ID%TYPE, 
  BTS_ID             d_betriebsart.BTS_ID%TYPE, 
  TYP                d_betriebsart.TYP%TYPE, 
  CODE               d_betriebsart.CODE%TYPE, 
  BEZEICHNUNG        d_betriebsart.BEZEICHNUNG%TYPE, 
  FB                 d_betriebsart.FB%TYPE, 
  GUELTIG_VON        d_betriebsart.GUELTIG_VON%TYPE, 
  GUELTIG_BIS        d_betriebsart.GUELTIG_BIS%TYPE, 
  D010101_ID         d_betriebsart.D010101_ID%TYPE, 
  GELTUNGSBEREICH    d_betriebsart.GELTUNGSBEREICH%TYPE, 
  GEWERBSMAESSIG_JN  d_betriebsart.GEWERBSMAESSIG_JN%TYPE, 
  INS_DATE           d_betriebsart.INS_DATE%TYPE, 
  ADR_STO_ID         d_betriebsart.ADR_STO_ID%TYPE       
  );
  
  TYPE tbBar IS TABLE OF tBar;
 
  TYPE tUSC IS RECORD (
    ID d_usecase.ID%TYPE,
    BTS_ID d_usecase.BTS_ID%TYPE,
    usecase d_usecase.usecase%TYPE,
    MANDANT d_usecase.MANDANT%TYPE,
    user_name d_usecase.user_name%TYPE,
    USER_SID  d_usecase.USER_SID%TYPE,
    typ  d_usecase.typ%TYPE,
    Aenderungsgrund  d_usecase.Aenderungsgrund%TYPE,
    Bemerkung  d_usecase.Bemerkung%TYPE,
    FB d_usecase.FB%TYPE,
    ZB d_usecase.ZB%TYPE,
    Alter_Wert d_usecase.Alter_Wert%TYPE,
    Neuer_Wert d_usecase.Neuer_Wert%TYPE,
    D0101_ID d_usecase.d0101_id%TYPE,
    gueltig_von d_usecase.gueltig_von%TYPE,
    gueltig_bis d_usecase.gueltig_bis%TYPE,    
    A0101_501_SID d_usecase.A0101_501_SID%TYPE
    );
      
  TYPE tbUSC IS TABLE OF tUSC;                              
  
  TYPE tbD_Personal IS TABLE OF d_personal%ROWTYPE;

  TYPE tFnc IS RECORD( 
    Fkt      d_personalfunktion%ROWTYPE,    
    Pers     d_personal%ROWTYPE,
    Adr_Pst  tAdr,  -- Postadresse
    Adr_Sto  tAdr,  -- Standortadresse 
    Reg      tbReg , 
    Personal tbD_Personal
    );

  TYPE tFAB IS RECORD ( 
     ID           d_fachbereich.ID%TYPE, 
     BTS_ID       d_fachbereich.BTS_ID%TYPE, 
     CODE         d_fachbereich.CODE%TYPE,
     A0101_06_SID d_fachbereich.A0101_06_SID%TYPE,
     gueltig_von  d_fachbereich.gueltig_von%TYPE,
     gueltig_bis  d_fachbereich.gueltig_bis%TYPE,
     D010104_ID   d_fachbereich.D010104_ID%TYPE,
     A0115_SID    d_fachbereich.A0115_SID%TYPE,
     A0101_01_SID d_fachbereich.A0101_01_SID%TYPE,
     ERSTKONTROLLTERMIN d_fachbereich.ERSTKONTROLLTERMIN%TYPE,
     INS_DATE     d_fachbereich.ins_date%TYPE );

  TYPE tbFAB IS TABLE OF tFAB; 
  
  TYPE tBTS IS RECORD( 
    ID D_BETRIEBSSTAETTE.id%TYPE,
    BEZEICHNUNG D_BETRIEBSSTAETTE.BEZEICHNUNG%TYPE,
    gueltig_von D_BETRIEBSSTAETTE.gueltig_von%TYPE,
    gueltig_bis D_BETRIEBSSTAETTE.gueltig_bis%TYPE,
    D0101_ID D_BETRIEBSSTAETTE.d0101_id%TYPE,
    ZB D_BETRIEBSSTAETTE.zb%TYPE,
    KENNZEICHEN D_BETRIEBSSTAETTE.KENNZEICHEN%TYPE,
    INS_DATE D_BETRIEBSSTAETTE.ins_date%TYPE,
    BEMERKUNG d_betriebsstaette.bemerkung%TYPE, -- 26.06.2014
    Telefon D_BETRIEBSSTAETTE.Telefon%TYPE, 
    FAX D_BETRIEBSSTAETTE.fax%TYPE, 
    Mobil  D_BETRIEBSSTAETTE.Mobil%TYPE, 
    EMAIL  D_BETRIEBSSTAETTE.email%TYPE,
    weitere D_BETRIEBSSTAETTE.weitere%TYPE,
    Internet D_BETRIEBSSTAETTE.Internet%TYPE,

    Adr_Pst_ID D_BETRIEBSSTAETTE.Adr_Pst_id%TYPE,
    Adr_Sto_ID D_BETRIEBSSTAETTE.Adr_Sto_id%TYPE,
    Adr_BTR_ID D_BETRIEBSSTAETTE.Adr_BTR_ID%TYPE,
    Adr_Std_ID D_BETRIEBSSTAETTE.Adr_Std_ID%TYPE
    );
                                               
  TYPE tbBTS IS TABLE OF tBTS;
  
  TYPE tPrt IS RECORD ( 
    ID d_protokoll.ID%TYPE,
    BTS_ID d_protokoll.BTS_ID%TYPE, 
    D0101_ID d_protokoll.D0101_ID%TYPE, 
    STATUS d_protokoll.STATUS%TYPE, 
    INS_DATE d_protokoll.INS_DATE%TYPE, 
    USER_SID d_protokoll.USER_SID%TYPE, 
    LETZTE_AENDERUNG d_protokoll.LETZTE_AENDERUNG%TYPE, 
    MANDANT d_protokoll.MANDANT%TYPE, 
    DELETED d_protokoll.DELETED%TYPE, 
    PARAMETER d_protokoll.PARAMETER%TYPE, 
    DATENHERKUNFT  d_protokoll.DATENHERKUNFT%TYPE
    );   
  
  TYPE tbPrt IS TABLE OF tPrt; 

  TYPE tPersonal_Adr_Pst IS RECORD (
    --btr_e_person
      ID                d_personal.ID%TYPE 
    --, R_TYP             d_personal.owner_typE%TYPE                
    , KURZBEZEICHNUNG1  d_personal.KURZBEZEICHNUNG1%TYPE          
    , KURZBEZEICHNUNG2  d_personal.KURZBEZEICHNUNG2%TYPE          
    , TYP               d_personal.TYP%TYPE                
    , Anrede            d_personal.Anrede%TYPE            
    , TITEL             d_personal.TITEL%TYPE              
    , VORNAME           d_personal.VORNAME%TYPE            
    , NACHNAME          d_personal.NACHNAME%TYPE          
    , Geburtsdatum      d_personal.Geburtsdatum%TYPE      
    , Geburtsort        d_personal.Geburtsort%TYPE        
    , BEZEICHNUNG       d_personal.BEZEICHNUNG%TYPE        
    , BEZEICHNUNG2      d_personal.BEZEICHNUNG2%TYPE      
    , RECHTSFORM        d_personal.RECHTSFORM%TYPE        
    , REF_ID            d_personal.REF_ID%TYPE        
    --, PERS_ID,    d_personal., PERS_ID, REF_ID  
    , VORSATZ_NACHNAME  d_personal.VORSATZ_NACHNAME%TYPE  
    , NACHSATZ_NACHNAME d_personal.NACHSATZ_NACHNAME%TYPE 
    , HAUPTANSPRECHPARTNER_JN d_personal.HAUPTANSPRECHPARTNER_JN%TYPE
    , A0101_03_SID      VARCHAR2(10 CHAR) --d_personal.A0101_03_SID%TYPE 
    , A0101_70_SID      VARCHAR2(10 CHAR) --d_personal.A0101_70_SID%TYPE 
    , OWNER_PRS_ID      d_personal.owner_prs_id%TYPE
    , OWNER_TYPE        d_personal.owner_type%TYPE
    , bemerkung         d_personal.bemerkung%TYPE
    
    -- btr_e_postadresse
    , Hausnummer        D_ADRESSE.Hausnummer%TYPE
    , Hausnummernzusatz D_ADRESSE.Hausnummernzusatz%TYPE
    , Ort               D_ADRESSE.Ort%TYPE
    , Ortsteil          D_ADRESSE.Ortsteil%TYPE
    , Postfach          D_ADRESSE.Postfach%TYPE
    , Staat             D_ADRESSE.Staat%TYPE
    , STRASSE           D_ADRESSE.STRASSE%TYPE
    , PLZ               D_ADRESSE.PLZ%TYPE
    , GKZ               D_ADRESSE.gkz%TYPE
    , GLO_A24_SID       VARCHAR2(10 CHAR) --btr_e_postadresse.GLO_A24_SID%TYPE  
    , ADR_TYPE          D_ADRESSE.TYP%TYPE

    , Telefon           d_personal.Telefon%TYPE 
    , FAX               d_personal.fax%TYPE 
    , Mobil             d_personal.Mobil%TYPE 
    , EMAIL             d_personal.email%TYPE
    , weitere           d_personal.weitere%TYPE
    , Internet          d_personal.Internet%TYPE

  ); 

  TYPE tbPersonal_Adr_Pst IS TABLE OF tPersonal_Adr_Pst;
                                 
  TYPE tBtr_Prs IS RECORD(
      gueltig_von      d_personalfunktion.gueltig_von%TYPE
    , gueltig_bis      d_personalfunktion.gueltig_bis%TYPE
    , ID               d_personal.ID%TYPE 
    , KURZBEZEICHNUNG1 d_personal.KURZBEZEICHNUNG1%TYPE          
    , KURZBEZEICHNUNG2 d_personal.KURZBEZEICHNUNG2%TYPE          
    , TYP              d_personal.TYP%TYPE                
    , Anrede           d_personal.Anrede%TYPE            
    , TITEL            d_personal.TITEL%TYPE              
    , VORNAME          d_personal.VORNAME%TYPE            
    , NACHNAME         d_personal.NACHNAME%TYPE          
    , Geburtsdatum     d_personal.Geburtsdatum%TYPE      
    , Geburtsort       d_personal.Geburtsort%TYPE        
    , BEZEICHNUNG      d_personal.BEZEICHNUNG%TYPE        
    , BEZEICHNUNG2     d_personal.BEZEICHNUNG2%TYPE      
    , RECHTSFORM       d_personal.RECHTSFORM%TYPE
    , REF_ID           d_personal.ref_id%TYPE         
    --, PERS_ID,   d_personal., PERS_ID, REF_ID
    --, D0101_ID3     d_personal.ref_id%TYPE  
    , VORSATZ_NACHNAME  d_personal.VORSATZ_NACHNAME%TYPE  
    , NACHSATZ_NACHNAME d_personal.NACHSATZ_NACHNAME%TYPE 
    , A0101_03_SID     VARCHAR2(10 CHAR) --d_personal.A0101_03_SID%TYPE 
    , A0101_70_SID     VARCHAR2(10 CHAR) --d_personal.A0101_70_SID%TYPE 
    --11.02.2014 , R_TYPE          d_personal.owner_type%TYPE

    , Telefon     d_personal.Telefon%TYPE 
    , FAX         d_personal.fax%TYPE 
    , Mobil       d_personal.Mobil%TYPE 
    , EMAIL       d_personal.email%TYPE
    , weitere     d_personal.weitere%TYPE
    , Internet    d_personal.Internet%TYPE
    , Adr_Pst_ID  d_personal.Adr_Pst_ID%TYPE
    , Adr_STZ_ID  d_personal.Adr_STZ_ID%TYPE
    , bemerkung   d_personal.bemerkung%TYPE
    
  );
  
  TYPE tbBtr_Prs IS TABLE OF tBtr_Prs;

  TYPE tPersonal IS RECORD (
    ID                         d_personal.id%TYPE 
    --, ADR_STZ_ID            , ADR_STZ_ID
    --, ADR_PST_ID            , ADR_PST_ID
    --, OWNER_PRS_ID          , OWNER_PRS_ID
    , OWNER_TYPE              d_personal.OWNER_TYPE%TYPE
    --, KURZBEZEICHNUNG1      , KURZBEZEICHNUNG1
    --, KURZBEZEICHNUNG2      , KURZBEZEICHNUNG2
    , TYP                     d_personal.TYP%TYPE
    , ANREDE                  d_personal.ANREDE%TYPE
    , TITEL                   d_personal.TITEL%TYPE
    , VORNAME                 d_personal.VORNAME%TYPE
    , NACHNAME                d_personal.NACHNAME%TYPE
    , GEBURTSDATUM            d_personal.GEBURTSDATUM%TYPE
    , GEBURTSORT              d_personal.GEBURTSORT%TYPE
    --, BEZEICHNUNG           , BEZEICHNUNG
    --, BEZEICHNUNG2          , BEZEICHNUNG2
    --, RECHTSFORM            , RECHTSFORM
    --, PERS_ID               , PERS_ID
    , REF_ID                  d_personal.REF_ID%TYPE
    , VORSATZ_NACHNAME        d_personal.VORSATZ_NACHNAME%TYPE
    , NACHSATZ_NACHNAME       d_personal.NACHSATZ_NACHNAME%TYPE
    --, A0101_03_SID          , A0101_03_SID
    , A0101_70_SID            d_personal.A0101_70_SID%TYPE
    , INS_DATE                d_personal.INS_DATE%TYPE
    , TELEFON                 d_personal.TELEFON%TYPE
    , FAX                     d_personal.FAX%TYPE
    , INTERNET                d_personal.INTERNET%TYPE
    , MOBIL                   d_personal.MOBIL%TYPE
    , EMAIL                   d_personal.EMAIL%TYPE
    , WEITERE                 d_personal.WEITERE%TYPE
    , HAUPTANSPRECHPARTNER_JN d_personal.HAUPTANSPRECHPARTNER_JN%TYPE
    , BEMERKUNG               d_personal.BEMERKUNG%TYPE
  );
  
  TYPE tbPersonal IS TABLE OF tPersonal;
    
  TYPE tBTS_rec IS RECORD( 
    BTS          tBTS,
    FAB          tbFAB,
    USC          tbUSC,
    Prot         tPrt,
    Reg          tbReg,
    Bar          tbBar,
    --Abt_Adr      tbBtr2_Btr,
    ABT          tbABT,
    --ABT_Abt      tbABT_ABT,
    Adr_Sto     tAdr,  -- Standortadresse
    --Adr_BTRO2  tAdr,   
    Adr_Pst     tAdr,   -- Postadresse
    --Adr_BTRA2  tAdr,
    Fkt_HV       tFnc,
    Fkt_INH      tFnc,
    Btr_Personal_Adr_Pst tbPersonal_Adr_Pst, -- Personal Betreiber
    Btr_Reg      tbReg,
    Btr2_Btr  tBtr_Prs, -- Betreiber zum Betreiber
    Btr2_Adr_Pst  tAdr, -- Postadresse Betreiber zum Betreiber
    Btr2_Adr_Sto  tAdr, -- Standortadresse Betreiber zum Betreiber
    Btr2_Personal_Adr_Pst tbPersonal_Adr_Pst --, -- Personal Betreiber zum Betreiber                         
    );                                        
               

  BTS1 tBTS_Rec;  -- Betriebsstaette
  vBTS_ID      D_BETRIEBSSTAETTE.id%TYPE;
  vMandant_SID INTEGER := -1; -- Mandant
  vUSER_SID    INTEGER := -1;
  vErrMsg       CLOB   := NULL;
  vMessage      CLOB   := NULL;
  vGKZ2        VARCHAR2(2 CHAR);
  vCRLF        CONSTANT VARCHAR2(4 CHAR) := CHR(13);
  --vCommit      NUMBER(1) := 1;
  Default_gueltig_bis CONSTANT DATE := TO_DATE('01.01.9999', 'dd.mm.yyyy');
  Default_gueltig_von CONSTANT DATE := TO_DATE('31.12.1920', 'dd.mm.yyyy');
  vErrCnt      INTEGER := 0;
  
  vDateMin CONSTANT DATE := TO_DATE('31.12.1920', 'dd.mm.yyyy');
  vDateMax CONSTANT DATE := TO_DATE('01.01.9999', 'dd.mm.yyyy');

  Betreiber CONSTANT VARCHAR2(9 CHAR) := 'BTR';
  StandortAdr CONSTANT VARCHAR2(20 CHAR) := 'ADR_STO';
  PostAdr CONSTANT VARCHAR2(20 CHAR) := 'ADR_PST';
  HV CONSTANT VARCHAR2(2 CHAR) := 'HV';
  Personal CONSTANT VARCHAR2(5 CHAR) := 'NP';
  vINH VARCHAR2(20 CHAR) := Betreiber;
  GbR INTEGER := 6;
  
  vHV VARCHAR2(20 CHAR) := HV;
  vPersonal d_personal.owner_type%TYPE := Personal;
  Adr_Strasse    CONSTANT VARCHAR2(20 CHAR) := 'S'; --'STRASSE';
  Adr_Postfach   CONSTANT VARCHAR2(20 CHAR) := 'P'; --'Postfach'; 
  Adr_Free       CONSTANT VARCHAR2(20 CHAR) := 'F'; --'FREE';
  Adr_WECHSELNDER_STANDORT CONSTANT VARCHAR2(20 CHAR) := 'V'; --'VARIABLE_LOCATION';     
  vMandantZB vis_d0101.zb%TYPE := '%'; -- erster ZB des Mandanten
  vPlausiErrCnt INTEGER := 0;
  vPlausiMsg CLOB := NULL;
  vVerfahren VARCHAR2(10 CHAR) := 'BEA';
  vTypeJP CONSTANT VARCHAR2(2 CHAR) := 'JP'; -- juistischen Person
  vTypeNP CONSTANT VARCHAR2(2 CHAR) := 'NP'; -- natrliche Person
  vHauptBA CONSTANT VARCHAR2(3 CHAR) := 'HBA'; -- d_betriebsart.geltungsbereich Kennzeichen fr Hauptbetriebsart 
  PROCEDURE InsertD0101(pBTS_ID IN VARCHAR2, pWithOutRead IN INTEGER := 0);
  FUNCTION Fill_BTS1(pBTS_ID D_BETRIEBSSTAETTE.id%TYPE) RETURN INTEGER;
  FUNCTION Fill_BTS(pBTS OUT NOCOPY tBTS_rec, pBTS_ID IN D_BETRIEBSSTAETTE.id%TYPE) RETURN INTEGER;
  --FUNCTION GetD010200_BEZ( pNNAME VARCHAR2, pVName VARCHAR2) RETURN VARCHAR2; 
  --FUNCTION GetD010200_BEZ( pnname IN VARCHAR2, pvname IN VARCHAR2, pTitel IN VARCHAR2, pVorsatz IN VARCHAR2, pNachsatz IN VARCHAR2) RETURN VARCHAR2;
  FUNCTION CreateD0102Bez( pAnrede IN VARCHAR2, pTitel IN VARCHAR2,pVname IN VARCHAR2, pNname IN VARCHAR2,  pVorsatz IN VARCHAR2, pNachsatz IN VARCHAR2) RETURN VARCHAR2 DETERMINISTIC;

  FUNCTION CreateD0101P_Name( pNname IN VARCHAR2, pVname IN VARCHAR2,
                            pVorsatz IN VARCHAR2, pNachsatz  IN VARCHAR2, 
                            pTITEL IN VARCHAR2) RETURN VARCHAR2 DETERMINISTIC;
    
  PROCEDURE ClearErrMsg;
  FUNCTION GetErrMsg RETURN CLOB; 
  FUNCTION GetErrCnt RETURN INTEGER; 
  
  FUNCTION GetD0101_ID RETURN VARCHAR2;
  --FUNCTION GetCreatedusecase RETURN NUMBER;
  --FUNCTION GetAnl_Min_D0101_ID3 RETURN VARCHAR2;
  FUNCTION GetUser_SID( pMandant_User IN VARCHAR2) RETURN INTEGER;
  FUNCTION Version RETURN VARCHAR2;
  FUNCTION GKZ2 RETURN VARCHAR2;
  PROCEDURE GKZ2 ( pGKZ2 IN VARCHAR2 );
  FUNCTION ReadInit(pBTS_ID IN VARCHAR2) RETURN INTEGER;
  FUNCTION ReadPrt RETURN tbPrt PIPELINED;
  FUNCTION ReadUsc RETURN tbUsc PIPELINED;

  FUNCTION ReadBts RETURN tbBTS PIPELINED;
  FUNCTION ReadBtsFAB RETURN tbFAB PIPELINED;
  FUNCTION ReadBtsAdr_Sto RETURN tbAdr PIPELINED;
  FUNCTION ReadBtsAdr_Pst RETURN tbAdr PIPELINED;

  --FUNCTION ReadBtsPersonal RETURN tbD_Personal PIPELINED;

  FUNCTION ReadBtsReg RETURN tbReg PIPELINED;
  FUNCTION ReadBtsBar RETURN tbBar PIPELINED;

  FUNCTION ReadBtrPrs RETURN tbBtr_Prs PIPELINED;
  FUNCTION ReadBtrAdr_Sto RETURN tbAdr PIPELINED;
  FUNCTION ReadBtrAdr_Pst RETURN tbAdr PIPELINED; 

  FUNCTION ReadBtrPersonal RETURN tbPersonal_Adr_Pst PIPELINED;  

  FUNCTION ReadBtr2Prs RETURN tbBtr_Prs PIPELINED;
  FUNCTION ReadBtr2Adr_Sto RETURN tbAdr PIPELINED;
  FUNCTION ReadBtr2Adr_Pst RETURN tbAdr PIPELINED;
  FUNCTION ReadBtr2Personal RETURN tbPersonal_Adr_Pst PIPELINED;  
  FUNCTION ReadBtrReg RETURN tbReg PIPELINED;
  
  FUNCTION SaveInit(pBTS_ID IN VARCHAR2) RETURN INTEGER;
  FUNCTION SaveBts( pValues IN tBTS) RETURN INTEGER;
  FUNCTION SaveBtsFAB( pValues IN tFAB) RETURN INTEGER;
  FUNCTION SavePrt(pValues IN tPrt)  RETURN INTEGER;
  FUNCTION SaveUsc(pValues IN tUsc)  RETURN INTEGER;

  FUNCTION SaveBtsAdr_Sto(pValues IN tAdr) RETURN INTEGER;
  FUNCTION SaveBtsAdr_Pst(pValues IN tAdr) RETURN INTEGER;

  FUNCTION SaveBtsReg(pValues IN tReg) RETURN INTEGER;
  FUNCTION SaveBtsBar(pValues IN tBar) RETURN INTEGER;
  --FUNCTION SaveBtsPersonal(pValues tPersonal) RETURN INTEGER;

  FUNCTION SaveBtrPrs(pValues IN tBtr_Prs) RETURN INTEGER;


  FUNCTION SaveBtrAdr_Sto(pValues IN tAdr) RETURN INTEGER;
  FUNCTION SaveBtrAdr_Pst(pValues IN tAdr) RETURN INTEGER;
  
  FUNCTION SaveBtrPersonal(pValues tPersonal_Adr_Pst) RETURN INTEGER;
  FUNCTION SaveBtrReg(pValues IN tReg) RETURN INTEGER;
  
  FUNCTION SaveBtr2Prs(pValues IN tBtr_Prs) RETURN INTEGER;

  FUNCTION SaveBtr2Adr_Sto(pValues IN tAdr) RETURN INTEGER;
  FUNCTION SaveBtr2Adr_Pst(pValues IN tAdr) RETURN INTEGER;

  FUNCTION SaveBtr2Personal(pValues tPersonal_Adr_Pst) RETURN INTEGER;
  
  FUNCTION SaveFinaly(pBTS_ID IN VARCHAR2, pWithOutClear INTEGER := 0) RETURN INTEGER;
  PROCEDURE DeleteBts(pBTS_ID VARCHAR2);
  PROCEDURE Plausi(pBTS IN INTEGER := 1, pBTR IN INTEGER := 1);
  FUNCTION Plausi(pBTS_ID IN VARCHAR2) RETURN INTEGER;
  PROCEDURE Plausi(pBTS_ID IN VARCHAR2, pErrorCount OUT INTEGER, pMessage OUT NOCOPY CLOB);
  FUNCTION PlausiMessage RETURN CLOB;
  FUNCTION PlausiErrorCount RETURN INTEGER;
  FUNCTION GetZBbyMandantSID(pMandantSid NUMBER) RETURN VARCHAR;
--  FUNCTION CreatePersonBez(pNName IN VARCHAR2, pVName IN VARCHAR2,
--                         pVorsatz IN VARCHAR2, pNachsatz  IN VARCHAR2, 
--                         pTITEL IN VARCHAR2) RETURN VARCHAR2;

  FUNCTION UpdProtocol(pValues IN tPrt) RETURN INTEGER;
  -- 1.23 neu Update Betrieb
  -- bertragen D0101 in Korb
  FUNCTION TransferFromD0101(pD0101_ID IN VARCHAR2, pDATENHERKUNFT IN VARCHAR2, pUserSID IN INTEGER := -1, pMandantSID IN INTEGER := NULL, pLastUpdDate IN DATE := NULL) RETURN VARCHAR2;
  PROCEDURE TransferToD0101(pBTS_ID IN VARCHAR2);
  FUNCTION ClearAll RETURN INTEGER;
  -- nur zum Test
  PROCEDURE AnlageD0308(pUsecase IN tUSC, pD0101_ID IN VARCHAR2);
END blv_ein;
/

/*<TOAD_FILE_CHUNK>*/

CREATE OR REPLACE PACKAGE BODY BLV_EIN AS

  vDEFAULT_A24_SID INTEGER := 120;  -- Standard Land
  vDEFAULT_S09_SID INTEGER := -1;   -- Standard Koordinatensystem;
  vPrt_Params tbParams; 
  
-- Generieren Bezeichnung: Titel Vorname Vorsatz Nachname, Nachsatz 
FUNCTION CreateD0101P_Name( pNname IN VARCHAR2, pVname IN VARCHAR2,
                            pVorsatz IN VARCHAR2, pNachsatz  IN VARCHAR2, 
                            pTITEL IN VARCHAR2) RETURN VARCHAR2 DETERMINISTIC AS
v1 VARCHAR2(450);
  PROCEDURE Add_v1( p1 IN VARCHAR2, p2 IN VARCHAR2) AS
  BEGIN
    IF p1 IS NOT NULL THEN
      IF v1 IS NULL THEN
        v1 := p1;
      ELSE
        v1 := TRIM(v1) || p2 || p1;
      END IF; 
    END IF; 
  END;
BEGIN

  v1 := pTitel;
  Add_v1(pVName, ' ');
  Add_v1(pVorsatz, ' ');
  Add_v1(pNName, ' ');
  Add_v1(pNachsatz, ', ');

  IF LENGTH(v1) > 128 THEN
    v1 := SUBSTR(v1, 1, 126) || '..';
  END IF;
  
  RETURN v1;
         
END;

FUNCTION CrtD0101_BEZ_ART(pType IN VARCHAR2, pA0101_03_SID IN INTEGER) RETURN VARCHAR2 
DETERMINISTIC AS
BEGIN

 RETURN CASE WHEN pType IN( vTypeJP, 'LP') OR pA0101_03_sid = GbR THEN 'F' 
        ELSE 'N' 
        END;

END;  
   
FUNCTION GetRechtsformTyp(pA0101_03_SID IN INTEGER) RETURN CHAR DETERMINISTIC AS
vRes VARCHAR2(10 CHAR) := 'E';
BEGIN


  IF pA0101_03_SID > -1 THEN
    BEGIN
    
      SELECT feld1 INTO vRes FROM vis_a0101
      WHERE sid = pA0101_03_SID;

      vRes := TRIM(vRes);

      IF vRes = '0' THEN 
        vRes := 'N';
      ELSE
        vRes := 'F';
      END IF;
      
      EXCEPTION WHEN NO_DATA_FOUND THEN NULL;
      
    END;
  END IF;
  
  RETURN vRes;   
    
--    CASE 
--    WHEN pA0101_03_SID IN (  
--      1976001,  -- sonst. Natrl. Person
--      2,        -- Einzelunternehmer
--      434001)   -- eingetragener Kaufmann/frau 
--    THEN 'N'
--    WHEN pA0101_03_SID = -1 THEN 'E'
--    ELSE 'F'
--    END;
    
END;
                
-- Liefert zur Anrede die passende Briefanrede aus dem Katalog Anrede (a0101 skz = 7)
-- 09.09.2013
Function GetBriefanrede(pAnrede IN VARCHAR2) RETURN VARCHAR2 DETERMINISTIC AS
  v1 vis_a0101.bez%TYPE;
BEGIN

  BEGIN
    SELECT bez INTO v1
    FROM vis_a0101
    WHERE deleted = 0
    AND skz = 7
    AND kurzb = pAnrede;
    
    EXCEPTION 
    WHEN NO_DATA_FOUND THEN
      v1 := NULL;
    WHEN TOO_MANY_ROWS THEN
      v1 := NULL;
  END;
    
  RETURN v1;

END;

-- liefert den 1. ZB des Mandanten
FUNCTION GetZBbyMandantSID(pMandantSid NUMBER) RETURN VARCHAR AS
  vZB vis_d0101.zb%TYPE := '%';
  PROCEDURE P1 AS 
  BEGIN 
    SELECT DISTINCT FIRST_VALUE(a25.zb) OVER( ORDER BY s5002.lfdnr NULLS LAST) first_zb
    INTO vZB
    FROM vis_s5002 s5002
    JOIN glo_a25 a25 ON a25.sid = s5002.glo_a25_sid
    WHERE s5002.s50_sid = pMandantSID
    AND s5002.deleted = 0;
   
    EXCEPTION WHEN NO_DATA_FOUND THEN 
      vZB := '%';  
  END;
BEGIN 
  P1();   
  RETURN vZB;
END GetZBbyMandantSid;
 

FUNCTION EmptyID( pID IN VARCHAR2) RETURN BOOLEAN DETERMINISTIC AS
 vRes BOOLEAN;
BEGIN
  CASE 
  WHEN pID = '-1' THEN 
    vRes := TRUE;
  WHEN pID = '-9999' THEN
    vRes := TRUE;
  WHEN pID IS NULL THEN
    vRes := TRUE;
  ELSE
    vRes := FALSE;
  END CASE;  
  
  RETURN vRes;
END;

FUNCTION GetErrCnt RETURN INTEGER AS
BEGIN
  RETURN vErrCnt + vPlausiErrCnt;
END;

--PROCEDURE AddErrCnt AS
--BEGIN
--  vErrCnt := vErrCnt + 1;
--END;

PROCEDURE AddErrMsg( pMsg IN VARCHAR2) AS
BEGIN
  vErrMsg := vErrMsg || pMsg || vCRLF;
  vErrCnt := vErrCnt + 1;
END;

--PROCEDURE AddMsg( pMsg IN VARCHAR2) AS
--BEGIN
--  vMessage := vMessage || pMsg || vCRLF;
--END;

FUNCTION GetErrMsg RETURN CLOB AS
v VARCHAR2(4000 CHAR);
BEGIN
  If vMessage IS NOT NULL THEN
    v:= 'Hinweise:' || vCRLF || vMessage || vCRLF || vErrMsg;
  ELSE
    v := vErrMsg;
  END IF;
  If vPlausiMsg IS NOT NULL THEN
    v := v || vCrLf || vPlausiMsg;
  END IF;
  RETURN v;
END;

PROCEDURE ClearErrMsg AS
BEGIN
  vErrMsg := NULL;
  vMessage := NULL;
  vErrCnt := 0;
END;

-- Personalfunhktionen anlegen
-- sind keine im Zuordnungskatalog dann einen leeren Datensatz anlegen
PROCEDURE InsertD010202(pA0101_03_SID IN INTEGER, pD0101_ID IN VARCHAR2, pD010200_ID IN VARCHAR2, pA0101_70_SID IN INTEGER) AS
vD010202 vis_d010202%ROWTYPE;
vExists INTEGER:= 0;
BEGIN

  -- Initialisierung
  SELECT * INTO vD010202
  FROM vis_d010202 WHERE id = '-1';
            
  vD010202.d010200_id := pD010200_id;
  vD010202.d0101_id   := pD0101_id;
  vD010202.MANDANT    := vMandant_SID; 
  vD010202.INS_USER   := vUser_SID;
  vD010202.INS_DATE   := SYSDATE;
  vD010202.UPD_USER   := vUser_SID;
  vD010202.UPD_DATE   := SYSDATE;
  vD010202.DELETED    := 0;
  vD010202.DEL_USER   := '-1';
  vD010202.DEL_DATE   := NULL;
  vD010202.d0103_id   := '-1';
  vD010202.zb         := '%';
  vD010202.fb         := '%';
  vD010202.az_prozent := 0;
  vD010202.vertreter  := NULL;
  vD010202.code       := NULL;
  vD010202.coden      := NULL;
  vD010202.bez        := NULL;
  vD010202.a0101_70_sid := -1;

  IF pA0101_70_sid > -1 THEN  
    vD010202.a0101_70_sid := pA0101_70_sid;
  ELSE 
    FOR c1 IN ( 
      SELECT a0088.a0101_70_sid
      FROM vis_va0088$a0101_03$a0101_70 a0088
      WHERE a0088.a0101_03_sid = pA0101_03_sid
    ) LOOP
    
      vD010202.id         := SYS_GUID();
      vD010202.a0101_70_sid := NVL(c1.A0101_70_sid, -1);
      INSERT INTO vis_d010202 VALUES vD010202;
      vExists := 1;
      
    END LOOP;
    
  END IF; 
  
  IF vExists = 0 THEN
    vD010202.id := SYS_GUID();
    INSERT INTO vis_d010202 VALUES vD010202;  
  END IF;
   
END;      

-- Bezeichnung generierien: Anrede Titel Vorname Vorsatz Nachname, Nachsatz  
--FUNCTION GetD010200_BEZ( pAnrede IN VARCHAR2, pTitel IN VARCHAR2,pnname IN VARCHAR2, pvname IN VARCHAR2,  pVorsatz IN VARCHAR2, pNachsatz IN VARCHAR2) RETURN VARCHAR2 AS
FUNCTION CreateD0102Bez( pAnrede IN VARCHAR2, pTitel IN VARCHAR2,pVname IN VARCHAR2, pNname IN VARCHAR2,  pVorsatz IN VARCHAR2, pNachsatz IN VARCHAR2) RETURN VARCHAR2 
DETERMINISTIC AS
 v1 VARCHAR2(450);
  PROCEDURE Add_v1( p1 IN VARCHAR2, p2 IN VARCHAR2) AS
  BEGIN
    IF p1 IS NOT NULL THEN
      IF v1 IS NULL THEN
        v1 := p1;
      ELSE
        v1 := TRIM(v1) || p2 || p1;
      END IF; 
    END IF;
  END;
BEGIN
  v1 := pTitel;
  --Add_V1(TRIM(pTitel), ' ');
  Add_V1(TRIM(pVname), ' ');
  Add_V1(TRIM(pVorsatz), ' ');
  Add_V1(TRIM(pNname), ' ');
  Add_V1(TRIM(pNachsatz), ', ');

  IF LENGTH(v1) > 128 THEN
    v1 := SUBSTR(v1, 1, 126) || '..';
  END IF;

  RETURN v1;   
 
END;

Function GetAdresse(pAdr_ID IN D_ADRESSE.ID%TYPE) RETURN tAdr AS
  res tAdr := NULL;
  vAdr D_ADRESSE%ROWTYPE; 
BEGIN

  IF pADR_ID <> '-1' THEN
  
    SELECT * INTO vAdr
    FROM D_ADRESSE 
    WHERE ID = pAdr_ID;

   res.ID               := vAdr.id;
   res.FreiText         := vAdr.FreiText;
   res.WECHSELNDER_STANDORT := vAdr.WECHSELNDER_STANDORT;
   res.gueltig_von      := vAdr.gueltig_von;
   res.gueltig_bis      := vAdr.gueltig_bis;
  --, ADR_ID
   res.TYP              := vAdr.TYP;
   res.ADRESSZUSATZ     := vAdr.ADRESSZUSATZ;
     
    --ID
   res.Flurnummer       := vAdr.Flurnummer;
   res.Flurstueck       := vAdr.Flurstueck;
   res.Gemarkung        := vAdr.Gemarkung;
   res.X_Wert           := vAdr.X_Wert;
   res.Y_Wert           := vAdr.Y_Wert;
   res.Rechtswert       := vAdr.Rechtswert;
   res.Hochwert         := vAdr.Hochwert;
  -- 13.02.2013
   res.Koordinatenherkunft := vAdr.Koordinatenherkunft;
   res.S09_SID          := NVL(vAdr.s09_sid, vDEFAULT_S09_SID);
    
   res.Hausnummer       := vAdr.Hausnummer;
   res.Hausnummernzusatz:= vAdr.Hausnummernzusatz;
   res.Ort              := vAdr.Ort;
   res.Ortsteil         := vAdr.Ortsteil;
   res.Postfach         := vAdr.Postfach;
   res.Staat            := vAdr.Staat;
   res.STRASSE          := vAdr.STRASSE;
   res.PLZ              := vAdr.PLZ;
   res.GLO_A24_SID      := NVL(vAdr.glo_a24_sid, vDEFAULT_A24_SID); --  VARCHAR2(10) --btr_e_postadresse.GLO_A24_SID;
   res.GEMEINDE         := vAdr.GEMEINDE;
   res.GKZ              := vAdr.GKZ;
--    , REGIONALSCHLUESSEL btr_e_verwaltung.REGIONALSCHLUESSEL;
   res.Teilort          := vAdr.Teilort; 
   res.postbezeichnung  := vAdr.postbezeichnung;
  END IF;
 
  RETURN res;
END; -- Get_Adresse


PROCEDURE Clear_bts(pbts IN OUT NOCOPY tBTS_rec) AS
BEGIN
  pbts := NULL;
  pbts.REG              := tbReg();
  pbts.fkt_inh.reg      := tbReg();
  pbts.FAB              := tbFAB();
  pbts.USC              := tbUSC();
  pBts.Reg              := tbReg();
  pBts.Bar              := tbBar();
  --pbts.Abt_Adr          := tbBtr2_Btr();
  pbts.ABT              := tbABT();
  --pbts.ABT_Abt          := tbABT_Abt();
  pbts.Btr_Personal_Adr_Pst  := tbPersonal_Adr_Pst();
  pbts.Btr2_Personal_Adr_Pst := tbPersonal_Adr_Pst();
  pBts.Btr_Reg          := tbReg();  
  pBts.fkt_hv.personal := tbD_Personal();
  
END;

FUNCTION ClearAll RETURN INTEGER AS
BEGIN
  Clear_bts(BTS1);
  ClearErrMsg;
  RETURN 1;
END;

FUNCTION Fill_BTS1(pBTS_ID D_BETRIEBSSTAETTE.id%TYPE) RETURN INTEGER AS
BEGIN
  RETURN Fill_bts(BTS1, pBTS_ID);
END;  

FUNCTION Person_PAdr(pPers_ID IN VARCHAR2) RETURN tbPersonal_Adr_Pst AS
  vPerson_PAdr tbPersonal_Adr_Pst;
  iExt INTEGER:= 0;
BEGIN
  -- Personal
  vPerson_PAdr := tbPersonal_Adr_Pst();
  FOR c1 IN (

    SELECT pers.*
    FROM d_personal pers
    WHERE pers.owner_PRS_ID = pPers_id
    AND pers.owner_type = vPersonal
  ) LOOP
    
    iExt := iExt + 1;
    vPERSON_Padr.Extend(); 

    vPerson_PAdr(iExt).ID               := c1.ID;

    vPerson_PAdr(iExt).KURZBEZEICHNUNG1 := c1.KURZBEZEICHNUNG1;          
    vPerson_PAdr(iExt).KURZBEZEICHNUNG2 := c1.KURZBEZEICHNUNG2;          
    vPerson_PAdr(iExt).TYP              := c1.TYP;                
    vPerson_PAdr(iExt).Anrede           := c1.Anrede;            
    vPerson_PAdr(iExt).TITEL            := c1.TITEL;              
    vPerson_PAdr(iExt).VORNAME          := c1.VORNAME;            
    vPerson_PAdr(iExt).NACHNAME         := c1.NACHNAME;          
    vPerson_PAdr(iExt).Geburtsdatum     := c1.Geburtsdatum;      
    vPerson_PAdr(iExt).Geburtsort       := c1.Geburtsort;        
    vPerson_PAdr(iExt).BEZEICHNUNG      := c1.BEZEICHNUNG;        
    vPerson_PAdr(iExt).BEZEICHNUNG2     := c1.BEZEICHNUNG2;      
    vPerson_PAdr(iExt).RECHTSFORM       := c1.RECHTSFORM;        
    vPerson_PAdr(iExt).VORSATZ_NACHNAME := c1.VORSATZ_NACHNAME;  
    vPerson_PAdr(iExt).NACHSATZ_NACHNAME:= c1.NACHSATZ_NACHNAME;   
    vPerson_PAdr(iExt).REF_ID           := c1.ref_id;
    vPerson_PAdr(iExt).HAUPTANSPRECHPARTNER_JN := NVL(c1.HAUPTANSPRECHPARTNER_JN, 0);
    vPerson_PAdr(iExt).bemerkung        := c1.bemerkung;
    
    vPerson_PAdr(iExt).A0101_03_SID   := c1.A0101_03_SID;
    vPerson_PAdr(iExt).A0101_70_SID   := c1.A0101_70_SID;
  
    vPerson_PAdr(iExt).Telefon  := c1.Telefon;
    vPerson_PAdr(iExt).fax      := c1.fax;
    vPerson_PAdr(iExt).Mobil    := c1.Mobil;
    vPerson_PAdr(iExt).email    := c1.email;
    vPerson_PAdr(iExt).Internet := c1.Internet;
     
    -- Postadressen
    FOR c2 IN ( 

      SELECT adr.*
      FROM D_ADRESSE adr  
      WHERE adr.id = c1.Adr_Pst_ID
       --AND adr.typ = vBTRA

    ) LOOP      
      -- D_ADRESSE
      vPerson_PAdr(iExt).Hausnummer         := c2.Hausnummer;
      vPerson_PAdr(iExt).Hausnummernzusatz  := c2.Hausnummernzusatz;
      vPerson_PAdr(iExt).Ort                := c2.Ort;
      vPerson_PAdr(iExt).Ortsteil           := c2.Ortsteil;
      vPerson_PAdr(iExt).Postfach           := c2.Postfach;
      vPerson_PAdr(iExt).Staat              := c2.Staat;
      vPerson_PAdr(iExt).STRASSE            := c2.STRASSE;
      vPerson_PAdr(iExt).PLZ                := c2.PLZ;
      vPerson_PAdr(iExt).GLO_A24_SID        := c2.GLO_A24_SID;            
      vPerson_PAdr(iExt).ADR_TYPE           := c2.TYP;            
      vPerson_PAdr(iExt).GKZ                := c2.gkz;
    END LOOP;
  END LOOP;
  RETURN vPerson_PAdr;               
END; -- Person_PAdr

FUNCTION GetLandByA24_SID(pA24_SID INTEGER) RETURN VARCHAR2 AS
vLand glo_a24.post%TYPE;
BEGIN

  BEGIN
    SELECT post INTO vLand
    FROM glo_a24 
    WHERE deleted = 0
      AND sid = NVL(pA24_SID, vDEFAULT_A24_SID);
                      
    EXCEPTION WHEN NO_DATA_FOUND THEN 
      vLand := NULL;        
  END;
  
  RETURN vLand;
  
END ;

FUNCTION Fill_bts(pBts OUT NOCOPY tBTS_rec, pBTS_ID IN D_BETRIEBSSTAETTE.id%TYPE) RETURN INTEGER AS
  res INTEGER := 1;
  vBTS_ID D_BETRIEBSSTAETTE.id%TYPE := pBTS_ID;
  --vCnt INTEGER;
  i INTEGER := 0;
BEGIN

  Clear_bts(pbts);
  vINH  := Betreiber;
  vHV   := HV; 
  --vBTRO := StandortAdr;
  --vBTRA := PostAdr;      
  vPersonal := Personal;

  SELECT COUNT(*) INTO res
  FROM D_BETRIEBSSTAETTE bts
  WHERE bts.id = vBTS_ID;
        
  IF Res <> 1 THEN
    res := 0;
  ELSE

    -- bts
    SELECT ID, Adr_Pst_ID, Adr_Sto_ID, Adr_BTR_ID, Adr_Std_ID, 
    BEZEICHNUNG, gueltig_von, gueltig_bis, D0101_ID, 
    ZB, kennzeichen, INS_DATE, 
    Telefon, FAX, Internet, Mobil, EMAIL, weitere, 
    bemerkung
    INTO 
    pbts.bts.ID, pbts.bts.Adr_Pst_ID, pbts.bts.Adr_Sto_id, pbts.bts.Adr_BTR_ID, pbts.bts.Adr_Std_ID, 
    pbts.bts.BEZEICHNUNG, pbts.bts.gueltig_von, pbts.bts.gueltig_bis, pbts.bts.d0101_id,
    pbts.bts.zb, pbts.bts.kennzeichen, pbts.bts.ins_date,
    pbts.bts.Telefon, pbts.bts.fax, pbts.bts.Internet, pbts.bts.Mobil, pbts.bts.email, pbts.bts.weitere,
    pbts.bts.bemerkung
    FROM D_BETRIEBSSTAETTE bts
    WHERE bts.id = vBTS_ID;

     
    -- Protokoll
    BEGIN
      SELECT ID, BTS_ID, D0101_ID, STATUS, 
      INS_DATE, USER_SID, LETZTE_AENDERUNG, 
      MANDANT, DELETED, PARAMETER, 
      DATENHERKUNFT
      INTO 
      pbts.Prot.ID, pbts.Prot.BTS_ID, pbts.Prot.D0101_ID, pbts.Prot.STATUS,
      pbts.Prot.INS_DATE, pbts.Prot.USER_SID, pbts.Prot.LETZTE_AENDERUNG, 
      pbts.Prot.MANDANT, pbts.Prot.DELETED, pbts.Prot.PARAMETER, 
      pbts.Prot.DATENHERKUNFT
      FROM d_protokoll prot
      WHERE prot.BTS_ID = vBTS_ID;
      EXCEPTION WHEN NO_DATA_FOUND THEN NULL;
    END;
    
    -- usecase
    FOR cUSC IN (
      SELECT usc.* 
      FROM d_usecase usc
      WHERE usc.BTS_ID = vBTS_ID
    ) LOOP

      pbts.USC.EXTEND();
      i := pbts.USC.LAST;
      pbts.USC(i).ID := cUSC.ID; 
      pbts.USC(i).usecase := cUSC.usecase;
      pbts.USC(i).MANDANT := cUSC.MANDANT;
      pbts.USC(i).user_name := cUSC.user_name;
      pbts.USC(i).USER_SID := cUSC.USER_SID;
      pbts.USC(i).typ := cUSC.typ; 
      pbts.USC(i).Aenderungsgrund := cUSC.Aenderungsgrund; 
      pbts.USC(i).Bemerkung := cUSC.Bemerkung; 
      pbts.USC(i).FB := cUSC.FB; 
      pbts.USC(i).ZB := cUSC.ZB; 
      pbts.USC(i).D0101_ID := cUSC.D0101_ID; 
      pbts.USC(i).gueltig_von := cUSC.gueltig_von; 
      pbts.USC(i).gueltig_bis := cUSC.gueltig_bis; 
      pbts.USC(i).A0101_501_SID := cUSC.A0101_501_SID;
      pBts.USC(i).alter_wert := cUSC.alter_wert;
      pBts.USC(i).neuer_wert := cUSC.neuer_wert;       
    
    END LOOP;
            
    -- Adresse Betriebsstaette
         
    IF pbts.bts.Adr_Pst_ID <> '-1' THEN  -- Postadresse
      pbts.Adr_Pst := GetAdresse(pbts.bts.Adr_Pst_ID);
    END IF;
      
    IF pbts.bts.Adr_Sto_ID <> '-1' THEN  -- Standortadresse
      pbts.Adr_Sto := GetAdresse(pbts.bts.Adr_Sto_ID);
    END IF;
      
--    IF pbts.bts.Adr_BTR_ID <> '-1' THEN  -- Betreiberadresse
--      NULL;
--    END IF;
--      
--    IF pbts.bts.Adr_Std_ID <> '-1' THEN  -- Standardadresse
--      NULL;
--    END IF;
          
    -- Fachbereiche zur Betriebsstaette
    SELECT id, BTS_ID, CODE, A0101_06_SID, gueltig_von, gueltig_bis, d010104_ID, A0115_SID, A0101_01_SID, ERSTKONTROLLTERMIN, ins_date
    BULK COLLECT INTO pbts.FAB 
    FROM d_fachbereich
    WHERE BTS_ID = vBTS_ID;
     

    -- Hauptverantwortlicher, nur wenn auch vorhanden
--    SELECT COUNT(*) INTO vCnt
--    FROM d_personalfunktion fkt
--    WHERE fkt.TYP = vHV 
--     AND FKT.BTS_ID = vBTS_ID;
--        
--    IF vCnt = 1 THEN
    BEGIN    
      SELECT *
      INTO pbts.fkt_hv.fkt
      FROM d_personalfunktion fkt
      WHERE fkt.TYP = vHV 
       AND FKT.BTS_ID = vBTS_ID;
        
      -- Hauptverantwortlicher - PERSON
      SELECT prs.* INTO pbts.fkt_hv.pers
      FROM d_personal prs
      WHERE prs.id = pbts.fkt_hv.fkt.prs_id;
      
      EXCEPTION 
      WHEN no_data_found THEN NULL;

    END;      
--    END IF;

    IF pbts.Prot.DATENHERKUNFT IN ('AUGE', 'WEIN') THEN
      -- Registrierungen der Betriebssttte    
      SELECT ID, PRS_ID, BTS_ID, TYP, CODE, NUMMER, ZUSATZ, GUELTIG_VON, GUELTIG_BIS, REF_ID, INS_DATE            
      BULK COLLECT INTO pbts.reg 
      FROM d_registrierung
      WHERE BTS_ID = vBTS_ID;  

      -- Betriebsarten der Betriebssttte    
      SELECT ID ,BTS_ID ,TYP ,CODE ,BEZEICHNUNG ,FB ,GUELTIG_VON ,GUELTIG_BIS ,
      D010101_ID ,GELTUNGSBEREICH ,GEWERBSMAESSIG_JN ,INS_DATE ,ADR_STO_ID            
      BULK COLLECT INTO pbts.bar 
      FROM d_betriebsart
      WHERE BTS_ID = vBTS_ID;  
      
      -- Betriebspersonal
--      SELECT personal.*
--      BULK COLLECT INTO pBTS.fkt_hv.personal
--      FROM d_personal personal
--      JOIN d_personalfunktion fkt ON fkt.prs_id = personal.id
--      AND fkt.typ IN (vHV, vPersonal)
--      AND fkt.bts_id = vBTS_ID;
      
    END IF;
        
    -- Betreiber  
    FOR cInh IN ( 
      SELECT fkt.* 
      FROM d_personalfunktion fkt
      WHERE fkt.TYP = vINH 
       AND FKT.BTS_ID = vBTS_ID
    ) LOOP
      pbts.fkt_inh.fkt := cInh;
    END LOOP; -- Betreiber
         
    -- Betreiber - Person
    FOR cInhPers IN (
      SELECT prs.* --INTO pbts.fkt_inh.pers
      FROM d_personal prs
      WHERE prs.id = pbts.fkt_inh.fkt.prs_id
    ) LOOP
      pbts.fkt_inh.pers := cInhPers;
    END LOOP;

    -- Personal Betreiber
    pbts.Btr_Personal_Adr_Pst := Person_PAdr(pbts.fkt_inh.fkt.prs_id);    
      
    -- Betreiber - Adresse
    IF pbts.fkt_inh.pers.Adr_Pst_ID <> '-1' THEN  -- 'Postadressse'
      pbts.Fkt_Inh.Adr_Pst := GetAdresse(pbts.fkt_inh.pers.Adr_Pst_ID);
    END IF;
      
    IF pbts.fkt_inh.pers.Adr_STZ_ID <> '-1' THEN -- 'Sitzadressse'
      pbts.Fkt_Inh.Adr_Sto := GetAdresse(pbts.fkt_inh.pers.Adr_STZ_ID);
    END IF;
                
    -- HV - Adresse
    IF pbts.fkt_hv.pers.Adr_Pst_ID <> '-1' THEN -- Postadresse HV
      pbts.Fkt_hv.Adr_Pst := GetAdresse( pbts.fkt_hv.pers.Adr_Pst_ID);    
    END IF;
      
    IF pbts.fkt_hv.pers.Adr_STZ_ID <> '-1' THEN -- Standortadressse HV
      pbts.Fkt_hv.Adr_Sto := GetAdresse( pbts.fkt_hv.pers.Adr_STZ_ID);    
    END IF;
    
    IF pbts.Prot.DATENHERKUNFT IN ('AUGE', 'WEIN') THEN
      -- Registrierungen des Betreibers    
      SELECT ID, PRS_ID, BTS_ID, TYP, CODE, NUMMER, ZUSATZ, GUELTIG_VON, GUELTIG_BIS, REF_ID, INS_DATE            
      BULK COLLECT INTO pbts.btr_reg 
      FROM d_registrierung
      WHERE PRS_ID = pbts.fkt_inh.fkt.prs_id;     
    END IF;
  
    -- Betreiber zum Betreiber
    IF pbts.fkt_inh.pers.id <> '-1' THEN -- Betreiber vorhanden
      -- Person Betreiber zum Betreiber
      FOR c1 IN (
        SELECT pers.*
        FROM d_personal pers 
        WHERE pers.owner_prs_id = pbts.fkt_inh.pers.id
         AND pers.owner_type = vINH
      ) LOOP
          
        pbts.Btr2_Btr.gueltig_von      := NULL; --pValues.gueltig_von;
        pbts.Btr2_Btr.gueltig_bis      := NULL; --pValues.gueltig_bis;
        pbts.Btr2_Btr.ID               := c1.ID;
        pbts.Btr2_Btr.KURZBEZEICHNUNG1 := c1.KURZBEZEICHNUNG1;
        pbts.Btr2_Btr.KURZBEZEICHNUNG2 := c1.KURZBEZEICHNUNG2;
        pbts.Btr2_Btr.TYP              := c1.TYP; -- 07.08.2013 wegen unklarere Logik CASE WHEN c1.BEZEICHNUNG||c1.BEZEICHNUNG2 IS NULL THEN 'JP' ELSE 'NP' END;              
        pbts.Btr2_Btr.REF_ID           := c1.ref_id;
        pbts.Btr2_Btr.Anrede           := c1.Anrede;
        pbts.Btr2_Btr.TITEL            := c1.TITEL;
        pbts.Btr2_Btr.VORNAME          := c1.VORNAME;
        pbts.Btr2_Btr.NACHNAME         := c1.NACHNAME;
        pbts.Btr2_Btr.Geburtsdatum     := c1.Geburtsdatum;
        pbts.Btr2_Btr.Geburtsort       := c1.Geburtsort;
        pbts.Btr2_Btr.BEZEICHNUNG      := c1.BEZEICHNUNG;
        pbts.Btr2_Btr.BEZEICHNUNG2     := c1.BEZEICHNUNG2;
        pbts.Btr2_Btr.RECHTSFORM       := c1.RECHTSFORM;  
        pbts.Btr2_Btr.VORSATZ_NACHNAME := c1.VORSATZ_NACHNAME;
        pbts.Btr2_Btr.NACHSATZ_NACHNAME:= c1.NACHSATZ_NACHNAME;
        pbts.Btr2_Btr.A0101_03_SID     := c1.A0101_03_SID;
        pbts.Btr2_Btr.A0101_70_SID     := c1.A0101_70_SID;
        pBts.Btr2_Btr.bemerkung        := c1.bemerkung;
        --11.02.2014 pbts.Btr2_Btr.r_type          := c1.owner_type;
        pbts.Btr2_Btr.Telefon          := c1.Telefon;
        pbts.Btr2_Btr.fax              := c1.fax;
        pbts.Btr2_Btr.Mobil            := c1.Mobil;
        pbts.Btr2_Btr.Internet         := c1.Internet;
        pbts.Btr2_Btr.email            := c1.email;
        pbts.Btr2_Btr.Adr_Pst_ID       := c1.Adr_Pst_ID;
        pbts.Btr2_Btr.Adr_STZ_ID       := c1.Adr_STZ_ID;
          
        -- Adressen Person Betreiber zum Betreiber
          
        IF c1.Adr_Pst_ID <> '-1' THEN -- Postadresse
          pbts.Btr2_Adr_Pst := GetAdresse(c1.Adr_Pst_ID);
        END IF;

        IF c1.Adr_STZ_ID <> '-1' THEN -- Sitzadresse
          pbts.Btr2_Adr_Sto := GetAdresse(c1.Adr_STZ_ID);
        END IF;
          
        -- Personal Betreiber zum Betreiber
        pbts.Btr2_Personal_Adr_Pst := Person_PAdr(c1.id);
      END LOOP;

    END IF;
  END IF;  
  RETURN res;
  
END Fill_bts;  

--PROCEDURE GetA24_SID_LAND_by_ISO( pISO_Nr IN VARCHAR2, pSID OUT NUMBER, pLand OUT NOCOPY VARCHAR2) AS
--BEGIN
--
--    SELECT sid, post INTO pSid, pLand
--    FROM glo_a24 
--    WHERE deleted = 0
--      AND iso_nr = pIso_Nr;
--      
--    EXCEPTION WHEN NO_DATA_FOUND OR TOO_MANY_ROWS THEN 
--      pSid := 120;
--      pLand := 'D';
--
--END;

--PROCEDURE GetA0101_47(pBez IN VARCHAR2, pSID OUT NUMBER, pCode OUT NOCOPY VARCHAR2) AS
--BEGIN
--       
--  SELECT sid, code INTO pSid, pCode
--  FROM VIS_VA0101_47
--  WHERE bez = pBez;
--          
--  EXCEPTION WHEN no_data_found THEN 
--    pSid := -1;
--    pCode := NULL;
--          
--END;

-- Vergleiche
--FUNCTION Compare( pS1 VARCHAR2, pS2 VARCHAR2) RETURN NUMBER AS
--  vRes INTEGER;
--BEGIN
--  IF (pS1 IS NULL AND pS2 IS NULL) OR pS1 = pS2 THEN
--    vRes := 1;
--  ELSE 
--    vRes := 0;
--  END IF;  
--  RETURN vRes;
--END;

--FUNCTION Compare( pS1 IN DATE, pS2 IN DATE) RETURN NUMBER AS
--  vRes INTINTEGER;
--BEGIN
--  IF (pS1 IS NULL AND pS2 IS NULL) OR pS1 = pS2 THEN
--    vRes := 1;
--  ELSE 
--    vRes := 0;
--  END IF;  
--  RETURN vRes;
--END;

--FUNCTION Compare( pS1 IN NUMBER, pS2 IN NUMBER) RETURN NUMBER AS
--  vRes INTEGER;
--BEGIN
--  IF (pS1 IS NULL AND pS2 IS NULL) OR pS1 = pS2 THEN
--    vRes := 1;
--  ELSE 
--    vRes := 0;
--  END IF;  
--  RETURN vRes;
--END;

--FUNCTION Compare( pS1 IN CLOB, pS2 IN CLOB) RETURN NUMBER AS
--  vRes INTEGER;
--BEGIN
--  IF (pS1 IS NULL AND pS2 IS NULL) OR pS1 = pS2 THEN
--    vRes := 1;
--  ELSE 
--    vRes := 0;
--  END IF;  
--  RETURN vRes;
--END;

-- Vergleich Adressen, bei Gleichheit Rckgabe 1
--FUNCTION CompareAdr( Adr1 tAdr, Adr2 tAdr) RETURN NUMBER AS
--  res NUMBER(1) := 1;
--BEGIN
--  
--  -- padr Vergleich
--  IF Compare(adr1.adr.PLZ || adr1.adr.ort || adr1.adr.ortsteil || 
--            adr1.adr.postfach || adr1.adr.STRASSE || adr1.adr.hausnr || 
--            adr1.adr.hausnrzusatz ,
--            adr2.adr.PLZ || adr2.adr.ort || adr2.adr.ortsteil || 
--            adr2.adr.postfach || adr2.adr.STRASSE || adr2.adr.hausnr || 
--            adr2.adr.hausnrzusatz
--           ) = 0 THEN
--    res := 0;      
--  END IF;   
--  
--  RETURN res;
--
--END;

-- Postanschrift der Betriebssttte direkt vom Betreiber aktualisieren
PROCEDURE BETR_POST_KOR_BETREI(vD0101 IN OUT NOCOPY vis_d0101%ROWTYPE) AS
BEGIN

  -- Daten direkt vom Betreiber lesen
  IF vD0101.D0101_ID3 <> '-1' THEN
    SELECT d3.p_land, d3.glo_a24_sid2 
     ,d3.p_plz, d3.p_ort, d3.p_ortsteil, d3.is_postfach
     , d3.p_strasse, d3.p_hausnr, d3.p_hausnrzusatz
     , d3.is_postfach   
     , d3.p_name1 
    INTO vD0101.p_land, vD0101.glo_a24_sid2 
     ,vD0101.p_plz, vD0101.p_ort, vD0101.p_ortsteil, vD0101.is_postfach
     , vD0101.p_strasse, vD0101.p_hausnr, vD0101.p_hausnrzusatz
     , vD0101.is_postfach   
     , vD0101.p_name1        
    FROM vis_d0101 d3
    WHERE d3.id = vD0101.D0101_ID3;
    
    vD0101.abw_post := 1;
    
  ELSE
    AddErrMsg('Der Betriebssttte ist kein Betreiber zugeordnet. Die Postadresse kann deshalb nicht vom Betreiber bernommen werden.');
  END IF;
END;
  
--------------------------------------------------------------------------------
PROCEDURE BETR_POST_KOR(vD0101 IN OUT NOCOPY vis_d0101%ROWTYPE, pAdr_Pst IN tAdr ) AS
BEGIN
  
  IF pAdr_Pst.id IS NOT NULL THEN

    vD0101.p_land := GetLandByA24_SID( pAdr_Pst.glo_A24_sid );

    vD0101.p_plz       := pAdr_Pst.PLZ;
    vD0101.p_ort       := pAdr_Pst.Ort; 
    vD0101.p_ortsteil  := pAdr_Pst.Ortsteil;
    IF pAdr_Pst.Postfach IS NULL THEN
      vD0101.is_postfach := 0;
      vD0101.p_strasse   := pAdr_Pst.STRASSE; 
      vD0101.p_hausnr    := pAdr_Pst.Hausnummer;
      vD0101.p_hausnrzusatz := pAdr_Pst.Hausnummernzusatz; 
    ELSE
      vD0101.is_postfach := 1;
      vD0101.p_strasse      := pAdr_Pst.Postfach;
      vD0101.p_hausnr       := NULL;
      vD0101.p_hausnrzusatz := NULL; 
    END IF;
    vD0101.glo_a24_sid2 := NVL(pAdr_Pst.glo_A24_sid, vDEFAULT_A24_SID);      
    vD0101.abw_post     := 1;

    vD0101.p_name1 := pAdr_Pst.postbezeichnung; -- 06.03.2014

  END IF;

END;


-- Fachbereiche der Betriebsstaette
-- pChkFB : Prfung und nicht vorh. anlegen
PROCEDURE AnlbtsFB(pChkFB IN BOOLEAN, vD0101 IN vis_d0101%ROWTYPE) AS
  vD010104 vis_d010104%ROWTYPE;
  vD0301 vis_d0301%ROWTYPE;
  vFB vis_d0101.FB%TYPE;
  vCnt INTEGER:= 0;
BEGIN
  IF BTS1.FAB.COUNT() > 0 THEN
    
    SELECT * INTO vD010104  -- Initialisierung mit Standardwerten
    FROM vis_d010104 WHERE id = '-1';

    SELECT * INTO vD0301  -- Initialisierung mit Standardwerten
    FROM vis_d0301 WHERE id = '-1';
    
    vD0301.bez := 'Plankontrolltermin';
    vD0301.d0101_id := BTS1.prot.d0101_id;
    vD0301.d0101_id1 := BLV_SYS.GET_MD_D0101_ID;  -- Eigenbehrde
    
    BEGIN
      SELECT d010200.id INTO vD0301.d010200_id -- angelegt durch
      FROM vis_s50 s50
      JOIN vis_d010200 d010200 ON d010200.d0102_id = s50.d0102_id
      AND d010200.deleted = 0
      AND d010200.d0101_id = BLV_SYS.GET_MD_D0101_ID
      WHERE s50.sid = vUSER_SID;
      EXCEPTION WHEN no_data_found THEN vD0301.d010200_id := '-1';
      WHEN too_many_rows THEN vD0301.d010200_id := '-1';
    END;
    
    vD0301.D010200_ID1 := vD0301.d010200_id;
    vD0301.A010801_01_SID := -1;  -- keine Ttigkeitsart
    vD0301.a0301_01_SID := 27001; -- Plankontrolltermin
    vD0301.a0301_02_SID := 4001; -- Status eingetragen (Standard)
    vD0301.STATUS := 1;
    vD0301.ort := DBO.GETADRESSE(vD0101.STRASSE, vD0101.HAUSNR, vD0101.hausnrzusatz, vD0101.PLZ, vD0101.ORT || ' ' || vD0101.Ortsteil);
    vD0301.prioritaet := 3; -- hoch
    vD0301.datumerledigt := TRUNC(SYSDATE);
    vD0301.PKS := '%';
    vD0301.REF_OBJ := '1.01';
    vD0301.REF_ID := BTS1.prot.d0101_id;
    vD0301.tabellenname := 'VIS_D0101';
    vD0301.mandant := vMandant_SID;    
    vD0301.INS_USER := vUSER_SID;
    vD0301.INS_DATE := SYSDATE;
    vD0301.UPD_USER := vUSER_SID;
    vD0301.UPD_DATE := SYSDATE; 
    vD0301.DELETED  := 0; 
    vD0301.DEL_USER := -1;
    vD0301.DEL_DATE := NULL;

    vD010104.d0101_id := BTS1.prot.d0101_id;    
    vD010104.Aktiv    := 1;
    vD010104.mandant  := vMandant_SID;    
    vD010104.INS_USER := vUSER_SID;
    vD010104.INS_DATE := SYSDATE;
    vD010104.UPD_USER := vUSER_SID;
    vD010104.UPD_DATE := SYSDATE; 
    vD010104.DELETED  := 0; 
    vD010104.DEL_USER := -1;
    vD010104.DEL_DATE := NULL;

    FOR i IN BTS1.FAB.FIRST .. BTS1.FAB.LAST LOOP
      IF BTS1.FAB(i).a0101_06_sid <> -1 THEN
        IF pChkFB THEN
          SELECT COUNT(*) INTO vCnt
          FROM vis_d010104
          WHERE deleted = 0
            AND d0101_id = vD010104.d0101_id
            AND a0101_06_sid = BTS1.FAB(i).a0101_06_sid;                
        END IF;
        
        IF vCnt = 0 THEN     
          vD010104.id := SYS_GUID();
          BTS1.FAB(i).d010104_id := vD010104.id;
          vD010104.A0101_06_SID := BTS1.FAB(i).a0101_06_sid;
          vD010104.GUELTIG_BIS  := NVL(BTS1.bts.gueltig_bis, Default_gueltig_bis); -- 12.06.2013 BTS1.FAB(i).gueltig_bis;
          vD010104.GUELTIG_VON  := NVL(BTS1.bts.gueltig_von, TRUNC(SYSDATE)); -- 12.06.2013 BTS1.FAB(i).gueltig_von;
          vD010104.A0115_SID    := NVL(BTS1.FAB(i).a0115_sid, -1);
          vD010104.A0101_01_SID := NVL(BTS1.FAB(i).a0101_01_sid, -1);
          
          -- nicht gefllte Felder
          --, A0150_SID, A0150_SID2, D010101_ID, A0115_SID, D0115_ID, A0101_01_SID, A0001_SID, CODEN,  MONITOR, BEM,ZB, STAT_REL, KPFLICHT, KONTR_FRIST, LFDNR,, KONTR_FRIST_ME,   
          SELECT CODE, CODE, BEZ INTO vD010104.FB, vD010104.CODE, vD010104.bez
          FROM vis_a0101 WHERE sid = vD010104.A0101_06_SID;
          
          INSERT INTO vis_d010104 VALUES vD010104;
         
          IF BTS1.FAB(i).ERSTKONTROLLTERMIN IS NOT NULL THEN
            vD0301.ID := SYS_GUID();
            vD0301.FB :=  vD010104.FB;
            vD0301.DATUMSTART := TRUNC(SYSDATE) +  BTS1.FAB(i).ERSTKONTROLLTERMIN;
            vD0301.DATUMENDE := vD0301.DATUMSTART;
            vD0301.TERMINBEZ := TO_CHAR(vD0301.DATUMSTART, 'DD.MM.YYYY');
            
            INSERT INTO vis_d0301 VALUES vD0301;          
            
          END IF;
          
          vFB := vFB || vD010104.FB;
        END IF;
          
      END IF;
    END LOOP;
  
    IF pChkFB THEN
      UPDATE vis_d0101
      SET FB     = FB  || vFB
        , FB0    = FB0 || vFB
        , FACHB  = blvUtils.Get_FB2KurzbV(FB  || vFB)
        , FACHB0 = blvUtils.Get_FB2KurzbV(FB0 || vFB)
        , upd_date = SYSDATE
        , upd_user = vUser_SID
      WHERE id = BTS1.prot.d0101_id; 
    END IF; 
  END IF;

END;

-- Anlage Registrierungen fr Betriebssttte und Betreiber 
-- pChk : Prfung und nicht vorh. anlegen
PROCEDURE AnlRegistrierung(pChk IN BOOLEAN, pReg IN OUT NOCOPY tbReg ,pD0101_ID IN vis_d0101.id%TYPE) AS
  vD010102 vis_d010102%ROWTYPE;
  vCnt INTEGER:= 0;
BEGIN
  IF pReg.COUNT() > 0 THEN
    
    SELECT * INTO vD010102  -- Initialisierung mit Standardwerten
    FROM vis_d010102 WHERE id = '-1';

    vD010102.d0101_id := pD0101_id;    
    vD010102.mandant  := vMandant_SID;    
    vD010102.INS_USER := vUSER_SID;
    vD010102.INS_DATE := SYSDATE;
    vD010102.UPD_USER := vUSER_SID;
    vD010102.UPD_DATE := SYSDATE; 
    vD010102.DELETED  := 0; 
    vD010102.DEL_USER := -1;
    vD010102.DEL_DATE := NULL;

    FOR i IN pReg.FIRST .. pReg.LAST LOOP
      IF pReg(i).CODE IS NOT NULL THEN
--        IF pChk THEN
--          SELECT COUNT(*) INTO vCnt
--          FROM vis_d010102
--          WHERE deleted = 0
--            AND d0101_id = vD010102.d0101_id
--            AND a010145_sid = BTS1.Reg(i).Code;                
--        END IF;
        
        IF vCnt = 0 THEN     
          vD010102.id := SYS_GUID();
          pReg(i).Ref_id := vD010102.id;

          vD010102.GUELTIG_BIS := NVL(pReg(i).gueltig_bis, Default_gueltig_bis); 
          vD010102.GUELTIG_VON := NVL(pReg(i).gueltig_von, TRUNC(SYSDATE)); 
          vD010102.nummer := pReg(i).nummer;
          -- nicht gefllte Felder
          SELECT FB, SID, BEZ 
          INTO vD010102.FB, vD010102.A010145_SID, vD010102.bez
          FROM vis_a010145 a010145
          WHERE code = pReg(i).code
          AND a010145.deleted > -2
          AND a010145.skz = TO_NUMBER(pReg(i).Typ);
        
          INSERT INTO vis_d010102 VALUES vD010102;

        END IF;
          
      END IF;
    END LOOP;
    
    FORALL i IN pReg.FIRST .. pReg.LAST 
    UPDATE d_registrierung
    SET ref_id = pReg(i).ref_id
    WHERE id = pReg(i).id;
     
  END IF;

END AnlRegistrierung; 

-- Anlage Registrierungen fr Betriebssttte und Betreiber 
-- pChk : Prfung und nicht vorh. anlegen
PROCEDURE AnlBetriebsarten(pChk IN BOOLEAN, pBar IN OUT NOCOPY tbBar ,pD0101_ID IN vis_d0101.id%TYPE) AS
  vD010101 vis_d010101%ROWTYPE;
  vCnt INTEGER:= 0;
  vCnt2 INTEGER;
BEGIN
  IF pBar.COUNT() > 0 THEN
    
    SELECT * INTO vD010101  -- Initialisierung mit Standardwerten
    FROM vis_d010101 WHERE id = '-1';

    SELECT COUNT(*) INTO vCnt2
    FROM vis_d010101 WHERE d0101_id = pD0101_ID
    AND deleted = 0
    AND a010108_skz = 2
    AND aktiv = 1
    AND gueltig_bis > SYSDATE;
    
    vD010101.d0101_id := pD0101_id;
    vD010101.aktiv    := 1;    
    vD010101.mandant  := vMandant_SID;    
    vD010101.INS_USER := vUSER_SID;
    vD010101.INS_DATE := SYSDATE;
    vD010101.UPD_USER := vUSER_SID;
    vD010101.UPD_DATE := SYSDATE; 
    vD010101.DELETED  := 0; 
    vD010101.DEL_USER := -1;
    vD010101.DEL_DATE := NULL;
    vD010101.hauptn   := 0;
    

    FOR i IN pBar.FIRST .. pBar.LAST LOOP
      IF pBar(i).CODE IS NOT NULL THEN
--        IF pChk THEN
--          SELECT COUNT(*) INTO vCnt
--          FROM vis_d010101
--          WHERE deleted = 0
--            AND d0101_id = vD010101.d0101_id
--            AND a010145_sid = BTS1.Reg(i).Code;                
--        END IF;
        
        IF vCnt = 0 THEN     
          vD010101.id := SYS_GUID();
          vD010101.id0 := vD010101.id;
          pBar(i).d010101_id := vD010101.id;

          vD010101.GUELTIG_BIS  := NVL(pBar(i).gueltig_bis, Default_gueltig_bis); 
          vD010101.GUELTIG_VON  := NVL(pBar(i).gueltig_von, TRUNC(SYSDATE));
          vD010101.angemeldet   := vD010101.gueltig_von;
          vD010101.abgemeldet   := pBar(i).gueltig_bis; 
          vD010101.gewerbsmaessig := NVL( pBar(i).gewerbsmaessig_jn, 0);
          -- nicht gefllte Felder
          SELECT FB, SID, BEZ, a010108_sid0,
          skz 
          INTO vD010101.FB, vD010101.A010108_SID, vD010101.bez, vD010101.a010108_sid0,
          vD010101.a010108_skz          
          FROM vis_a010108 a010108
          WHERE a010108.code = pBar(i).code
          AND a010108.deleted > -2
          AND a010108.skz = TO_NUMBER(pBar(i).Typ);

          vD010101.bez := NVL( pBar(i).bezeichnung, vD010101.bez);
          
          IF pBar.COUNT() = 1 AND vD010101.a010108_skz = 2 AND vCnt2 = 0 THEN 
            vD010101.hauptn := 1;
          ELSE
            vD010101.hauptn := CASE WHEN UPPER(pBar(i).geltungsbereich) = vHauptBA THEN 1 ELSE 0 END;        
          END IF; 

          INSERT INTO vis_d010101 VALUES vD010101;

        END IF;
          
      END IF;
    END LOOP;
    
    FORALL i IN pBar.FIRST .. pBar.LAST 
    UPDATE d_betriebsart
    SET d010101_id = pBar(i).d010101_id
    WHERE id = pBar(i).id;
     
  END IF;

END AnlBetriebsarten; 


PROCEDURE BETR_Post_Defa( vD0101 IN OUT NOCOPY vis_d0101%ROWTYPE) AS
BEGIN

  vD0101.p_plz          := vD0101.plz;
  vD0101.p_ort          := vD0101.ort;      
  vD0101.p_ortsteil     := vD0101.ortsteil;
  vD0101.is_postfach    := 0;
  vD0101.p_strasse      := vD0101.strasse; 
  vD0101.p_hausnr       := vD0101.hausnr;
  vD0101.p_hausnrzusatz := vD0101.hausnrzusatz;
  vD0101.p_land         := vD0101.Land;      
  vD0101.glo_a24_sid2   := vD0101.glo_A24_sid;
  vD0101.abw_post       := 0;
  
--10.07.2014   
--  vD0101.p_bez_art   := vD0101.bez_art;
--  vD0101.p_anrede    := CASE WHEN vD0101.bez_art = 'F' AND vD0101.f_anrede IS NOT NULL THEN vD0101.f_anrede ELSE vD0101.anrede END;
--  IF vD0101.bez_art = 'F' THEN  -- 16.04.2014 beim bez_art N neu generieren
--    vD0101.p_name      := vD0101.bez;    
--  ELSE
--    vD0101.p_name := CreateD0101P_name(vD0101.NNAME, vD0101.VNAME, vD0101.VORSATZ_NNAME, vD0101.NACHSATZ_NNAME, vD0101.TITEL);
--  END IF;
--  vD0101.p_name1     := vD0101.name1;  -- bleibt 
  vD0101.briefanrede := GetBriefanrede(vD0101.p_anrede);

END;

PROCEDURE AnlageBetreiberPersonal(pPersonal_PAdr IN OUT NOCOPY tbPersonal_Adr_Pst, 
                                  pD0101_ID IN VARCHAR2, pA0101_03_SID IN INTEGER,
                                  pInhaber IN INTEGER) AS
  vD0102   vis_d0102%ROWTYPE;
  vD010200 vis_d010200%ROWTYPE;
  --vD010202 vis_d010202%ROWTYPE;
  --vA0101_70_sid vis_d010202.a0101_70_sid%TYPE;  
  vSysdate DATE := SYSDATE;
BEGIN

  -- Personal zum Betreiber einschl. Adresse
  IF pPERSONAL_PADR.COUNT > 0 THEN -- Personal vorh.

    SELECT * INTO vD0102   -- Initialisierung
    FROM vis_d0102 WHERE id = '-1';

    vD0102.MANDANT  := vMandant_SID; 
    vD0102.INS_USER := vUser_SID;
    vD0102.INS_DATE := vSYSDATE;
    vD0102.UPD_USER := vUser_SID;
    vD0102.UPD_DATE := vSYSDATE;
    vD0102.DELETED  := 0;
    vD0102.DEL_USER := '-1';
    vD0102.DEL_DATE := NULL;

    SELECT * INTO vD010200   -- Initialisierung
    FROM vis_d010200 WHERE id = '-1';

    vD010200.d0101_id   := pD0101_id;
    vD010200.D0101_id2  := pD0101_id;
    vD010200.D0101_id3  := pD0101_id;
    vD010200.MANDANT    := vMandant_SID; 
    vD010200.INS_USER   := vUser_SID;
    vD010200.INS_DATE   := vSYSDATE;
    vD010200.UPD_USER   := vUser_SID;
    vD010200.UPD_DATE   := vSYSDATE;
    vD010200.DELETED    := 0;
    vD010200.DEL_USER   := '-1';
    vD010200.DEL_DATE   := NULL;
    vD010200.inhaber    := pInhaber;
    vD010200.BETRIEBSPERSONAL := 1;

     
    FOR i IN pPERSONAL_PADR.FIRST .. pPERSONAL_PADR.LAST LOOP
      -- D0102
      IF NVL(pPERSONAL_PADR(i).ref_id, '-1') = '-1' THEN


        pPERSONAL_PADR(i).ref_id := SYS_GUID;
          
        UPDATE d_personal 
        SET ref_id = pPERSONAL_PADR(i).ref_id 
        WHERE id = pPERSONAL_PADR(i).id ;
      END IF;
        
      vD0102.ID := pPERSONAL_PADR(i).ref_id ;
        
      --CODE, CODEN,  BEM, 
      --IF pPERSONAL_PADR(i).bezeichnung IS NULL THEN
        vD0102.BEZ := CreateD0102Bez( pPERSONAL_PADR(i).Anrede, pPERSONAL_PADR(i).TITEL, pPERSONAL_PADR(i).VORNAME , pPERSONAL_PADR(i).NACHNAME, pPERSONAL_PADR(i).VORSATZ_NACHNAME, pPERSONAL_PADR(i).NACHSATZ_NACHNAME );
      --ELSE
      --  vD0102.BEZ := pPERSONAL_PADR(i).bezeichnung;
      --END IF;        
      vD0102.NNAME    := pPERSONAL_PADR(i).NACHNAME;
      vD0102.VNAME    := pPERSONAL_PADR(i).VORNAME;
      vD0102.TITEL    := pPERSONAL_PADR(i).TITEL;
      vD0102.ANREDE   := pPERSONAL_PADR(i).Anrede;
      vD0102.NACHSATZ_NNAME := pPERSONAL_PADR(i).NACHSATZ_NACHNAME;
      vD0102.VORSATZ_NNAME  := pPERSONAL_PADR(i).VORSATZ_NACHNAME;
      --vD0102.ZUS_BEZ  
      vD0102.LAND     := GetLandByA24_SID(pPERSONAL_PADR(i).glo_a24_SID);  -- 05.08.2013 pPERSONAL_PADR(i).Staat; 
      vD0102.PLZ      := pPERSONAL_PADR(i).PLZ;
      vD0102.ORT      := pPERSONAL_PADR(i).Ort;
      vD0102.ORTSTEIL := pPERSONAL_PADR(i).Ortsteil;
      vD0102.STRASSE  := pPERSONAL_PADR(i).STRASSE;
      vD0102.HAUSNR   := pPERSONAL_PADR(i).Hausnummer;
      vD0102.HAUSNRZUSATZ := pPERSONAL_PADR(i).Hausnummernzusatz;
      --vD0102.GEMEINDE 
      vD0102.GKZ      := pPERSONAL_PADR(i).gkz;    
      --, STAATSBUERGERSCHAFT, 
      
      -- Kommunikationsmittel

      vD0102.GEB_DATUM := pPERSONAL_PADR(i).Geburtsdatum;
      --, GEB_ORT, BERUFSWEG, ZB, FB, BRIEFANREDE, BANK, BLZ, KONTO, PERS_ID, 
      vD0102.briefanrede := GetBriefanrede(vD0102.anrede);
        
      INSERT INTO vis_d0102 VALUES vD0102;

      -- D010200          
      vD010200.ID := SYS_GUID();
      vD010200.bez := vD0102.bez;
      vD010200.d0102_id := vD0102.id;        
      vD010200.HAUPTANSPRECHPARTNER := NVL(pPERSONAL_PADR(i).HAUPTANSPRECHPARTNER_JN, 0);
      vD010200.bem          := pPersonal_PAdr(i).bemerkung;
      vD010200.kom_tel      := pPERSONAL_PADR(i).Telefon;
      vD010200.kom_fax      := pPERSONAL_PADR(i).fax;
      vD010200.kom_mobil    := pPERSONAL_PADR(i).Mobil;
      vD010200.kom_internet := pPERSONAL_PADR(i).Internet;
      vD010200.kom_email    := pPERSONAL_PADR(i).email;
      vD010200.kom_sonst    := pPERSONAL_PADR(i).weitere;      
            
      INSERT INTO vis_d010200 VALUES vD010200;
        
      IF vD010200.HAUPTANSPRECHPARTNER = 1 THEN
        UPDATE vis_d0101
        SET nname = vD0102.nname
          , vname = vD0102.vname
          , nachsatz_nname = vD0102.nachsatz_nname
          , vorsatz_nname = vD0102.vorsatz_nname
          , titel = vD0102.titel
          , anrede = vD0102.anrede
          , d010200_id2 = vD010200.id 
          , upd_date = vSYSDATE
        WHERE id = pD0101_id;
              
      END IF;
      
      -- Personalfunktion ber die Rechtsform anlegen   
      IF pA0101_03_SID > 0 OR pPERSONAL_PADR(i).a0101_70_sid > 0 THEN
        InsertD010202(pA0101_03_SID, vD010200.d0101_id,  vD010200.id, pPERSONAL_PADR(i).a0101_70_sid);    
      END IF;
    END LOOP; 
  
  END IF;   -- Betreiber Personal      

END;

-- Ermittelt die Rechtsform fr den Betreiber2 anhand der bergebenen 
-- Rechtsform vom Betreibers1  
FUNCTION GetRechtsformBetreiber2(pA0101_03_sid IN INTEGER) RETURN INTEGER AS
  v1 INTEGER := -1;
BEGIN
  CASE pA0101_03_sid  
  WHEN 643001 THEN -- 3001 Limited und Co.KG
    v1 := 642001;  -- 30 Limited
  WHEN 1151001 THEN -- GmbH und Co. OHG
    v1 := 4;  -- 03 GmbH
  WHEN 5 THEN -- 04 GmbH und Co. KG
    v1 := 4;   -- 03 GmbH
  WHEN 1219001 THEN -- 0302 UG (haftungsbeschrnkt) und Co. KG
    v1 := 1187001; -- 0301 UG (haftungsbeschrnkt)
  WHEN 2539001 THEN -- 1403 AG  Co. KG
    v1 := 3;        -- 02 AG
  WHEN 2538001 THEN -- 1402 Stiftung und Co. KG
    v1 := 400001;   -- 23 Stiftung des privaten Rechts    
  ELSE
    v1 := -1;
  END CASE;
  RETURN v1;
END;

-- Betreiber vom Betreiber anlegen
-- pModus :
--  0 : Bei der Erfassung einer Betriebssttte wird der vorhandene Betreiber 
--      2. Ordnung nicht aktualisiert
--  1 : nicht vorhandene Betreiber wird angelegt, vorhandene Betreiber wird aktualisiert 
--      wird bei der Bereinigung angewendet 
FUNCTION AnlageBetreiber_Betreiber(pModus IN INTEGER)  RETURN VARCHAR2 AS
  vD0101    vis_d0101%ROWTYPE;
  vRes      vis_d0101.id%TYPE := '-1';
  
  PROCEDURE VerarbeitungBTR2(pInsert IN BOOLEAN) AS
  BEGIN
  
    vD0101.bez          := BTS1.Btr2_Btr.BEZEICHNUNG;
    vD0101.name1        := BTS1.Btr2_Btr.BEZEICHNUNG2;
    vD0101.P_NAME       := BTS1.Btr2_Btr.BEZEICHNUNG;
    vD0101.P_NAME1      := BTS1.Btr2_Btr.BEZEICHNUNG2;      
    vD0101.TITEL        := BTS1.Btr2_Btr.TITEL;
    vD0101.nname        := BTS1.Btr2_Btr.NACHNAME;
    vD0101.vname        := BTS1.Btr2_Btr.VORNAME;
    vD0101.vorsatz_nname  := BTS1.Btr2_Btr.VORSATZ_NACHNAME;
    vD0101.nachsatz_nname := BTS1.Btr2_Btr.NACHSATZ_NACHNAME;
    vD0101.bem          := BTS1.Btr2_Btr.bemerkung;
    -- Rechtsform ber Betreiber1 ermitteln   
    vD0101.a0101_03_sid := GetRechtsformBetreiber2(BTS1.fkt_inh.pers.a0101_03_sid);
    BTS1.Btr2_Btr.a0101_03_sid := vD0101.a0101_03_sid;
    
    vD0101.ZB           := vMandantZB; 
    vD0101.FB           := '-'; 
    vD0101.FB0          := '-'; 
    --vD0101.FACHB        := blvUtils.get_fb2KurzbV(vD0101.FB); -- 24.10.2014
    --vD0101.FACHB0       := vD0101.Fachb;  -- 24.10.2014
    vD0101.SKZ          := 99; 

    --11.10.2013 IF BTS1.prot.parameter LIKE '%chk_betreiber_kurzb2=1%' THEN     
      vD0101.HIT_BEZ_1    := BTS1.Btr2_Btr.KURZBEZEICHNUNG1; 
      vD0101.HIT_BEZ_2    := BTS1.Btr2_Btr.KURZBEZEICHNUNG2;
      --vD0101.HIT_P_BEZ_1  := BTS1.Btr2_Btr.KURZBEZEICHNUNG1;
      --vD0101.HIT_P_BEZ_2  := BTS1.Btr2_Btr.KURZBEZEICHNUNG2;
--    ELSE
--      vD0101.HIT_BEZ_1    := SUBSTR(BTS1.Btr2_Btr.bezeichnung,1,30); 
--      vD0101.HIT_BEZ_2    := SUBSTR(BTS1.Btr2_Btr.bezeichnung2,1,30);
--      vD0101.HIT_P_BEZ_1  := SUBSTR(BTS1.Btr2_Btr.bezeichnung,1,30);
--      vD0101.HIT_P_BEZ_2  := SUBSTR(BTS1.Btr2_Btr.bezeichnung2,1,30);
--    END IF;
      
    IF BTS1.Btr2_Btr.TYP IN( vTypeJP, 'LP') THEN
      vD0101.F_ANREDE := BTS1.Btr2_Btr.Anrede;
      vD0101.ANREDE   := NULL;      
    ELSE
      vD0101.F_ANREDE := NULL;
      vD0101.ANREDE   := BTS1.Btr2_Btr.Anrede;      
    END IF; 
    vD0101.P_ANREDE := BTS1.Btr2_Btr.Anrede;

    vD0101.briefanrede  := GetBriefanrede(vD0101.p_anrede);
    
    -- Standortanschrift vorhanden
    IF NOT EmptyID(BTS1.Btr2_Adr_Sto.id) THEN 
      vD0101.PLZ          := BTS1.Btr2_Adr_Sto.PLZ;
      vD0101.ORT          := BTS1.Btr2_Adr_Sto.Ort;
      vD0101.ORTSTEIL     := BTS1.Btr2_Adr_Sto.Ortsteil;
      vD0101.STRASSE      := BTS1.Btr2_Adr_Sto.STRASSE; -- nur eins gefllt 
      vD0101.HAUSNR       := BTS1.Btr2_Adr_Sto.Hausnummer;
      vD0101.hausnrzusatz := BTS1.Btr2_Adr_Sto.Hausnummernzusatz;
      vD0101.glo_a24_sid  := NVL(BTS1.Btr2_Adr_Sto.glo_a24_sid, vDEFAULT_A24_SID);
      vD0101.BEZ_ART      := CrtD0101_BEZ_ART(BTS1.Btr2_Btr.TYP, BTS1.Btr2_Btr.a0101_03_sid); 
      vD0101.land         := GetLandByA24_SID(BTS1.Btr2_Adr_Sto.glo_a24_sid);
      vD0101.gkz          := BTS1.Btr2_Adr_Sto.gkz;      
      -- keine Postanschrift vorhanden
      IF EmptyID(BTS1.Btr2_Adr_Pst.id) THEN
        BETR_POST_DEFA( vD0101 );
      END IF;          
    END IF;
    
    -- Postanschrift vorhanden
    IF NOT EmptyID(BTS1.Btr2_Adr_Pst.id) THEN 
      vD0101.P_PLZ          := BTS1.Btr2_Adr_Pst.PLZ;
      vD0101.P_ORT          := BTS1.Btr2_Adr_Pst.Ort;
      vD0101.P_ORTSTEIL     := BTS1.Btr2_Adr_Pst.Ortsteil;
      IF BTS1.Btr2_Adr_Pst.Postfach IS NULL THEN
        vD0101.Is_Postfach := 0;
        vD0101.P_STRASSE := BTS1.Btr2_Adr_Pst.STRASSE;
      ELSE
        vD0101.Is_Postfach := 1;
        vD0101.P_STRASSE := BTS1.Btr2_Adr_Pst.Postfach; 
      END IF; 
      vD0101.P_HAUSNR       := BTS1.Btr2_Adr_Pst.Hausnummer;
      vD0101.P_hausnrzusatz := BTS1.Btr2_Adr_Pst.Hausnummernzusatz;
      vD0101.P_BEZ_ART      := CrtD0101_BEZ_ART(BTS1.Btr2_Btr.TYP, BTS1.Btr2_Btr.a0101_03_sid);
      vD0101.glo_a24_sid2   := NVL(BTS1.Btr2_Adr_Pst.glo_a24_sid, vDEFAULT_A24_SID);
      vD0101.p_land         := GetLandByA24_SID(BTS1.Btr2_Adr_Pst.glo_a24_sid);      
      vD0101.gkz            := NVL(vD0101.GKZ, BTS1.Btr2_Adr_Pst.gkz);      
      vD0101.p_name1 := NVL( BTS1.btr2_adr_pst.postbezeichnung, vD0101.p_name1);
      -- keine Standortanschrift vorhanden, dann von Postanschrift bernehmen      
      IF EmptyID(BTS1.Btr2_Adr_Sto.id) THEN
        vD0101.PLZ          := vD0101.P_PLZ;         
        vD0101.ORT          := vD0101.P_ORT;         
        vD0101.ORTSTEIL     := vD0101.P_ORTSTEIL;    
        vD0101.STRASSE      := vD0101.P_STRASSE;     
        vD0101.HAUSNR       := vD0101.P_HAUSNR;      
        vD0101.hausnrzusatz := vD0101.P_hausnrzusatz;
        vD0101.BEZ_ART      := vD0101.P_BEZ_ART; 
        vD0101.glo_a24_sid  := vD0101.glo_a24_sid2; 
        vD0101.land         := vD0101.p_land;
        IF BTS1.Btr2_Adr_Pst.Postfach IS NOT NULL THEN
          vD0101.abw_post := 1;
        END IF;
                 
      END IF;
      
    END IF;

    vD0101.P_BEZ_ART  := CrtD0101_BEZ_ART(BTS1.Btr2_Btr.TYP,  BTS1.Btr2_Btr.a0101_03_sid);
    vD0101.Ambulant_jn:= 0;
    vD0101.daten_herkunft := vVerfahren;

    vD0101.kom_tel      := BTS1.Btr2_Btr.Telefon;
    vD0101.kom_fax      := BTS1.Btr2_Btr.fax;
    vD0101.kom_mobil    := BTS1.Btr2_Btr.Mobil;
    vD0101.kom_internet := BTS1.Btr2_Btr.Internet;
    vD0101.kom_sonst    := BTS1.Btr2_Btr.weitere;
    vD0101.kom_email    := BTS1.Btr2_Btr.email;     

    vRes := vD0101.id;  
    
    IF pInsert THEN
      INSERT INTO vis_d0101 VALUES vD0101;
    ELSE
      UPDATE vis_d0101 
      SET ROW = vD0101
      WHERE id = vD0101.id;
    END IF;
      
    IF ChkMsgMandant = 1 THEN 
      COMMIT;
    END IF;
         
    BTS1.Btr2_Btr.ref_id := vD0101.ID;
    
    UPDATE d_personal
    SET ref_id = BTS1.Btr2_Btr.ref_id
    WHERE id = BTS1.Btr2_Btr.id;
            
    -- Betreiber - Betreiber - Personal
    -- Personal zum Betreiber einschl. Adresse
    -- kommt beim Betreiber2 nicht zur Anwendung
    IF GetRechtsformTyp(BTS1.Btr2_Btr.a0101_03_sid ) = 'N' AND
    BTS1.Btr2_Personal_Adr_Pst.COUNT = 0 THEN 
      -- bei Einzelunternehmen ohne Personal aus BEZEICHNUNG, VorBEZEICHNUNG .. Personal erzeugen
      -- damit in AnlageBetreiberPersonal Personal zum Angelegen vorh. ist
      BTS1.Btr2_Personal_Adr_Pst.EXTEND;
      BTS1.Btr2_Personal_Adr_Pst(1).NACHNAME := BTS1.Btr2_Btr.NACHNAME;
      BTS1.Btr2_Personal_Adr_Pst(1).VORNAME := BTS1.Btr2_Btr.VORNAME;

      BTS1.Btr2_Personal_Adr_Pst(1).TITEL := BTS1.Btr2_Btr.TITEL;
      BTS1.Btr2_Personal_Adr_Pst(1).Anrede := BTS1.Btr2_Btr.Anrede;
      BTS1.Btr2_Personal_Adr_Pst(1).NACHSATZ_NACHNAME := BTS1.Btr2_Btr.NACHSATZ_NACHNAME;
      BTS1.Btr2_Personal_Adr_Pst(1).VORSATZ_NACHNAME := BTS1.Btr2_Btr.VORSATZ_NACHNAME;
      BTS1.Btr2_Personal_Adr_Pst(1).HAUPTANSPRECHPARTNER_JN := 1;
      BTS1.Btr2_Personal_Adr_Pst(1).bemerkung := BTS1.Btr2_btr.bemerkung;
       
      IF BTS1.Btr2_Adr_Pst.id <> '-1' THEN -- Postadresse vorh.
        BTS1.Btr2_Personal_Adr_Pst(1).id := BTS1.Btr2_Adr_Pst.id;       
        BTS1.Btr2_Personal_Adr_Pst(1).glo_a24_SID := BTS1.Btr2_Adr_Pst.glo_a24_SID;
        BTS1.Btr2_Personal_Adr_Pst(1).PLZ := BTS1.Btr2_Adr_Pst.PLZ;
        BTS1.Btr2_Personal_Adr_Pst(1).Ort := BTS1.Btr2_Adr_Pst.Ort;
        BTS1.Btr2_Personal_Adr_Pst(1).Ortsteil := BTS1.Btr2_Adr_Pst.Ortsteil;
        BTS1.Btr2_Personal_Adr_Pst(1).STRASSE := BTS1.Btr2_Adr_Pst.STRASSE;
        BTS1.Btr2_Personal_Adr_Pst(1).Hausnummer := BTS1.Btr2_Adr_Pst.Hausnummer;
        BTS1.Btr2_Personal_Adr_Pst(1).Hausnummernzusatz := BTS1.Btr2_Adr_Pst.Hausnummernzusatz;
        BTS1.Btr2_Personal_Adr_Pst(1).GKZ := BTS1.Btr2_Adr_Pst.GKZ;
      END IF;  
      
      -- Kommunikationsmittel
      BTS1.Btr2_Personal_Adr_Pst(1).Telefon := BTS1.Btr2_Btr.Telefon;
      BTS1.Btr2_Personal_Adr_Pst(1).fax := BTS1.Btr2_Btr.fax;
      BTS1.Btr2_Personal_Adr_Pst(1).Mobil := BTS1.Btr2_Btr.Mobil;
      BTS1.Btr2_Personal_Adr_Pst(1).Internet := BTS1.Btr2_Btr.Internet;
      BTS1.Btr2_Personal_Adr_Pst(1).email := BTS1.Btr2_Btr.email;
      BTS1.Btr2_Personal_Adr_Pst(1).weitere := BTS1.Btr2_Btr.weitere;
           
      BTS1.Btr2_Personal_Adr_Pst(1).Geburtsdatum := BTS1.Btr2_Btr.Geburtsdatum;      

      AnlageBetreiberPersonal(BTS1.Btr2_Personal_Adr_Pst, vD0101.ID, BTS1.Btr2_Btr.a0101_03_sid, 1);

    ELSE
      IF  BTS1.Prot.DATENHERKUNFT IN ('BEA') THEN
        AnlageBetreiberPersonal(BTS1.Btr2_Personal_Adr_Pst, vD0101.ID, BTS1.Btr2_Btr.a0101_03_sid, 0);
      ELSE
        AnlageBetreiberPersonal(BTS1.Btr2_Personal_Adr_Pst, vD0101.ID, BTS1.Btr2_Btr.a0101_03_sid, 1);
      END IF;            
    END IF;
  
  END VerarbeitungBTR2;
BEGIN

  CASE
  WHEN BTS1.Btr2_Btr.id <> '-1' AND NOT EmptyID(BTS1.Btr2_Btr.ref_id) AND pModus = 0 THEN
    vRes := BTS1.Btr2_Btr.ref_id;
    
  WHEN BTS1.Btr2_Btr.id <> '-1' AND NOT EmptyID(BTS1.Btr2_Btr.ref_id) AND pModus = 1 THEN
    SELECT * INTO vD0101 FROM vis_d0101 WHERE id = BTS1.Btr2_Btr.ref_id; -- Daten Lesen
    vD0101.UPD_USER     := vUser_sid;
    vD0101.UPD_DATE     := SYSDATE;
    VerarbeitungBTR2(False);  
  WHEN BTS1.Btr2_Btr.id <> '-1' AND EmptyID(BTS1.Btr2_Btr.ref_id) THEN
    SELECT * INTO vD0101 FROM vis_d0101 WHERE id = '-1'; -- Initialisierung
  
    vD0101.id        := SYS_GUID(); 
    vD0101.d0101_id2 := vD0101.id;
    vD0101.d0101_id3 := vD0101.id;
    vD0101.INS_USER  := vUser_sid;
    vD0101.INS_DATE  := SYSDATE;
    vD0101.UPD_USER  := vUser_sid;
    vD0101.UPD_DATE  := SYSDATE;
    vD0101.MANDANT   := vMandant_SID;
    vD0101.DEL_USER  := -1;
    vD0101.DELETED   := 0;
    vD0101.code      := NULL;
    
    vD0101.anmeldung := TRUNC( NVL(BTS1.bts.gueltig_von, SYSDATE));
    vD0101.abmeldung := NULL; --BTS1.bts.gueltig_bis;
    
    VerarbeitungBTR2(True);  
  END CASE;

  RETURN vRes;

END;  -- AnlageBetreiber_Betreiber

-- Generieren Bezeichnung: Nachname, Vorname Vorsatz, Nachsatz, Titel 
FUNCTION CreateD0101Bez(pnname IN VARCHAR2, pvname IN VARCHAR2,
                         pVorsatz IN VARCHAR2, pNachsatz  IN VARCHAR2, 
                         pTITEL IN VARCHAR2) RETURN VARCHAR2 AS
v1 VARCHAR2(450);
BEGIN

  v1 := Pnname ||
         CASE WHEN pvname || pVorsatz IS NOT NULL THEN  ', ' || TRIM(pvname || ' ' || pVorsatz) END || 
         CASE WHEN pNachsatz IS NOT NULL THEN  ', ' || pNachsatz END || 
         CASE WHEN pTITEL IS NOT NULL THEN ', ' || pTITEL END;

  IF LENGTH(v1) > 128 THEN
    v1 := SUBSTR(v1, 1, 126) || '..';
  END IF;
  
  RETURN v1;
         
END;

-- Anlage Betreiber
FUNCTION AnlageBetreiber(pFkt_inh IN OUT NOCOPY tFnc, pZB IN VARCHAR2) RETURN VARCHAR2 AS
  vD0101    vis_d0101%ROWTYPE;
  vD0101_ID3 vis_d0101.d0101_id3%TYPE;
BEGIN
      
  IF NOT EmptyID(pFkt_Inh.Pers.ref_id) THEN -- Betreiber in iP vorhanden
    vD0101.ID := pFkt_Inh.Pers.ref_id;
  ELSE

    SELECT * INTO vD0101 FROM vis_d0101 WHERE id = '-1'; -- Initialisierung
    IF BTS1.prot.parameter LIKE '%Mode=BT%' THEN -- nur Betreiber anlegen
     
      IF EmptyID(BTS1.prot.d0101_id) THEN
        BTS1.prot.d0101_id := SYS_GUID();
              
        UPDATE d_protokoll
        SET d0101_id = BTS1.prot.d0101_id
        WHERE id = BTS1.prot.id;
               
      END IF;
      pFkt_Inh.Pers.ref_id := BTS1.prot.d0101_id;
    
    ELSE
      pFkt_Inh.Pers.ref_id := SYS_GUID();
    END IF;
      
    UPDATE d_personal -- neue ID  
    SET ref_id = pFkt_Inh.Pers.ref_id
    WHERE id = pFkt_Inh.Pers.id;
          
    vd0101.id           := pFkt_Inh.Pers.ref_id;
    vD0101.mandant      := vMandant_SID;
    vD0101.code         := NULL;
    vD0101.D0101_ID2    := vD0101.id;    
    vD0101.D0101_ID3    := vD0101.id; 
    vD0101.D0101_ID4    := '-1';    
    vD0101.D0101_ID10   := '-1';    
    vD0101.D010200_ID   := '-1';    
    vD0101.D010200_ID2  := '-1';    
    vD0101.A030501_01_SID := -1;
    vD0101.A030501_02_SID := -1;
    vD0101.A030502_SID    := -1;
    vD0101.A0113_100_SID  := -1;
    vD0101.A010108_SID    := -1;
    vD0101.A030501_05_SID := -1;
    vD0101.A0101_03_SID := pFkt_Inh.Pers.A0101_03_SID;
    vD0101.GLO_A24_SID  := NVL(pFKT_INH.Adr_Sto.glo_a24_sid, vDEFAULT_A24_SID);
    vD0101.GLO_A24_SID2 := NVL(pFKT_INH.Adr_Pst.glo_a24_sid, vDEFAULT_A24_SID);
    vD0101.s09_SID      := vDEFAULT_S09_SID;
    vD0101.SKZ          := 99;
    -- 10.07.2014
    vD0101.BEZ_ART      := CrtD0101_BEZ_ART( pFKT_INH.pers.TYP, pFKT_INH.pers.a0101_03_sid);
    
    IF vD0101.BEZ_ART = 'F' THEN
      vD0101.BEZ := pFKT_INH.pers.BEZEICHNUNG;
      vD0101.P_NAME := pFKT_INH.pers.BEZEICHNUNG; --10.07.2014       
    ELSE 
      vD0101.BEZ := CreateD0101Bez( pFKT_INH.pers.NACHNAME,
                                    pFKT_INH.pers.VORNAME, 
                                    pFKT_INH.pers.VORSATZ_NACHNAME, 
                                    pFKT_INH.pers.NACHSATZ_NACHNAME,
                                    pFKT_INH.pers.TITEL); 

      --10.07.2014                                    
      vD0101.P_NAME := CreateD0101P_Name(                               
                                    pFKT_INH.pers.NACHNAME,
                                    pFKT_INH.pers.VORNAME, 
                                    pFKT_INH.pers.VORSATZ_NACHNAME, 
                                    pFKT_INH.pers.NACHSATZ_NACHNAME,
                                    pFKT_INH.pers.TITEL);

                                    
    END IF;
       
    vD0101.P_NAME1      := pFKT_INH.pers.BEZEICHNUNG2;          
    vD0101.Name1        := pFKT_INH.pers.BEZEICHNUNG2;
    vD0101.INS_USER     := vUser_sid;
    vD0101.INS_DATE     := SYSDATE;
    vD0101.UPD_USER     := vUser_sid;
    vD0101.UPD_DATE     := SYSDATE;
    vD0101.DEL_USER     := -1;
    vD0101.DELETED      := 0;
    vD0101.TITEL        := pFKT_INH.pers.TITEL;
    vD0101.nname        := pFKT_INH.pers.NACHNAME;
    vD0101.vname        := pFKT_INH.pers.VORNAME;
    vD0101.vorsatz_nname  := pFkt_inh.pers.VORSATZ_NACHNAME;
    vD0101.nachsatz_nname := pFkt_inh.pers.NACHSATZ_NACHNAME;
    vD0101.ANMELDUNG    := TRUNC( NVL(BTS1.bts.gueltig_von, SYSDATE));
    vD0101.ABMELDUNG    := NULL;  --TRUNC(BTS1.bts.gueltig_bis);
    vD0101.bem          := pFkt_inh.pers.bemerkung;
      
    -- Standort 
    vD0101.LAND         := GetLandByA24_SID(vD0101.GLO_A24_SID);  -- 05.08.2013 pFKT_INH.adr2.padr.Staat;
    vD0101.PLZ          := pFKT_INH.Adr_Sto.PLZ;
    vD0101.ORT          := pFKT_INH.Adr_Sto.Ort;
    vD0101.ORTSTEIL     := pFKT_INH.Adr_Sto.Ortsteil;
    vD0101.STRASSE      := pFKT_INH.Adr_Sto.STRASSE; 
    vD0101.HAUSNR       := pFKT_INH.Adr_Sto.Hausnummer;
    vD0101.hausnrzusatz := pFKT_INH.Adr_Sto.Hausnummernzusatz;
    vD0101.adresszusatz := pFKT_INH.Adr_Sto.ADRESSZUSATZ;
    vD0101.FLURSTUECK   := pFKT_inh.Adr_Sto.Flurstueck;
    vD0101.flurnummer   := pFKT_inh.Adr_Sto.Flurnummer;
    vD0101.GEMARKUNG    := pFKT_inh.Adr_Sto.Gemarkung;                          
    vD0101.GKZ          := pFKT_INH.Adr_Sto.gkz;   
    --pFKT_INH.adr.verw.bundesland || pFKT_INH.adr.verw.bezirk || pFKT_INH.adr.verw.kreis || pFKT_INH.adr.verw.gemeinde;
    vD0101.daten_herkunft := vVerfahren;
     
    --Postanschrift
    if BTS1.prot.parameter LIKE '%opt_betreiber_postadresse=1%' THEN
      -- abweichende Postanschrift
      BETR_POST_KOR(vD0101, pFKT_INH.Adr_Pst);   
    ELSE -- keine Postanschrift vorhanden, Postanschrift wie Standort setzen
      BETR_POST_DEFA( vD0101 );
    END IF;
    
    vD0101.KOM_TEL      := pFKT_INH.pers.Telefon; 
    vD0101.KOM_FAX      := pFKT_INH.pers.fax;
    vD0101.KOM_MOBIL    := pFKT_INH.pers.Mobil;
    vD0101.KOM_EMAIL    := pFKT_INH.pers.email;
    vD0101.KOM_SONST    := pFKT_INH.pers.weitere;
    vD0101.kom_internet := pFKT_INH.pers.Internet;
        
    vD0101.ZB           := NVL(pZB, vMandantZB);    
    vD0101.FB           := '-'; 
    vD0101.FB0          := '-';       
    vD0101.FACHB        := blvUtils.get_fb2KurzbV(vD0101.FB);
    vD0101.FACHB0       := vD0101.Fachb; 

    --vD0101.BEM, 
    -- 11.10.2013 IF BTS1.prot.parameter LIKE '%chk_betreiber_kurzb=1%' THEN    
      vD0101.HIT_BEZ_1    := pFkt_inh.pers.KURZBEZEICHNUNG1; 
      vD0101.HIT_BEZ_2    := pFkt_inh.pers.KURZBEZEICHNUNG2;
      --vD0101.HIT_P_BEZ_1  := pFkt_inh.pers.KURZBEZEICHNUNG1;
      --vD0101.HIT_P_BEZ_2  := pFkt_inh.pers.KURZBEZEICHNUNG2;
--    ELSE
--      vD0101.HIT_BEZ_1    := SUBSTR(pFkt_inh.pers.bezeichnung, 1, 30); 
--      vD0101.HIT_BEZ_2    := SUBSTR(pFkt_inh.pers.bezeichnung2, 1, 30);
--      vD0101.HIT_P_BEZ_1  := SUBSTR(pFkt_inh.pers.bezeichnung, 1, 30);
--      vD0101.HIT_P_BEZ_2  := SUBSTR(pFkt_inh.pers.bezeichnung2, 1, 30);
--    END IF;
      
    IF pFKT_INH.PERS.TYP IN( vTypeJP, 'LP') THEN
      vD0101.F_ANREDE   := pFKT_INH.pers.Anrede;
      vD0101.anrede     := NULL;    
    ELSE
      vD0101.F_ANREDE   := NULL;  
      vD0101.anrede     := pFKT_INH.pers.Anrede;    
    END IF; 
    vD0101.P_ANREDE     := pFKT_INH.pers.Anrede;

    vD0101.briefanrede  := GetBriefanrede(vD0101.p_anrede);    

    
    --vD0101.P_NAME2      := pFKT_INH.pers.VORNAME;    
      
    vD0101.P_BEZ_ART  := CrtD0101_BEZ_ART( pFKT_INH.pers.TYP, pFKT_INH.pers.a0101_03_sid);
      
    vD0101.HOCHWERT   := pFkt_inh.Adr_Sto.Hochwert;
    vD0101.RECHTSWERT := pFKT_inh.Adr_Sto.Rechtswert; 
    vD0101.X_WERT     := pFKT_inh.Adr_Sto.X_Wert; 
    vD0101.Y_WERT     := pFKT_inh.Adr_Sto.Y_Wert;
    vD0101.gis_quelle := pFKT_inh.Adr_Sto.Koordinatenherkunft;
    vD0101.s09_sid    := NVL(pFKT_inh.Adr_Sto.s09_sid, vDEFAULT_S09_SID);
    
    vD0101.Ambulant_jn:= 0;
        
    IF BTS1.Btr2_Btr.id <> '-1' THEN -- Betreiber - Betreiber vorhanden
    
      vD0101_ID3 := AnlageBetreiber_Betreiber(0);
      IF vD0101_ID3 <> '-1' THEN
        vD0101.D0101_id3 := vD0101_ID3; 
        vD0101.BETREIBER_ABW := 1; 
      END IF;    

    END IF;
        
    INSERT INTO vis_d0101 VALUES vD0101;
    IF ChkMsgMandant = 1 THEN 
      COMMIT;
    END IF;      
    
    -- Personal zum Betreiber einschl. Adresse
    IF GetRechtsformTyp(BTS1.fkt_inh.pers.a0101_03_sid ) = 'N' AND
    BTS1.Btr_Personal_Adr_Pst.COUNT = 0 THEN 
      -- bei Einzelunternehmen ohne Personal aus Name, Vorname .. Personal erzeugen
      -- damit in AnlageBetreiberPersonal Personal zum Angelegen vorh. ist
      BTS1.Btr_Personal_Adr_Pst.EXTEND;
      BTS1.Btr_Personal_Adr_Pst(1).NACHNAME := BTS1.fkt_inh.pers.NACHNAME;
      BTS1.Btr_Personal_Adr_Pst(1).VORNAME := BTS1.fkt_inh.pers.VORNAME;

      BTS1.Btr_Personal_Adr_Pst(1).TITEL := BTS1.fkt_inh.pers.TITEL;
      BTS1.Btr_Personal_Adr_Pst(1).Anrede := BTS1.fkt_inh.pers.Anrede;
      BTS1.Btr_Personal_Adr_Pst(1).NACHSATZ_NACHNAME := BTS1.fkt_inh.pers.NACHSATZ_NACHNAME;
      BTS1.Btr_Personal_Adr_Pst(1).VORSATZ_NACHNAME := BTS1.fkt_inh.pers.VORSATZ_NACHNAME;
      BTS1.Btr_Personal_Adr_Pst(1).HAUPTANSPRECHPARTNER_JN := 1;
      BTS1.Btr_Personal_Adr_Pst(1).BEZEICHNUNG := BTS1.fkt_inh.pers.bezeichnung;
      BTS1.Btr_Personal_Adr_Pst(1).bemerkung := BTS1.fkt_inh.pers.bemerkung;
      
      IF BTS1.fkt_inh.Adr_Sto.id <> '-1' THEN -- todo 55638090 Sitzadresse verwenden
        BTS1.Btr_Personal_Adr_Pst(1).id := BTS1.fkt_inh.Adr_Sto.id;
        BTS1.Btr_Personal_Adr_Pst(1).glo_a24_SID := BTS1.fkt_inh.Adr_Sto.glo_a24_SID;
        BTS1.Btr_Personal_Adr_Pst(1).PLZ := BTS1.fkt_inh.Adr_Sto.PLZ;
        BTS1.Btr_Personal_Adr_Pst(1).Ort := BTS1.fkt_inh.Adr_Sto.Ort;
        BTS1.Btr_Personal_Adr_Pst(1).Ortsteil := BTS1.fkt_inh.Adr_Sto.Ortsteil;
        BTS1.Btr_Personal_Adr_Pst(1).STRASSE := BTS1.fkt_inh.Adr_Sto.STRASSE;
        BTS1.Btr_Personal_Adr_Pst(1).Hausnummer := BTS1.fkt_inh.Adr_Sto.Hausnummer;
        BTS1.Btr_Personal_Adr_Pst(1).Hausnummernzusatz := BTS1.fkt_inh.Adr_Sto.Hausnummernzusatz;
        BTS1.Btr_Personal_Adr_Pst(1).GKZ := BTS1.fkt_inh.Adr_Sto.GKZ;
      END IF;  
      
      -- Kommunikationsmittel
      BTS1.Btr_Personal_Adr_Pst(1).Telefon := BTS1.fkt_inh.pers.Telefon;
      BTS1.Btr_Personal_Adr_Pst(1).fax := BTS1.fkt_inh.pers.fax;
      BTS1.Btr_Personal_Adr_Pst(1).Mobil := BTS1.fkt_inh.pers.Mobil;
      BTS1.Btr_Personal_Adr_Pst(1).Internet := BTS1.fkt_inh.pers.Internet;
      BTS1.Btr_Personal_Adr_Pst(1).email := BTS1.fkt_inh.pers.email;
      BTS1.Btr_Personal_Adr_Pst(1).weitere := BTS1.fkt_inh.pers.weitere;
           
      BTS1.Btr_Personal_Adr_Pst(1).Geburtsdatum := BTS1.fkt_inh.pers.Geburtsdatum;      

      AnlageBetreiberPersonal( BTS1.Btr_Personal_Adr_Pst, vD0101.ID, BTS1.fkt_inh.pers.a0101_03_sid, 1);          

    ELSE
      AnlageBetreiberPersonal( BTS1.Btr_Personal_Adr_Pst, vD0101.ID, BTS1.fkt_inh.pers.a0101_03_sid, 0);          
    END IF;
       
    AnlRegistrierung(False, Bts1.Btr_Reg, vD0101.ID);
     
  END IF;
    
  RETURN vD0101.id;

END; --AnlageBetreiber 

/*******************************************************************************
 Anlage Betriebssttte- Personal  
/******************************************************************************/
PROCEDURE AnlBtsPersonal(pD0101_id IN VARCHAR2) AS
v tbPersonal_Adr_Pst;
BEGIN

  IF bts1.fkt_hv.personal.count > 0 THEN
    v := tbPersonal_Adr_Pst();
    v.EXTEND( bts1.fkt_hv.personal.count );
    FOR i IN bts1.fkt_hv.personal.first .. bts1.fkt_hv.personal.last LOOP
      v(i).id :=  BTS1.fkt_hv.personal(i).ID;
      --v(i).OWNER_TYPE := BTS1.fkt_hv.personal(i).OWNER_TYPE;
      v(i).TYP := BTS1.fkt_hv.personal(i).TYP;
      v(i).ANREDE := BTS1.fkt_hv.personal(i).ANREDE;
      v(i).TITEL := BTS1.fkt_hv.personal(i).TITEL;
      v(i).VORNAME := BTS1.fkt_hv.personal(i).VORNAME;
      v(i).NACHNAME := BTS1.fkt_hv.personal(i).NACHNAME;
      v(i).GEBURTSDATUM := BTS1.fkt_hv.personal(i).GEBURTSDATUM;
      v(i).GEBURTSORT := BTS1.fkt_hv.personal(i).GEBURTSORT;
      v(i).REF_ID := BTS1.fkt_hv.personal(i).REF_ID;
      v(i).VORSATZ_NACHNAME := BTS1.fkt_hv.personal(i).VORSATZ_NACHNAME;
      v(i).NACHSATZ_NACHNAME := BTS1.fkt_hv.personal(i).NACHSATZ_NACHNAME;
      v(i).A0101_70_SID := BTS1.fkt_hv.personal(i).A0101_70_SID;
      v(i).TELEFON := BTS1.fkt_hv.personal(i).TELEFON;
      v(i).FAX := BTS1.fkt_hv.personal(i).FAX;
      v(i).INTERNET := BTS1.fkt_hv.personal(i).INTERNET;
      v(i).MOBIL := BTS1.fkt_hv.personal(i).MOBIL;
      v(i).EMAIL := BTS1.fkt_hv.personal(i).EMAIL;
      v(i).WEITERE := BTS1.fkt_hv.personal(i).WEITERE;
      v(i).HAUPTANSPRECHPARTNER_JN := BTS1.fkt_hv.personal(i).HAUPTANSPRECHPARTNER_JN;
      v(i).BEMERKUNG := BTS1.fkt_hv.personal(i).BEMERKUNG;      
    
    END LOOP;
    AnlageBetreiberPersonal(v, pD0101_id, -1, 0);
  END IF;


END;


/*******************************************************************************
 Anlage einer Betriebssttte komplett  
/******************************************************************************/
PROCEDURE AnlageBetriebsstaette AS
  vD0101_ID3 vis_d0101.d0101_id3%TYPE;
  vCnt  INTEGER := 0;
  vD0101 VIS_D0101%ROWTYPE;
  vD0101$3_D010200_ID2 vis_d0101.d010200_id2%TYPE;
  vD0101$3_A0101_03_SID vis_d0101.A0101_03_SID%TYPE;
  vD0101$3_nname vis_d0101.nname%TYPE;
  vD0101$3_vname vis_d0101.vname%TYPE;
  vD0101$3_vorsatz_nname vis_d0101.vorsatz_nname%TYPE;
  vD0101$3_nachsatz_nname vis_d0101.nachsatz_nname%TYPE;
  vD0101$3_anrede vis_d0101.anrede%TYPE;
  vD0101$3_titel vis_d0101.titel%TYPE;
  
BEGIN
  
  CASE
  WHEN BTS1.prot.parameter LIKE '%opt_betreiber=2%' THEN -- Betreiber anlegen
    vD0101_id3 := AnlageBetreiber(BTS1.fkt_inh, NULL); 
  WHEN BTS1.prot.parameter LIKE '%opt_betreiber=1%' THEN -- Betreiber vorhanden
    vD0101_id3 := BTS1.fkt_inh.pers.ref_id;   
  ELSE -- unbekannt
    vD0101_id3 := '-1';
  END CASE;
 
  -- Modus nur Betreiber anlegen, dann keine Betriebssttte anlegen
  IF BTS1.prot.parameter LIKE '%Mode=BT%' THEN
    RETURN;
  END IF; 

  -- wenn prot.d0101_id vorhanden dann Betrieb nicht anlegen nur Fachbereiche
  IF EmptyId( BTS1.prot.d0101_id ) THEN 
    vCnt := 0;
    BTS1.prot.d0101_id := SYS_GUID();
    
    UPDATE d_protokoll
    SET d0101_id = BTS1.prot.d0101_id
    WHERE id = BTS1.prot.id;
    
  ELSE
    SELECT COUNT(*) INTO vCnt
    FROM vis_d0101
    WHERE id = BTS1.prot.d0101_id;
  END IF;
  
  IF vCnt > 0 THEN
    -- nur Fachbereiche anlegen 
    SELECT * INTO vD0101
    FROM vis_d0101
    WHERE id = BTS1.prot.d0101_id;
    AnlbtsFB(True, vD0101);
  ELSE
  
    SELECT * INTO vD0101 -- Initialisierung mit Standardwerten
    FROM vis_d0101 
    WHERE id = '-1';

    vD0101.ID         := CASE WHEN EmptyId(BTS1.prot.d0101_id) THEN SYS_GUID() ELSE BTS1.prot.d0101_id END;
    vD0101.MANDANT    := vMandant_SID;
    vD0101.D0101_ID3  := vD0101_id3;
    -- immer Post an Betreiber, oder kein Betreiber vorh. dann an Betrieb
    vD0101.D0101_ID2  := CASE WHEN vD0101.D0101_ID3 = '-1' THEN vD0101.ID ELSE vD0101.D0101_ID3 END; 
    vD0101.SKZ        := 1;
    vD0101.NAME1      := BTS1.bts.BEZEICHNUNG; 
    vD0101.BEZ_ART    := 'F'; -- 09.05.2014 CrtD0101_BEZ_ART( BTS1.fkt_inh.pers.TYP, BTS1.fkt_inh.pers.a0101_03_sid);
    vD0101.INS_USER   := vUser_SID;
    vD0101.INS_DATE   := SYSDATE;
    vD0101.UPD_USER   := vUser_SID;
    vD0101.UPD_DATE   := SYSDATE;
    vD0101.DELETED    := 0;
    vD0101.ANMELDUNG  := TRUNC(BTS1.bts.gueltig_von);
    vD0101.ABMELDUNG  := TRUNC(BTS1.bts.gueltig_bis);
    vD0101.GKZ        := BTS1.Adr_Sto.gkz;
    vD0101.zb         := NVL(BTS1.bts.zb, vMandantZB);
    vD0101.glo_a24_sid:= NVL(BTS1.Adr_Sto.glo_a24_sid, vDEFAULT_A24_SID);
    vD0101.code       := BTS1.bts.kennzeichen;
    vD0101.anrede     := NULL;
    vD0101.daten_herkunft := vVerfahren;
    vD0101.bem        := Bts1.bts.bemerkung;
    -- Kommunikationsmittel
    vD0101.kom_tel      := BTS1.bts.Telefon;
    vD0101.kom_fax      := BTS1.bts.fax;
    vD0101.kom_email    := BTS1.bts.email;
    vD0101.kom_internet := BTS1.bts.Internet;
    vD0101.kom_mobil    := BTS1.bts.Mobil;
    vD0101.kom_sonst    := BTS1.bts.weitere;    
        
    vD0101.Land := GetLandByA24_SID(vD0101.GLO_A24_SID); -- 05.08.2013 
  --  opt_betrieb_adresse:
  --  0 : Standard
  --  1 : wechselnd
  --  2 : Freitext  
    IF BTS1.prot.parameter LIKE '%opt_betrieb_adresse=0%' -- Standard
    OR BTS1.prot.parameter LIKE '%opt_betrieb_adresse=2%' THEN -- Freitext
      vD0101.plz          := BTS1.Adr_Sto.PLZ;
      vD0101.ort          := BTS1.Adr_Sto.Ort;      
      vD0101.ortsteil     := BTS1.Adr_Sto.Ortsteil;  
      vD0101.hausnr       := BTS1.Adr_Sto.Hausnummer;
      vD0101.hausnrzusatz := BTS1.Adr_Sto.Hausnummernzusatz; 
      vD0101.glo_a24_sid  := NVL(BTS1.Adr_Sto.glo_a24_sid, vDEFAULT_A24_SID);  

      IF BTS1.prot.parameter LIKE '%opt_betrieb_adresse=2%' THEN -- Freitext
        vD0101.strasse     := BTS1.Adr_Sto.FreiText;
      ELSE
        vD0101.strasse     := BTS1.Adr_Sto.STRASSE;    
      END IF;

    END IF;
    -- BTS1.prot.parameter LIKE '%opt_betrieb_adresse=1%' THEN -- wechselnd
    
    vD0101.adresszusatz := BTS1.Adr_Sto.ADRESSZUSATZ;     

    -- verwaltung 
    vD0101.gkz         := BTS1.Adr_Sto.gkz;
    -- kataster   
    vD0101.flurstueck  := BTS1.Adr_Sto.Flurstueck;
    vD0101.flurnummer  := BTS1.Adr_Sto.Flurnummer;
    vD0101.gemarkung   := BTS1.Adr_Sto.Gemarkung;
    vD0101.rechtswert  := BTS1.Adr_Sto.Rechtswert;
    vD0101.hochwert    := BTS1.Adr_Sto.Hochwert;
    vD0101.x_wert      := BTS1.Adr_Sto.X_Wert;
    vD0101.y_wert      := BTS1.Adr_Sto.Y_Wert;
    vD0101.gis_quelle  := BTS1.Adr_Sto.Koordinatenherkunft;
    vD0101.s09_sid     := NVL(BTS1.Adr_Sto.s09_sid, vDEFAULT_S09_SID);

    vD0101.D010200_id2 := '-1';
    vD0101.a0101_03_sid := -1; 

    IF vD0101.d0101_id3 <> '-1' THEN

      -- Daten vom Betreiber bernehmen
      SELECT bez, titel, anrede, nname, vname, vorsatz_nname, nachsatz_nname
        /* 09.05.2014, bez_art*/, p_bez_art, f_anrede, briefanrede, p_anrede
        , d010200_id2, a0101_03_sid
        , hit_bez_1, hit_bez_2 
        , bez, p_name -- 10.07.2014         
      INTO vD0101.Bez, vD0101$3_titel, vD0101$3_anrede, vD0101$3_nname, vD0101$3_vname, vD0101$3_vorsatz_nname, vD0101$3_nachsatz_nname
        /* 09.05.2014, vD0101.bez_art*/, vD0101.p_bez_art, vD0101.F_ANREDE, vD0101.briefanrede, vD0101.p_anrede
        , vD0101$3_d010200_id2, vD0101$3_A0101_03_SID
        , vD0101.hit_bez_1, vD0101.hit_bez_2 
        , vD0101.bez, vD0101.p_name  -- 10.07.2014 
      FROM vis_d0101
      WHERE id = vD0101.d0101_id3;
      
      IF GetRechtsformTyp( vD0101$3_A0101_03_SID) = 'N'
      AND BTS1.prot.parameter LIKE '%chk_einzelunternehmer_ha=1%' THEN
        vD0101.D010200_id2 := vD0101$3_d010200_id2;
        vD0101.titel := vD0101$3_titel;
        vD0101.anrede := vD0101$3_anrede;
        vD0101.nname := vD0101$3_nname;
        vD0101.vname := vD0101$3_vname;
        vD0101.vorsatz_nname := vD0101$3_vorsatz_nname;
        vD0101.nachsatz_nname := vD0101$3_nachsatz_nname;        
      END IF;
      
    END IF;
    
    -- von unten nach hier verschoben
    -- 10.07.2014    
    --vD0101.p_name := vD0101.bez;
    vD0101.p_name1:= vD0101.name1;    

    --Postanschrift
    --opt_betrieb_postadresse:
    --0 - Postadresse = Sitzadresse
    --1 - abweichende 
    --2 - keine  
    CASE
    WHEN BTS1.prot.parameter LIKE '%opt_betrieb_postadresse=1%' THEN
      -- abweichende Postanschrift
      BETR_POST_KOR(vD0101, BTS1.Adr_Pst);       
      --BETR_POST_KOR_BETREI(vD0101);       
    WHEN BTS1.prot.parameter LIKE '%opt_betrieb_postadresse=2%' THEN
      -- Post an Betreiber
      -- wenn Betreiber keine abweichende Postadresse hat, dann Sitzadresse verwenden
      vD0101.D0101_ID2 := vD0101.D0101_ID3;
      BETR_POST_KOR_BETREI(vD0101);       
      
--      IF BTS1.prot.parameter LIKE '%opt_betreiber_postadresse=0%' OR BTS1.fkt_inh.Adr_Pst.ID IS NULL THEN
--        BETR_POST_KOR(vD0101, BTS1.fkt_inh.Adr_Sto, NULL);       
--      ELSE  
--        BETR_POST_KOR(vD0101, BTS1.fkt_inh.Adr_Pst, NULL);       
--      END IF;      
            
    WHEN BTS1.prot.parameter LIKE '%opt_betrieb_postadresse=0%' THEN
      -- keine Postanschrift vorhanden oder gleich
      -- Postanschrift wie Standort setzen
      BETR_POST_DEFA( vD0101 );
      -- 29.11.2013 vD0101.p_bez_art := 'F';  -- 20.03.2013 Post an Betrieb als Standard
    ELSE NULL;

    END CASE;
     
    vD0101.p_bez_art := 'F'; -- 29.11.2013    
        
    vD0101.ambulant_jn := CASE WHEN BTS1.prot.parameter LIKE '%opt_betrieb_adresse=1%' THEN 1
                               WHEN BTS1.prot.parameter LIKE '%opt_betrieb_adresse=2%' THEN 2
                               ELSE 0 
                          END;
      
    vD0101.betreiber_abw := CASE WHEN vD0101.d0101_id3 NOT IN (vD0101.id, '-1') THEN 1 ELSE 0 END;
    
    -- FB-Felder
    IF BTS1.FAB.count > 0 THEN
      vD0101.FB := NULL;
      FOR i IN BTS1.FAB.FIRST .. BTS1.FAB.LAST LOOP
        
        IF BTS1.FAB(i).a0101_06_sid <> '-1' THEN 
          IF BTS1.FAB(i).code IS NULL  THEN
            SELECT FB INTO BTS1.FAB(i).code 
            FROM vis_a0101
            WHERE sid = BTS1.FAB(i).a0101_06_sid;
          END IF;
          vD0101.fb := vD0101.fb || BTS1.FAB(i).code;        
        END IF;
        
      END LOOP;

      vD0101.FB0 := vD0101.FB;
    ELSE
      vD0101.FB := '%';
      vD0101.FB := '%';  
    END IF;
    
    vD0101.Fachb := blvUtils.Get_FB2KurzbV(vD0101.FB);
    vD0101.Fachb0 := vD0101.Fachb;

    INSERT INTO vis_d0101 VALUES vD0101;
    IF ChkMsgMandant = 1 THEN 
      COMMIT;
    END IF;
    
    -- Fachbereiche zur Betriebssttte
    AnlBtsFB(False, vD0101);
    
    -- Registrierungen zur Betrierbssttte
    AnlRegistrierung(False, Bts1.Reg, vD0101.ID);

    -- Betrierbsarten zur Betriebssttte
    AnlBetriebsarten(False, Bts1.Bar, vD0101.id);

    AnlBtsPersonal(vD0101.id);         
  END IF;    
END;


PROCEDURE InsertD0101(pBTS_ID IN VARCHAR2, pWithOutRead IN INTEGER := 0) AS
  --v NUMBER;
  vPlausiBTS INTEGER := 0;
  vPlausiBTR INTEGER := 0;
BEGIN
  ClearErrMsg;
  --Createdusecase := 0;
  --Anl_Min_D0101_ID3 := '-1';
  vBTS_ID := pBTS_ID;
  
  SELECT user_sid, mandant 
  INTO vUser_sid, vMandant_SID
  FROM d_protokoll
  WHERE BTS_ID = pBTS_ID; 
  
  vMandant_SID := NVL(vMandant_SID, -1);
  vUser_sid := NVL(vUser_SID, -1);
  
  IF pWithOutRead = 1 OR Fill_BTS1(vBTS_ID) > 0 THEN
    
    vMandantZB := GetZBbyMandantSID(vMandant_SID);

--    IF EmptyId( BTS1.prot.d0101_id ) THEN -- Neuanlage 
--      Plausi(1, 1); -- Plausiprfung
--    ELSE
--      Plausi(0, 0); -- keine Plausiprfung
--    END IF;
    -- Plausi fr Betriebssttte nur ausfhren wenn noch nicht vorh.
    IF EmptyId( BTS1.prot.d0101_id ) THEN
      vPlausiBTS := 1;
    ELSE
      SELECT CASE WHEN COUNT(*) > 0 THEN 0 ELSE 1 END 
      INTO vPlausiBTS
      FROM vis_d0101 WHERE id = BTS1.prot.d0101_id;
    END IF;
    -- Plausi fr Betreiber nur ausfhren wenn noch nicht vorh.
    IF EmptyId( BTS1.fkt_inh.pers.ref_id ) THEN
      vPlausiBTR := 1;
    ELSE
      SELECT CASE WHEN COUNT(*) > 0 THEN 0 ELSE 1 END 
      INTO vPlausiBTS
      FROM vis_d0101 WHERE id = BTS1.fkt_inh.pers.ref_id;
    END IF;
    
    Plausi(vPlausiBTS, vPlausiBTR);
    
    IF vPlausiErrCnt = 0 THEN
      AnlageBetriebsstaette();
    END IF;
  END IF;
  Clear_bts(BTS1);
END;


--FUNCTION GetMandantByGKZ8(pGKZ8 VARCHAR) RETURN NUMBER AS
--  vSID vis_s50.sid%TYPE;
--  vZB glo_a25.zb%TYPE := NULL;
--BEGIN 
--  
--  BEGIN  
--  
---- 02.10.2012     
----    SELECT DISTINCT zb INTO vZB
----    FROM glo_a25
----    WHERE deleted = 0
----    AND code LIKE pGKZ8 || '%';
--
--    -- Hierachische Auswertung wegen Gebietsreform (Kreiszusammenlegung)
--    SELECT dx.zb INTO vZB
--    FROM (
--      SELECT a25_1.zb 
--      FROM glo_a25 a25_1
--      WHERE a25_1.deleted > -2
--      START WITH a25_1.code LIKE pGKZ8 || '%' 
--      CONNECT BY PRIOR a25_1.glo_a25_sid1 = a25_1.sid
--      AND a25_1.glo_a25_sid1 <> a25_1.sid
--      ORDER BY LEVEL DESC
--      ) dx
--    WHERE ROWNUM = 1;       
--    
--    EXCEPTION 
--    WHEN no_data_found THEN 
--      AddErrMsg('GKZ ist nicht vorhanden: ' || pGKZ8);
--      vSID := -3;
--    WHEN too_many_rows THEN
--      AddErrMsg('Die Zustndigkeit (ZB) konnte aus dem GKZ8 "' || pGKZ8 || '" nicht eindeutig bbtsimmt werden.');
--      vSID := -4;
--  END;
--  
--  IF vZB IS NOT NULL THEN
--  
--    -- 07.05.2012: Fehlerbehandlung wenn kein Mandant gefunden wird
--    BEGIN
--    
--      SELECT s50_sid INTO vSID
--      FROM 
--      (
--          SELECT SID  AS S50_SID,
--            CODE  AS S50_CODE,
--            ZB AS GKZ,
--            ANZAHL, 
--            DENSE_RANK() OVER (PARTITION BY ZB ORDER BY ANZAHL, CODE) RANK
--          FROM
--          (
--            SELECT 
--              S50.SID,
--              S50.CODE, 
--              A25.ZB,
--              A25.CODE a25_code,
--              COUNT(A25.ZB) OVER(PARTITION BY S50.CODE) ANZAHL
--            FROM VIS_S50 S50
--              INNER JOIN VIS_S5002 S5002 ON S5002.S50_SID = S50.SID
--              INNER JOIN GLO_A25 A25 ON A25.SID = S5002.GLO_A25_SID
--            WHERE
--                  S5002.AL > 2
--              -- Hat der Mandant entsprechende Fachbereiche
--              AND EXISTS ( SELECT NULL 
--                           FROM VIS_S5004 S5004 
--                           LEFT JOIN VIS_A0101 A0101_06 ON A0101_06.SID = S5004.A0101_06_SID AND A0101_06.SKZ = 6 
--                               WHERE A0101_06.CODE IN ( 'D', 'H' ) -- todo DD
--                                      AND S5004.AL > 2
--                                      AND S5004.DELETED > -2
--                                      AND A0101_06.DELETED > -2
--                                      AND S5004.S50_SID = S50.SID)
--              AND S50.SKZ = 1
--              AND S50.Deleted = 0
--              AND S5002.Deleted = 0
--              AND A25.Deleted = 0
--            ORDER 
--              BY A25.ZB, ANZAHL
--          )
--          WHERE zb = vZb 
--          ORDER BY ZB, RANK
--        ) WHERE ROWNUM = 1;
--
--      EXCEPTION 
--      WHEN no_data_found THEN
--        AddErrMsg('Es ist kein Mandant mit Berechtigungen auf den ZB ' || vZB || ' vorhanden.');
--        vSID := -2;
--
--    END;
--    
--  END IF;
--  
--  RETURN vSID;
--
--END; --  GetMandantByZB
--



FUNCTION GetD0101_ID RETURN VARCHAR2 AS
BEGIN
  RETURN BTS1.prot.d0101_id;
END;

/*******************************************************************************
  Liefert VIS_S50.SID des User
  Parameter : 
  - pMandant_User: in der Form Mandant/User oder User@Mandant
  Rckgabe bei Fehler:
  - (-2) : Mandant/User nicht gefunden
  - (-3) : Mandant/User mehrfach vorhanden
  Beispiel:
    SELECT zbr_ein.GetUser_SID('BALVI/FG') FROM dual
    oder
    SELECT zbr_ein.GetUser_SID('FG@BALVI') FROM dual    
*******************************************************************************/
FUNCTION GetUser_SID( pMandant_User IN VARCHAR2) RETURN INTEGER AS
  vSID INTEGER := -1;
BEGIN

  BEGIN
  
    IF pMandant_User LIKE '%@%' THEN

      SELECT s50_3.sid INTO vSID 
      FROM VIS_S50 s50_1
      JOIN vis_s50 s50_3 ON s50_1.sid = s50_3.s50_sid00
      AND s50_1.skz = 1
      AND s50_1.deleted = 0
      AND S50_3.CODE || '/' || s50_1.CODE = pMandant_User;

    ELSE

      SELECT s50_3.sid INTO vSID 
      FROM VIS_S50 s50_1
      JOIN vis_s50 s50_3 ON s50_1.sid = s50_3.s50_sid00
      AND s50_1.skz = 1
      AND s50_1.deleted = 0
      AND S50_1.CODE || '/' || s50_3.CODE = pMandant_User;

    END IF;

    EXCEPTION WHEN NO_DATA_FOUND THEN vSID := -2;
              WHEN TOO_MANY_ROWS THEN vSID := -3;
              
  END;
  
  RETURN vSID;
              
END; -- GetUser_SID


FUNCTION GKZ2 RETURN VARCHAR2 AS
BEGIN
  RETURN vGKZ2;
END;

PROCEDURE GKZ2 ( pGKZ2 IN VARCHAR2 ) AS
BEGIN
  vGKZ2 := pGKZ2;
END;


FUNCTION ReadAllgAdresse(pAdr IN tAdr) RETURN tAdr AS
  v tAdr;
BEGIN
  v := pAdr;

--  v.ID                := pAdr.id;
--  v.FreiText         := pAdr.FreiText;
----  v.WECHSELNDER_STANDORT := pAdr.WECHSELNDER_STANDORT;
--  v.gueltig_von        := pAdr.gueltig_von;
--  v.gueltig_bis       := pAdr.gueltig_bis;
--  v.TYP              := pAdr.TYP;
--  v.ADRESSZUSATZ    := pAdr.ADRESSZUSATZ;
--   
--  v.Flurnummer  := pAdr.Flurnummer;
--  v.Flurstueck         := pAdr.Flurstueck;
--  v.Gemarkung          := pAdr.Gemarkung;
--  v.X_Wert           := pAdr.X_Wert;
--  v.Y_Wert           := pAdr.Y_Wert;
--  v.Rechtswert           := pAdr.Rechtswert;
--  v.Hochwert          := pAdr.Hochwert;
--  v.Koordinatenherkunft        := pAdr.Koordinatenherkunft;
  v.s09_sid           := NVL(pAdr.s09_sid, vDEFAULT_S09_SID);
   
--  v.Hausnummer        := pAdr.Hausnummer;
--  v.Hausnummernzusatz := pAdr.Hausnummernzusatz;
--  v.Ort                := pAdr.Ort;
--  v.Ortsteil   := pAdr.Ortsteil;
--  v.Postfach := pAdr.Postfach;
--  v.Staat           := pAdr.Staat;
--  v.STRASSE          := pAdr.STRASSE;
--  v.PLZ        := pAdr.PLZ;
  v.GLO_A24_SID     := NVL(pAdr.GLO_A24_SID, vDEFAULT_A24_SID);
   
--  ID
--  v.GEMEINDE      := pAdr.GEMEINDE;
--  v.GKZ               := pAdr.GKZ;
--  v.Teilort  := pAdr.Teilort;
  
  RETURN v; 
END;

PROCEDURE SaveAllgAdresse(pAdr OUT NOCOPY tAdr, pValues IN tAdr) AS
BEGIN

  pAdr := pValues;

  --, ADR
--  pAdr.id                 := pValues.id;
--  pAdr.FreiText          := pValues.FreiText;
--  pAdr.WECHSELNDER_STANDORT  := pValues.WECHSELNDER_STANDORT;
--
--  pAdr.gueltig_von     := pValues.gueltig_von;
--  pAdr.gueltig_bis    := pValues.gueltig_bis;
--    
--  pAdr.TYP            := pValues.TYP;
--  pAdr.ADRESSZUSATZ  := pValues.ADRESSZUSATZ;
--        
--  --Kataster
--  pAdr.Flurnummer := pValues.Flurnummer; 
--  pAdr.Flurstueck        := pValues.Flurstueck; 
--  pAdr.Gemarkung         := pValues.Gemarkung; 
--  pAdr.X_Wert          := pValues.X_Wert; 
--  pAdr.Y_Wert          := pValues.Y_Wert; 
--  pAdr.Rechtswert          := pValues.Rechtswert; 
--  pAdr.Hochwert         := pValues.Hochwert;
--  pAdr.Koordinatenherkunft       := pValues.Koordinatenherkunft;
  pAdr.s09_sid          := NVL(pValues.s09_sid, vDEFAULT_S09_SID) ; 
  -- Postadresse
--  pAdr.Hausnummer         := pValues.Hausnummer; 
--  pAdr.Hausnummernzusatz  := pValues.Hausnummernzusatz; 
--  pAdr.Ort                 := pValues.Ort; 
--  pAdr.Ortsteil        := pValues.Ortsteil; 
--  pAdr.Postfach      := pValues.Postfach; 
--  pAdr.Staat                := pValues.Staat; 
--  pAdr.STRASSE               := pValues.STRASSE; 
--  pAdr.PLZ             := pValues.PLZ; 
  pAdr.GLO_A24_SID          := NVL(pValues.GLO_A24_SID, vDEFAULT_A24_SID) ; 
   
  -- Verwaltung
--  pAdr.GEMEINDE       := pValues.GEMEINDE;
--  pAdr.GKZ                := pValues.GKZ;
--  pAdr.Teilort   := pValues.Teilort;
--   
  IF pAdr.TYP IS NULL THEN
    IF pAdr.Postfach IS NOT NULL THEN
      pAdr.TYP := Adr_Postfach;
    ELSIF pAdr.STRASSE IS NOT NULL THEN
      pAdr.TYP := Adr_STRASSE;
    END IF;      
  END IF;  

END;



-- Initialiserung der Objektvariablen vor dem Lesen
FUNCTION ReadInit(pBTS_ID IN VARCHAR2) RETURN INTEGER AS
BEGIN
  vBTS_ID := pBTS_ID;
  RETURN Fill_BTS1(pBTS_ID);
END;

-- Initialiserung der Objektvariablen vor dem Speichern
FUNCTION SaveInit(pBTS_ID IN VARCHAR2) RETURN INTEGER AS
BEGIN
  vBTS_ID := pBTS_ID;
  Clear_bts(BTS1);
  RETURN 1;
END;

-- Protokoll lesen
FUNCTION ReadPrt RETURN tbPrt PIPELINED AS
BEGIN
  IF BTS1.prot.id <> '-1' THEN
    PIPE ROW( BTS1.prot );
  END IF;
  RETURN;
END;  

-- Speichen Protokoll in Objektvariable
--FUNCTION SaveProt(pValues IN btr_e_protokoll%ROWTYPE) RETURN INTEGER AS
FUNCTION SavePrt(pValues IN tPrt) RETURN INTEGER AS
BEGIN
  --BTS1.Prot := pValues;
  
  BTS1.Prot.ID          := pValues.ID;
  --BTS1.Prot.BTS_ID      := pValues.BTS_ID; 
  BTS1.Prot.D0101_ID    := pValues.D0101_ID; 
  BTS1.Prot.STATUS      := pValues.STATUS; 
  BTS1.Prot.INS_DATE    := pValues.INS_DATE; 
  BTS1.Prot.USER_SID    := pValues.USER_SID; 
  BTS1.Prot.LETZTE_AENDERUNG := pValues.LETZTE_AENDERUNG; 
  BTS1.Prot.MANDANT     := pValues.MANDANT; 
  BTS1.Prot.DELETED     := pValues.DELETED; 
  BTS1.Prot.PARAMETER   := pValues.PARAMETER; 
  BTS1.Prot.DATENHERKUNFT := pValues.DATENHERKUNFT;     
   
  BTS1.Prot.BTS_ID := vBTS_ID;
  RETURN 1;
END;

-- usecase lesen
FUNCTION ReadUsc RETURN tbUsc PIPELINED AS
v1 tUSC;
BEGIN
  FOR c1 IN (
    SELECT usc.*  
    FROM d_usecase usc
    WHERE usc.BTS_ID = BTS1.bts.id
  ) LOOP
  
    v1.ID           := c1.ID ;
    v1.BTS_ID       := c1.BTS_ID;
    v1.usecase      := c1.usecase ;
    v1.MANDANT      := c1.MANDANT ;
    v1.user_name    := c1.user_name ;
    v1.USER_SID     := c1.USER_SID ;
    v1.typ          := c1.typ ;
    v1.Aenderungsgrund := c1.Aenderungsgrund ;
    v1.Bemerkung      := c1.Bemerkung ;
    v1.FB             := c1.FB ;
    v1.ZB             := c1.ZB ;
    v1.gueltig_von    := c1.gueltig_von;
    v1.gueltig_bis    := c1.gueltig_bis;
    v1.D0101_ID       := c1.D0101_ID;
    v1.A0101_501_SID  := c1.A0101_501_SID;
    v1.alter_wert     := c1.alter_wert;
    v1.neuer_wert     := c1.neuer_wert;    
    PIPE ROW( v1 );
  END LOOP;
  RETURN;
END;  

-- Speichern usecase in Objektvariable
FUNCTION SaveUsc(pValues IN tUsc) RETURN INTEGER AS 
  iExt INTEGER := 0;
  res INTEGER := 1;
BEGIN
  IF pValues.ID <> '-1' THEN
    BTS1.USC.EXTEND;
    iExt := BTS1.USC.LAST;
    
    BTS1.USC(iExt).ID             := pValues.ID;
    BTS1.USC(iExt).usecase        := pValues.usecase; 
    BTS1.USC(iExt).MANDANT        := pValues.MANDANT;
    BTS1.USC(iExt).user_name      := pValues.user_name;
    BTS1.USC(iExt).USER_SID       := pValues.USER_SID;
    BTS1.USC(iExt).typ            := pValues.typ;
    BTS1.USC(iExt).Aenderungsgrund:= pValues.Aenderungsgrund;
    BTS1.USC(iExt).Bemerkung      := pValues.Bemerkung;
    BTS1.USC(iExt).FB             := pValues.FB;
    BTS1.USC(iExt).ZB             := pValues.ZB;
    BTS1.USC(iExt).D0101_ID       := pValues.D0101_ID;
    BTS1.USC(iExt).gueltig_von    := pValues.gueltig_von;
    BTS1.USC(iExt).gueltig_bis    := pValues.gueltig_bis;
    BTS1.USC(iExt).A0101_501_SID  := pValues.A0101_501_SID;
    BTS1.USC(iExt).alter_wert     := pValues.alter_wert;
    BTS1.USC(iExt).neuer_wert     := pValues.neuer_wert;
              
    BTS1.USC(iExt).BTS_ID := BTS1.bts.id; 
  ELSE
    res := 0;
  END IF;
  RETURN res;
END;

-- BTS-Registrierung lesen
FUNCTION ReadBtsReg RETURN tbReg PIPELINED AS
v1 tReg;
BEGIN
  FOR c1 IN (
    SELECT reg.*  
    FROM d_registrierung reg
    WHERE reg.BTS_ID = BTS1.bts.id
  ) LOOP
  
    v1.ID          := c1.ID;
    v1.PRS_ID      := c1.PRS_ID;
    v1.BTS_ID      := c1.BTS_ID;
    v1.TYP         := c1.TYP;
    v1.CODE        := c1.CODE;
    v1.NUMMER      := c1.NUMMER;
    v1.ZUSATZ      := c1.ZUSATZ;
    v1.GUELTIG_VON := c1.GUELTIG_VON;
    v1.GUELTIG_BIS := c1.GUELTIG_BIS;
    v1.REF_ID      := c1.REF_ID;
    v1.INS_DATE    := c1.INS_DATE;
    
    PIPE ROW( v1 );
  END LOOP;
  RETURN;
END; 

-- Speichern BTS-Registrierung in Objektvariable
FUNCTION SaveBtsReg(pValues IN tReg) RETURN INTEGER AS 
  iExt INTEGER := 0;
  res INTEGER := 1;
BEGIN
  IF pValues.ID <> '-1' THEN
    BTS1.reg.EXTEND;
    iExt := BTS1.reg.LAST;
    
    BTS1.reg(iExt).ID          := pValues.ID;
    BTS1.reg(iExt).PRS_ID      := NULL;
    BTS1.reg(iExt).BTS_ID      := BTS1.bts.id;
    BTS1.reg(iExt).TYP         := pValues.TYP;
    BTS1.reg(iExt).CODE        := pValues.CODE;
    BTS1.reg(iExt).NUMMER      := pValues.NUMMER;
    BTS1.reg(iExt).ZUSATZ      := pValues.ZUSATZ;
    BTS1.reg(iExt).GUELTIG_VON := pValues.GUELTIG_VON;
    BTS1.reg(iExt).GUELTIG_BIS := pValues.GUELTIG_BIS;
    BTS1.reg(iExt).REF_ID      := pValues.REF_ID;
    BTS1.reg(iExt).INS_DATE    := pValues.INS_DATE;
     
  ELSE
    res := 0;
  END IF;
  RETURN res;
END SaveBtsReg;

-- Betriebsarten lesen
FUNCTION ReadBtsBar RETURN tbBar PIPELINED AS
v1 tBar;
BEGIN
  FOR c1 IN (
    SELECT bar.*  
    FROM d_betriebsart bar
    WHERE bar.BTS_ID = BTS1.bts.id
  ) LOOP
  
    v1.ID                := c1.ID;
    v1.BTS_ID            := c1.BTS_ID;
    v1.TYP               := c1.TYP;
    v1.CODE              := c1.CODE;
    v1.BEZEICHNUNG       := c1.BEZEICHNUNG;
    v1.FB                := c1.FB;
    v1.GUELTIG_VON       := c1.GUELTIG_VON;
    v1.GUELTIG_BIS       := c1.GUELTIG_BIS;
    v1.D010101_ID        := c1.D010101_ID;
    v1.GELTUNGSBEREICH   := c1.GELTUNGSBEREICH;
    v1.GEWERBSMAESSIG_JN := c1.GEWERBSMAESSIG_JN;
    v1.INS_DATE          := c1.INS_DATE;
    v1.ADR_STO_ID        := c1.ADR_STO_ID;
    
    PIPE ROW( v1 );
  END LOOP;
  RETURN;
END; 

-- Speichern Betriebsarten in Objektvariable
FUNCTION SaveBtsBar(pValues IN tBar) RETURN INTEGER AS 
  iExt INTEGER := 0;
  res INTEGER := 1;
BEGIN
  IF pValues.ID <> '-1' THEN
    BTS1.bar.EXTEND;
    iExt := BTS1.bar.LAST;
    
    BTS1.bar(iExt).ID                 := pValues.ID;
    BTS1.bar(iExt).BTS_ID             := BTS1.bts.ID;
    BTS1.bar(iExt).TYP                := pValues.TYP;
    BTS1.bar(iExt).CODE               := pValues.CODE;
    BTS1.bar(iExt).BEZEICHNUNG        := pValues.BEZEICHNUNG;
    BTS1.bar(iExt).FB                 := pValues.FB;
    BTS1.bar(iExt).GUELTIG_VON        := pValues.GUELTIG_VON;
    BTS1.bar(iExt).GUELTIG_BIS        := pValues.GUELTIG_BIS;
    BTS1.bar(iExt).D010101_ID         := pValues.D010101_ID;
    BTS1.bar(iExt).GELTUNGSBEREICH    := pValues.GELTUNGSBEREICH;
    BTS1.bar(iExt).GEWERBSMAESSIG_JN  := pValues.GEWERBSMAESSIG_JN;
    BTS1.bar(iExt).INS_DATE           := pValues.INS_DATE;
    BTS1.bar(iExt).ADR_STO_ID         := pValues.ADR_STO_ID;
     
  ELSE
    res := 0;
  END IF;
  RETURN res;
END SaveBtsBar;


-- Betriebsstaette lesen
FUNCTION ReadBts RETURN tbBTS PIPELINED AS
BEGIN
  IF BTS1.bts.id <> '-1' THEN
    PIPE ROW( BTS1.bts );
  END IF;
  RETURN;
END;  

-- Speichern Betriebssttte in Objektvariable
FUNCTION SaveBts( pValues IN tBTS) RETURN INTEGER AS
BEGIN
  BTS1.bts := pValues;
  RETURN 1;
END;

-- Lesen Fachbereiche der Betriebsstaette
FUNCTION ReadbtsFAB RETURN tbFAB PIPELINED AS
BEGIN
  FOR c1 IN (
    SELECT id
      , BTS_ID BTS_ID
      , code
      , a0101_06_sid
      , gueltig_von 
      , gueltig_bis
      , d010104_id
      , a0115_sid
      , a0101_01_sid
      , ERSTKONTROLLTERMIN
      , ins_date
    FROM d_fachbereich FAB
    WHERE FAB.BTS_ID = BTS1.bts.id
  ) LOOP
  
    PIPE ROW( c1 );
  END LOOP;
  RETURN;
END;

-- Speichern Fachbereiche der Betriebsstaette in Objektvariable
FUNCTION SaveBtsFAB(pValues IN tFAB) RETURN INTEGER AS
  iExt INTEGER := 0;
  res INTEGER := 1;
BEGIN
  IF pValues.ID <> '-1' THEN
    BTS1.FAB.EXTEND;
    iExt := BTS1.FAB.LAST;
    
    BTS1.FAB(iExt).ID                 := pValues.ID;
    --BTS1.FAB(iExt).BTS_ID              := pValues.BTS_ID; 
    BTS1.FAB(iExt).CODE               := pValues.CODE;
    BTS1.FAB(iExt).A0101_06_SID       := pValues.A0101_06_SID;
    BTS1.FAB(iExt).gueltig_von        := pValues.gueltig_von;
    BTS1.FAB(iExt).gueltig_bis        := pValues.gueltig_bis;
    BTS1.FAB(iExt).d010104_ID         := pValues.d010104_ID;
    BTS1.FAB(iExt).A0115_SID          := pValues.A0115_SID;
    BTS1.FAB(iExt).A0101_01_SID       := pValues.A0101_01_SID;
    BTS1.FAB(iExt).ERSTKONTROLLTERMIN := pValues.ERSTKONTROLLTERMIN;
    BTS1.FAB(iExt).INS_DATE           := SYSDATE;    
     
    BTS1.FAB(iExt).BTS_ID := BTS1.bts.id; 
  ELSE
    res := 0;
  END IF;
  RETURN res;
END;

-- Lesen Betriebsstaette Standortadresse
FUNCTION ReadbtsAdr_Sto RETURN tbAdr PIPELINED AS
  v tAdr;
BEGIN
  v := ReadAllgAdresse(BTS1.Adr_Sto);
  IF v.id <> '-1' THEN
    PIPE ROW( v );
  END IF;
  RETURN;  
END;

-- Speichern Betriebssttte Standortadresse in Objektvariable
FUNCTION SavebtsAdr_Sto(pValues IN tAdr) RETURN INTEGER AS
BEGIN
  SaveAllgAdresse(BTS1.Adr_Sto, pValues);    
  RETURN 1;
END;

-- Lesen Betriebsstaette Postadresse
FUNCTION ReadbtsAdr_Pst RETURN tbAdr PIPELINED AS
  v tAdr;
BEGIN
  v := ReadAllgAdresse(BTS1.Adr_Pst);
  IF v.ID <> '-1' THEN
    PIPE ROW( v );
  END IF;
  RETURN;  
END;

-- Speichern Betriebssttte Postadresse in Objektvariable
-- opt_betrieb_postadresse:
-- 0 - Postadresse = Sitzadresse
-- 1 - abweichende 
-- 2 - keine
FUNCTION SavebtsAdr_Pst(pValues IN tAdr) RETURN INTEGER AS
BEGIN
  IF BTS1.prot.parameter LIKE '%opt_betrieb_postadresse=1%' THEN
    SaveAllgAdresse(BTS1.Adr_Pst, pValues);    
  END IF;
  RETURN 1;
END;

--Lesen Betriebsstaette Hauptverantwortlicher Person 
FUNCTION ReadBtsPersonal RETURN tbD_Personal PIPELINED AS
v d_personal%ROWTYPE;
BEGIN
  IF BTS1.fkt_hv.personal.COUNT > 0 THEN
    FOR i IN BTS1.fkt_hv.personal.FIRST .. BTS1.fkt_hv.personal.LAST LOOP
      v.ID                      := BTS1.fkt_hv.personal(i).id; 
      --v.ADR_STZ_ID            v.ADR_STZ_ID
      --v.ADR_PST_ID            v.ADR_PST_ID
      --v.OWNER_PRS_ID          v.OWNER_PRS_ID
      v.OWNER_TYPE              := BTS1.fkt_hv.personal(i).OWNER_TYPE;
      --v.KURZBEZEICHNUNG1      v.KURZBEZEICHNUNG1
      --v.KURZBEZEICHNUNG2      v.KURZBEZEICHNUNG2
      v.TYP                     := BTS1.fkt_hv.personal(i).TYP;
      v.ANREDE                  := BTS1.fkt_hv.personal(i).ANREDE;
      v.TITEL                   := BTS1.fkt_hv.personal(i).TITEL;
      v.VORNAME                 := BTS1.fkt_hv.personal(i).VORNAME;
      v.NACHNAME                := BTS1.fkt_hv.personal(i).NACHNAME;
      v.GEBURTSDATUM            := BTS1.fkt_hv.personal(i).GEBURTSDATUM;
      v.GEBURTSORT              := BTS1.fkt_hv.personal(i).GEBURTSORT;
      --v.BEZEICHNUNG           v.BEZEICHNUNG
      --v.BEZEICHNUNG2          v.BEZEICHNUNG2
      --v.RECHTSFORM            v.RECHTSFORM
      --v.PERS_ID               v.PERS_ID
      v.REF_ID                  := BTS1.fkt_hv.personal(i).REF_ID;
      v.VORSATZ_NACHNAME        := BTS1.fkt_hv.personal(i).VORSATZ_NACHNAME;
      v.NACHSATZ_NACHNAME       := BTS1.fkt_hv.personal(i).NACHSATZ_NACHNAME;
      --v.A0101_03_SID          v.A0101_03_SID
      v.A0101_70_SID            := BTS1.fkt_hv.personal(i).A0101_70_SID;
      v.INS_DATE                := BTS1.fkt_hv.personal(i).INS_DATE;
      v.TELEFON                 := BTS1.fkt_hv.personal(i).TELEFON;
      v.FAX                     := BTS1.fkt_hv.personal(i).FAX;
      v.INTERNET                := BTS1.fkt_hv.personal(i).INTERNET;
      v.MOBIL                   := BTS1.fkt_hv.personal(i).MOBIL;
      v.EMAIL                   := BTS1.fkt_hv.personal(i).EMAIL;
      v.WEITERE                 := BTS1.fkt_hv.personal(i).WEITERE;
      v.HAUPTANSPRECHPARTNER_JN := BTS1.fkt_hv.personal(i).HAUPTANSPRECHPARTNER_JN;
      v.BEMERKUNG               := BTS1.fkt_hv.personal(i).BEMERKUNG;

      PIPE ROW( v );
    END LOOP;  
  END IF;
  RETURN;  
END;


FUNCTION SaveBtsPersonal(pValues IN tPersonal) RETURN INTEGER AS
i INTEGER;
BEGIN

  IF pValues.ID <> '-1' THEN
    BTS1.fkt_hv.personal.EXTEND;
    i := BTS1.fkt_hv.personal.COUNT;
    
    BTS1.fkt_hv.personal(i).id :=  pValues.ID;
    BTS1.fkt_hv.personal(i).OWNER_TYPE := pValues.OWNER_TYPE;
    BTS1.fkt_hv.personal(i).TYP := pValues.TYP;
    BTS1.fkt_hv.personal(i).ANREDE := pValues.ANREDE;
    BTS1.fkt_hv.personal(i).TITEL := pValues.TITEL;
    BTS1.fkt_hv.personal(i).VORNAME := pValues.VORNAME;
    BTS1.fkt_hv.personal(i).NACHNAME := pValues.NACHNAME;
    BTS1.fkt_hv.personal(i).GEBURTSDATUM := pValues.GEBURTSDATUM;
    BTS1.fkt_hv.personal(i).GEBURTSORT := pValues.GEBURTSORT;
    BTS1.fkt_hv.personal(i).REF_ID := pValues.REF_ID;
    BTS1.fkt_hv.personal(i).VORSATZ_NACHNAME := pValues.VORSATZ_NACHNAME;
    BTS1.fkt_hv.personal(i).NACHSATZ_NACHNAME := pValues.NACHSATZ_NACHNAME;
    BTS1.fkt_hv.personal(i).A0101_70_SID := pValues.A0101_70_SID;
    BTS1.fkt_hv.personal(i).INS_DATE := pValues.INS_DATE;
    BTS1.fkt_hv.personal(i).TELEFON := pValues.TELEFON;
    BTS1.fkt_hv.personal(i).FAX := pValues.FAX;
    BTS1.fkt_hv.personal(i).INTERNET := pValues.INTERNET;
    BTS1.fkt_hv.personal(i).MOBIL := pValues.MOBIL;
    BTS1.fkt_hv.personal(i).EMAIL := pValues.EMAIL;
    BTS1.fkt_hv.personal(i).WEITERE := pValues.WEITERE;
    BTS1.fkt_hv.personal(i).HAUPTANSPRECHPARTNER_JN := pValues.HAUPTANSPRECHPARTNER_JN;
    BTS1.fkt_hv.personal(i).BEMERKUNG := pValues.BEMERKUNG;

      --v.ADR_STZ_ID            pValue.ADR_STZ_ID
      --v.ADR_PST_ID            pValue.ADR_PST_ID
      --v.OWNER_PRS_ID          pValue.OWNER_PRS_ID
      --v.KURZBEZEICHNUNG1      pValue.KURZBEZEICHNUNG1
      --v.KURZBEZEICHNUNG2      pValue.KURZBEZEICHNUNG2
      --v.BEZEICHNUNG           pValue.BEZEICHNUNG
      --v.BEZEICHNUNG2          pValue.BEZEICHNUNG2
      --v.RECHTSFORM            pValue.RECHTSFORM
      --v.PERS_ID               pValue.PERS_ID
      --v.A0101_03_SID          pValue.A0101_03_SID

  END IF;
  RETURN 1;
END;

--------------------------------------------------------------------------------

-- Betreiber
FUNCTION ReadBtrPrs RETURN tbBtr_Prs PIPELINED AS
  v tBtr_Prs;
BEGIN
  IF BTS1.fkt_inh.pers.ID <> '-1' THEN
    v.ref_id           := BTS1.fkt_inh.pers.ref_id;
    v.gueltig_von      := BTS1.fkt_inh.fkt.gueltig_von;
    v.gueltig_bis      := BTS1.fkt_inh.fkt.gueltig_bis;
    v.ID               := BTS1.fkt_inh.pers.ID;
    v.KURZBEZEICHNUNG1 := BTS1.fkt_inh.pers.KURZBEZEICHNUNG1;          
    v.KURZBEZEICHNUNG2 := BTS1.fkt_inh.pers.KURZBEZEICHNUNG2;          
    v.TYP           := BTS1.fkt_inh.pers.TYP;                
    v.Anrede        := BTS1.fkt_inh.pers.Anrede;          
    v.TITEL         :=  BTS1.fkt_inh.pers.TITEL;        
    v.VORNAME       := BTS1.fkt_inh.pers.VORNAME;
    v.NACHNAME      := BTS1.fkt_inh.pers.NACHNAME;
    v.Geburtsdatum  := BTS1.fkt_inh.pers.Geburtsdatum;
    v.Geburtsort    := BTS1.fkt_inh.pers.Geburtsort;
    v.BEZEICHNUNG   := BTS1.fkt_inh.pers.BEZEICHNUNG;
    v.BEZEICHNUNG2  := BTS1.fkt_inh.pers.BEZEICHNUNG2;
    v.RECHTSFORM    := BTS1.fkt_inh.pers.RECHTSFORM;
    --, PERS_ID, REF_ID   ein_d_personal., PERS_ID, REF_ID  
    v.VORSATZ_NACHNAME  := BTS1.fkt_inh.pers.VORSATZ_NACHNAME;
    v.NACHSATZ_NACHNAME := BTS1.fkt_inh.pers.NACHSATZ_NACHNAME;
    v.A0101_03_SID    := BTS1.fkt_inh.pers.A0101_03_SID;
    v.A0101_70_SID    := BTS1.fkt_inh.pers.A0101_70_SID;
    v.bemerkung       := BTS1.fkt_inh.pers.bemerkung;
    v.Telefon   := BTS1.fkt_inh.pers.Telefon;
    v.FAX       := BTS1.fkt_inh.pers.fax;
    v.Mobil     := BTS1.fkt_inh.pers.Mobil;
    v.EMAIL     := BTS1.fkt_inh.pers.email;
    v.weitere   := BTS1.fkt_inh.pers.weitere;
    v.Internet  := BTS1.fkt_inh.pers.Internet;
    v.Bemerkung := BTS1.fkt_inh.pers.bemerkung; 
    PIPE ROW( v );
  END IF;
  RETURN;  
END;

-- Speichern Betreiber - Person in Objektvariable
FUNCTION SaveBtrPrs(pValues IN tBtr_Prs) RETURN INTEGER AS
BEGIN

  IF pValues.ID <> '-1' THEN

    BTS1.fkt_inh.fkt.id     := SYS_GUID();
    BTS1.fkt_inh.fkt.TYP    := vINH;
    BTS1.fkt_inh.fkt.BTS_ID := vBTS_ID;
     
    BTS1.fkt_inh.fkt.gueltig_von    := pValues.gueltig_von;
    BTS1.fkt_inh.fkt.gueltig_bis    := pValues.gueltig_bis;
    BTS1.fkt_inh.pers.ID            := pValues.ID;
    BTS1.fkt_inh.pers.KURZBEZEICHNUNG1 := pValues.KURZBEZEICHNUNG1;
    BTS1.fkt_inh.pers.KURZBEZEICHNUNG2 := pValues.KURZBEZEICHNUNG2;
    BTS1.fkt_inh.pers.TYP           := pValues.TYP;              
    BTS1.fkt_inh.pers.ref_id        := pValues.ref_id;
    BTS1.fkt_inh.pers.Anrede        := pValues.Anrede;
    BTS1.fkt_inh.pers.TITEL         := pValues.TITEL;
    BTS1.fkt_inh.pers.VORNAME       := pValues.VORNAME;
    BTS1.fkt_inh.pers.NACHNAME      := pValues.NACHNAME;
    BTS1.fkt_inh.pers.Geburtsdatum  := pValues.Geburtsdatum;
    BTS1.fkt_inh.pers.Geburtsort    := pValues.Geburtsort;
    BTS1.fkt_inh.pers.BEZEICHNUNG   := pValues.BEZEICHNUNG;
    BTS1.fkt_inh.pers.BEZEICHNUNG2  := pValues.BEZEICHNUNG2;
    BTS1.fkt_inh.pers.RECHTSFORM    := pValues.RECHTSFORM;
    --, PERS_ID           ein_d_personal., PERS_ID, REF_ID  
    BTS1.fkt_inh.pers.VORSATZ_NACHNAME  := pValues.VORSATZ_nachname;
    BTS1.fkt_inh.pers.NACHSATZ_NACHNAME := pValues.NACHSATZ_NACHNAME;
    BTS1.fkt_inh.pers.A0101_03_SID := pValues.A0101_03_SID;
    BTS1.fkt_inh.pers.A0101_70_SID := pValues.A0101_70_SID;
 
    BTS1.fkt_inh.pers.Telefon := pValues.Telefon;  
    BTS1.fkt_inh.pers.fax     := pValues.FAX;       
    BTS1.fkt_inh.pers.Mobil   := pValues.Mobil;     
    BTS1.fkt_inh.pers.email   := pValues.EMAIL;     
    BTS1.fkt_inh.pers.weitere := pValues.weitere;  
    BTS1.fkt_inh.pers.Internet:= pValues.Internet;  
    BTS1.fkt_inh.pers.bemerkung := pValues.bemerkung;
  END IF;  

  RETURN 1;
END;

-- BTR-Registrierung lesen
FUNCTION ReadBtrReg RETURN tbReg PIPELINED AS
v1 tReg;
BEGIN
  FOR c1 IN (
    SELECT reg.*  
    FROM d_registrierung reg
    WHERE reg.PRS_ID = BTS1.fkt_inh.pers.id
  ) LOOP
  
    v1.ID          := c1.ID;
    v1.PRS_ID      := c1.PRS_ID;
    v1.BTS_ID      := c1.BTS_ID;
    v1.TYP         := c1.TYP;
    v1.CODE        := c1.CODE;
    v1.NUMMER      := c1.NUMMER;
    v1.ZUSATZ      := c1.ZUSATZ;
    v1.GUELTIG_VON := c1.GUELTIG_VON;
    v1.GUELTIG_BIS := c1.GUELTIG_BIS;
    v1.REF_ID      := c1.REF_ID;
    v1.INS_DATE    := c1.INS_DATE;
    
    PIPE ROW( v1 );
  END LOOP;
  RETURN;
END; 

-- Speichern BTR-Registrierung in Objektvariable
FUNCTION SaveBtrReg(pValues IN tReg) RETURN INTEGER AS 
  iExt INTEGER := 0;
  res INTEGER := 1;
BEGIN
  IF pValues.ID <> '-1' THEN
    BTS1.btr_reg.EXTEND;
    iExt := BTS1.btr_reg.LAST;
    
    BTS1.btr_reg(iExt).ID          := pValues.ID;
    BTS1.btr_reg(iExt).PRS_ID      := BTS1.fkt_inh.pers.id;
    BTS1.btr_reg(iExt).BTS_ID      := NULL;
    BTS1.btr_reg(iExt).TYP         := pValues.TYP;
    BTS1.btr_reg(iExt).CODE        := pValues.CODE;
    BTS1.btr_reg(iExt).NUMMER      := pValues.NUMMER;
    BTS1.btr_reg(iExt).ZUSATZ      := pValues.ZUSATZ;
    BTS1.btr_reg(iExt).GUELTIG_VON := pValues.GUELTIG_VON;
    BTS1.btr_reg(iExt).GUELTIG_BIS := pValues.GUELTIG_BIS;
    BTS1.btr_reg(iExt).REF_ID      := pValues.REF_ID;
    BTS1.btr_reg(iExt).INS_DATE    := pValues.INS_DATE;
  ELSE
    res := 0;
  END IF;
  RETURN res;
END;


-- Lesen Betreiber-Betreiber Person
FUNCTION ReadBtr2Prs RETURN tbBtr_Prs PIPELINED AS
  v tBtr_Prs;
BEGIN
  IF BTS1.Btr2_Btr.ID <> '-1' THEN
    v.ref_id            := BTS1.Btr2_Btr.ref_id;
    v.gueltig_von       := NULL; --BTS1.inh2.fkt.gueltig_von;
    v.gueltig_bis       := NULL; --BTS1.inh2.fkt.gueltig_bis;
    v.ID                := BTS1.Btr2_Btr.ID;
    v.KURZBEZEICHNUNG1  := BTS1.Btr2_Btr.KURZBEZEICHNUNG1;          
    v.KURZBEZEICHNUNG2  := BTS1.Btr2_Btr.KURZBEZEICHNUNG2;          
    v.Anrede            := BTS1.Btr2_Btr.Anrede;          
    v.TITEL             := BTS1.Btr2_Btr.TITEL;        
    v.VORNAME           := BTS1.Btr2_Btr.VORNAME;
    v.NACHNAME          := BTS1.Btr2_Btr.NACHNAME;
    v.Geburtsdatum      := BTS1.Btr2_Btr.Geburtsdatum;
    v.Geburtsort        := BTS1.Btr2_Btr.Geburtsort;
    v.BEZEICHNUNG       := BTS1.Btr2_Btr.BEZEICHNUNG;
    v.BEZEICHNUNG2      := BTS1.Btr2_Btr.BEZEICHNUNG2;
    v.RECHTSFORM        := BTS1.Btr2_Btr.RECHTSFORM;
    v.VORSATZ_nachname  := BTS1.Btr2_Btr.VORSATZ_nachname;
    v.NACHSATZ_NACHNAME := BTS1.Btr2_Btr.NACHSATZ_NACHNAME;
    v.A0101_03_SID      := BTS1.Btr2_Btr.A0101_03_SID;
    v.A0101_70_SID      := BTS1.Btr2_Btr.A0101_70_SID;
    v.TYP               := BTS1.Btr2_Btr.TYP;    
    v.Bemerkung         := BTS1.Btr2_Btr.bemerkung;            
    --11.02.2014 v.r_TYP         := BTS1.Btr2_Btr.R_TYP;
    PIPE ROW( v );
  END IF;
  RETURN;  
END;

-- Speichern Betreiber zum Betreiber - Person in Objektvariable
FUNCTION SaveBtr2Prs(pValues IN tBtr_Prs) RETURN INTEGER AS
BEGIN

  IF pValues.ID <> '-1' THEN
   
    --BTS1.Btr2_Btr.gueltig_von        := pValues.gueltig_von;
    --BTS1.Btr2_Btr.gueltig_bis        := pValues.gueltig_bis;
    BTS1.Btr2_Btr.ID                 := pValues.ID;
    BTS1.Btr2_Btr.KURZBEZEICHNUNG1   := pValues.KURZBEZEICHNUNG1;
    BTS1.Btr2_Btr.KURZBEZEICHNUNG2   := pValues.KURZBEZEICHNUNG2;
    BTS1.Btr2_Btr.TYP                := pValues.TYP;              
    BTS1.Btr2_Btr.REF_ID             := pValues.ref_id;
    BTS1.Btr2_Btr.Anrede             := pValues.Anrede;
    BTS1.Btr2_Btr.TITEL              := pValues.TITEL;
    BTS1.Btr2_Btr.VORNAME            := pValues.VORNAME;
    BTS1.Btr2_Btr.NACHNAME           := pValues.NACHNAME;
    BTS1.Btr2_Btr.Geburtsdatum       := pValues.Geburtsdatum;
    BTS1.Btr2_Btr.Geburtsort         := pValues.Geburtsort;
    BTS1.Btr2_Btr.BEZEICHNUNG        := pValues.BEZEICHNUNG;
    BTS1.Btr2_Btr.BEZEICHNUNG2       := pValues.BEZEICHNUNG2;
    BTS1.Btr2_Btr.RECHTSFORM         := pValues.RECHTSFORM;  
    BTS1.Btr2_Btr.VORSATZ_nachname   := pValues.VORSATZ_nachname;
    BTS1.Btr2_Btr.NACHSATZ_NACHNAME  := pValues.NACHSATZ_NACHNAME;
    BTS1.Btr2_Btr.A0101_03_SID       := pValues.A0101_03_SID;
    BTS1.Btr2_Btr.A0101_70_SID       := pValues.A0101_70_SID;
    BTS1.Btr2_Btr.bemerkung          := pValues.bemerkung;
    --11.02.2014 BTS1.Btr2_Btr.r_TYP         := vINH;
  
  END IF;  

  RETURN 1;
END;

-- Lesen Betreiber Personal 
FUNCTION ReadBtrPersonal RETURN tbPersonal_Adr_Pst PIPELINED AS
BEGIN

  IF BTS1.Btr_Personal_Adr_Pst.COUNT > 0 THEN
    FOR i IN BTS1.Btr_Personal_Adr_Pst.FIRST .. BTS1.Btr_Personal_Adr_Pst.LAST LOOP
      PIPE ROW( BTS1.Btr_Personal_Adr_Pst(i) );
    END LOOP;
  END IF;
  RETURN;  
END;

-- Speichern Betreiber Personal
FUNCTION SaveBtrPersonal(pValues tPersonal_Adr_Pst) RETURN INTEGER AS
BEGIN
  BTS1.Btr_Personal_Adr_Pst.EXTEND();
  BTS1.Btr_Personal_Adr_Pst(BTS1.Btr_Personal_Adr_Pst.LAST) := pValues;
  RETURN 1;  
END;

-- Lesen Betreiber-Betreiber Personal 
FUNCTION ReadBtr2Personal RETURN tbPersonal_Adr_Pst PIPELINED AS
BEGIN

  IF BTS1.Btr2_Personal_Adr_Pst.COUNT > 0 THEN
    FOR i IN BTS1.Btr2_Personal_Adr_Pst.FIRST .. BTS1.Btr2_Personal_Adr_Pst.LAST LOOP
      PIPE ROW( BTS1.Btr2_Personal_Adr_Pst(i) );
    END LOOP;
  END IF;
  RETURN;  
END;

-- Speichern Betreiber-Betreiber Personal
FUNCTION SaveBtr2Personal(pValues tPersonal_Adr_Pst) RETURN INTEGER AS
BEGIN
  BTS1.Btr2_Personal_Adr_Pst.EXTEND();
  BTS1.Btr2_Personal_Adr_Pst(BTS1.Btr2_Personal_Adr_Pst.LAST) := pValues;
  RETURN 1;  
END;


-- Lesen Betreiber Standortadresse
FUNCTION ReadBtrAdr_Sto RETURN tbAdr PIPELINED AS
  v tAdr;
BEGIN
  v := ReadAllgAdresse(BTS1.fkt_inh.Adr_Sto);
  IF v.id <> '-1' THEN
    PIPE ROW( v );
  END IF;
  RETURN;  
END;

-- Speichern Betreiber Standortadresse in Objektvariable
FUNCTION SaveBtrAdr_Sto(pValues IN tAdr) RETURN INTEGER AS
BEGIN
  SaveAllgAdresse(BTS1.fkt_inh.Adr_Sto, pValues);
  RETURN 1;
END;

-- Lesen Betreiber zum Betreiber Standortadresse
FUNCTION ReadBtr2Adr_Sto RETURN tbAdr PIPELINED AS
  v tAdr;
BEGIN
  v := ReadAllgAdresse(BTS1.Btr2_Adr_Sto);
  IF v.id <> '-1' THEN
    PIPE ROW( v );
  END IF;
  RETURN;  
END;

-- Speichern Betreiber zum Betreiber Standortadresse in Objektvariable
FUNCTION SaveBtr2Adr_Sto(pValues IN tAdr) RETURN INTEGER AS
BEGIN
  SaveAllgAdresse(BTS1.Btr2_Adr_Sto, pValues);
  RETURN 1;
END;

-- Lesen Betreiber Postadresse
FUNCTION ReadBtrAdr_Pst RETURN tbAdr PIPELINED AS
  v tAdr;
BEGIN
  v := ReadAllgAdresse(BTS1.fkt_inh.Adr_Pst);
  IF v.id <> '-1' THEN
    PIPE ROW( v );
  END IF;
  RETURN;  
END;

-- Speichern Betreiber Postadresse in Objektvariable
FUNCTION SaveBtrAdr_Pst(pValues IN tAdr) RETURN INTEGER AS   
BEGIN
  SaveAllgAdresse(BTS1.fkt_inh.Adr_Pst, pValues);
  RETURN 1;
END;

-- Lesen Betreiber zum Betreiber Postadresse
FUNCTION ReadBtr2Adr_Pst RETURN tbAdr PIPELINED AS
  v tAdr;
BEGIN
  v := ReadAllgAdresse(BTS1.Btr2_Adr_Pst);
  IF v.id <> '-1' THEN
    PIPE ROW( v );
  END IF;
  RETURN;  
END;

-- Speichern Betreiber zum Betreiber Postadresse in Objektvariable
FUNCTION SaveBtr2Adr_Pst(pValues IN tAdr) RETURN INTEGER AS   
BEGIN
  SaveAllgAdresse(BTS1.Btr2_Adr_Pst, pValues);
  RETURN 1;
END;


--PROCEDURE Del_R_PERS_ADR(pPrs_ID IN VARCHAR2) AS
--BEGIN
--
--  DELETE D_ADRESSE WHERE prs_id = pPers_id;
--        
--END; 



/*******************************************************************************
  kompletten Eingangskorb fr eine Betriebssttte lschen
  Parameter:
  - pBTS_ID: ID der Betriebssttte Protokolls
*******************************************************************************/
PROCEDURE DeleteBts(pBTS_ID VARCHAR2) AS
  TYPE tADD_ID IS TABLE OF VARCHAR2(32 CHAR);
  vADD_ID tADD_ID := tADD_ID();
  PROCEDURE ADD_ADR_ID(pID IN VARCHAR2) IS
  BEGIN
    IF pID <> '-1' THEN
      vADD_ID.EXTEND;
      vADD_ID(vADD_ID.LAST) := pID;
    END IF;
  END;
  
PROCEDURE Del_Person(pPrs_ID IN VARCHAR2) AS 
BEGIN
  FOR c1 IN (
    SELECT prs.ID, prs.Adr_Pst_ID, prs.Adr_STZ_ID
    FROM d_personal prs
    WHERE prs.owner_prs_id = pPrs_ID
  ) LOOP
    
    Del_Person(c1.id);
            
    DELETE d_personal WHERE id = c1.id;
    Add_Adr_ID(c1.Adr_Pst_ID);
    Add_Adr_ID(c1.Adr_STZ_ID);
    
  END LOOP;
END;  
BEGIN
 
  -- ID's D_ADRESSE merken und am Ende lschen
  -- zugeordnete 
  -- bts: Adr_Pst_ID, Adr_Sto_ID, Adr_BTR_ID, Adr_Std_ID
  -- DEP: ADD_ID beim Lschen von DEP
  -- PRS: Adr_Pst_ID, Adr_STZ_ID
  
  FOR c1 IN (
    SELECT Adr_Pst_ID, Adr_Sto_ID, Adr_BTR_ID, Adr_Std_ID
    FROM D_BETRIEBSSTAETTE
    WHERE id = pBTS_ID
  ) LOOP
  
    ADD_ADR_ID(c1.Adr_Pst_ID);
    ADD_ADR_ID(c1.Adr_Sto_ID);
    ADD_ADR_ID(c1.Adr_BTR_ID);
    ADD_ADR_ID(c1.Adr_Std_ID);
    
  END LOOP;
  
  -- d_personal ber d_personalfunktion  
  FOR cPrs IN (
    SELECT fnc.prs_id, PRS.Adr_STZ_ID, PRS.Adr_Pst_ID
    FROM d_personalfunktion fnc
    JOIN d_personal prs ON prs.id = fnc.prs_id
    WHERE fnc.BTS_ID = pBTS_ID
  ) LOOP

    Del_Person(cPrs.prs_id);                  
                    
    DELETE d_personal WHERE id = cPrs.prs_id;
    Add_Adr_ID(cPrs.Adr_Pst_ID);
    Add_Adr_ID(cPrs.Adr_STZ_ID);    
    
  END LOOP; 
    
  -- 7.Fachbereiche
  DELETE d_fachbereich
  WHERE BTS_ID = pBTS_ID;
   
  --8. ein_D_BETRIEBSSTAETTE
  DELETE D_BETRIEBSSTAETTE
  WHERE id = pBTS_ID;   

  IF vADD_ID.COUNT > 0 THEN
    FOR i IN vAdd_ID.FIRST .. vADD_ID.LAST LOOP
      IF vADD_ID(i) <> '-1' THEN
        DELETE D_ADRESSE WHERE ID = vADD_ID(i);
      END IF;      
    END LOOP;
    
  END IF;
END;


-- allgemein ADRESSE/KATASTER/VERWALTUNG/POSTADRESSE in DB aktualisieren
PROCEDURE UpdateAllgAdresse(pAdr IN OUT NOCOPY tAdr) AS
 vAdr   D_ADRESSE%ROWTYPE;
BEGIN
    
  IF NVL(pAdr.ID, '-1') = '-1' THEN 
    RETURN;
  END IF;

  vAdr.FreiText             := pAdr.FreiText;
  vAdr.WECHSELNDER_STANDORT := pAdr.WECHSELNDER_STANDORT;
  vAdr.gueltig_von          := pAdr.gueltig_von;  
  vAdr.gueltig_bis          := pAdr.gueltig_bis; 
  vAdr.TYP                  := pAdr.TYP;         
  vAdr.ADRESSZUSATZ         := pAdr.ADRESSZUSATZ;      
  vAdr.ID                   := pAdr.id;
  --vAdr.ID          := NVL(pAdr.id, SYS_GUID());     
  --Kataster
  vAdr.Flurnummer   := pAdr.Flurnummer ; 
  vAdr.Flurstueck   := pAdr.Flurstueck; 
  vAdr.Gemarkung    := pAdr.Gemarkung; 
  vAdr.X_Wert       := pAdr.X_Wert; 
  vAdr.Y_Wert       := pAdr.Y_Wert; 
  vAdr.Rechtswert   := pAdr.Rechtswert; 
  vAdr.Hochwert     := pAdr.Hochwert; 
  vAdr.Koordinatenherkunft := pAdr.Koordinatenherkunft;
  vAdr.s09_sid             := NVL(pAdr.s09_sid, vDEFAULT_S09_SID);
      
  -- Postadresse
  vAdr.Hausnummer         := pAdr.Hausnummer; 
  vAdr.Hausnummernzusatz := pAdr.Hausnummernzusatz; 
  vAdr.Ort               := pAdr.Ort; 
  vAdr.Ortsteil          := pAdr.Ortsteil; 
  vAdr.Postfach          := pAdr.Postfach; 
  vAdr.Staat             := pAdr.Staat; 
  vAdr.STRASSE           := pAdr.STRASSE; 
  vAdr.PLZ               := pAdr.PLZ; 
  vAdr.GLO_A24_SID       := NVL(pAdr.GLO_A24_SID, vDEFAULT_A24_SID); 

  IF NVL(vAdr.TYP, 'x') NOT IN( Adr_STRASSE, Adr_Postfach) THEN 
    IF vAdr.STRASSE IS NOT NULL THEN
      vAdr.TYP := Adr_STRASSE;
    ELSIF vAdr.Postfach IS NOT NULL THEN
      vAdr.TYP := Adr_Postfach;
    END IF; 
  END IF;
     
  -- Verwaltung
  vAdr.GEMEINDE     := pAdr.GEMEINDE;
  vAdr.GKZ              := pAdr.GKZ;     
  vAdr.Teilort := pAdr.Teilort; 
        
    --  , BUNDESLAND    ein_d_verwaltung.BUNDESLAND
    --  , BEZIRK        ein_d_verwaltung.BEZIRK
    --  , KREIS         ein_d_verwaltung.KREIS
    --  , REGIONALSCHLUESSEL ein_d_verwaltung.REGIONALSCHLUESSEL
    --  , Staat         ein_d_verwaltung.Staat    
--   END IF; -- Ende Verwaltung

  --vAdr.TYP       := pAdr.Typ;
  vAdr.ins_date   := SYSDATE;
  vAdr.Postbezeichnung := pAdr.Postbezeichnung;
  
  INSERT INTO D_ADRESSE VALUES vAdr;
 
END;

-- Postadresse speichern 
FUNCTION UpdateAllgPadr(pValue IN tPersonal_Adr_Pst ) RETURN VARCHAR2 AS
  vAdr tAdr;
  res VARCHAR2(32 CHAR) := '-1';
BEGIN
  
  IF pValue.Hausnummer IS NOT NULL OR      
     pValue.Hausnummernzusatz IS NOT NULL OR
     pValue.Ort IS NOT NULL OR         
     pValue.Ortsteil IS NOT NULL OR    
     pValue.Postfach IS NOT NULL OR    
     pValue.Staat IS NOT NULL OR       
     pValue.STRASSE IS NOT NULL OR     
     pValue.PLZ IS NOT NULL OR 
     pValue.GKZ IS NOT NULL OR        
     pValue.GLO_A24_SID <> -1 THEN
      
    IF NVL(vAdr.ID, '-1') = '-1' THEN
      vAdr.ID := SYS_GUID();    
    END IF; 
    
    res := vAdr.ID;
    -- Postadressen
    vAdr.Hausnummer        := pValue.Hausnummer;
    vAdr.Hausnummernzusatz := pValue.Hausnummernzusatz;
    vAdr.Ort               := pValue.Ort;
    vAdr.Ortsteil          := pValue.Ortsteil;
    vAdr.Postfach          := pValue.Postfach;
    vAdr.Staat             := pValue.Staat;
    vAdr.STRASSE           := pValue.STRASSE;
    vAdr.PLZ               := pValue.PLZ;
    vAdr.GLO_A24_SID       := NVL(pValue.GLO_A24_SID, vDEFAULT_A24_SID);
    vAdr.GKZ               := pValue.GKZ;
    vAdr.TYP               := pValue.ADR_TYPE;
    
    UpdateAllgAdresse(vAdr);
             
  END IF;
  
  RETURN res;
END;

PROCEDURE InsertPersonal_PAdr(pValues IN tPersonal_Adr_Pst) AS
  vPers d_personal%ROWTYPE;
  vAdr_ID VARCHAR2(32 CHAR);
BEGIN

  vPers.ID               := pValues.ID; 
  vPers.owner_type       := pValues.owner_type;
  vPers.owner_prs_id     := pValues.owner_prs_id;
  vPers.KURZBEZEICHNUNG1 := pValues.KURZBEZEICHNUNG1; 
  vPers.KURZBEZEICHNUNG2 := pValues.KURZBEZEICHNUNG2; 
  IF pValues.TYP IS NULL THEN
    vPers.TYP := vTypeNP;
  ELSE
    vPers.TYP := pValues.TYP;
  END IF; 
  vPers.Anrede            := pValues.Anrede; 
  vPers.TITEL             := pValues.TITEL; 
  vPers.VORNAME           := pValues.VORNAME; 
  vPers.NACHNAME          := pValues.NACHNAME; 
  vPers.Geburtsdatum      := pValues.Geburtsdatum; 
  vPers.Geburtsort        := pValues.Geburtsort; 
  vPers.BEZEICHNUNG       := pValues.BEZEICHNUNG; 
  vPers.BEZEICHNUNG2      := pValues.BEZEICHNUNG2; 
  vPers.RECHTSFORM        := pValues.RECHTSFORM; 
  vPers.VORSATZ_nachname  := pValues.VORSATZ_nachname; 
  vPers.NACHSATZ_NACHNAME := pValues.NACHSATZ_NACHNAME; 
  vPers.HAUPTANSPRECHPARTNER_JN := NVL(pValues.HAUPTANSPRECHPARTNER_JN, 0);
  vPers.A0101_03_SID   := pValues.A0101_03_SID;            
  vPers.A0101_70_SID   := pValues.A0101_70_SID;            
  vPers.bemerkung      := pValues.bemerkung;            
  
  vPers.Telefon  := pValues.Telefon;
  vPers.fax      := pValues.fax;
  vPers.Mobil    := pValues.Mobil;
  vPers.Internet := pValues.Internet;
  vPers.weitere  := pValues.weitere;
  
  vPers.ins_date       := SYSDATE;          

  vPers.Adr_Pst_ID := NULL;
  vPers.Adr_STZ_ID := NULL;
  -- Postadresse anlegen
  vAdr_ID := UpdateAllgPAdr(pValues/*, null, null, vPers.ID, vBTRA */);
  IF Not EmptyID(vAdr_ID) THEN
    vPers.Adr_Pst_ID := vAdr_ID;
  END IF;
  
  INSERT INTO d_personal VALUES vPers;
                           
END;

-- Speichern der usecases
PROCEDURE Insertusecase AS
BEGIN


  IF BTS1.Usc.COUNT = 0 THEN
    RETURN;
  END IF;
  
  FOR i IN BTS1.USC.FIRST .. BTS1.USC.LAST LOOP
    INSERT INTO d_usecase
    ( ID, BTS_ID, BTS_ID2, D0101_ID, usecase, 
      MANDANT, user_name, USER_SID, LETZTE_AENDERUNG, gueltig_von, gueltig_bis, 
      typ, Aenderungsgrund, Bemerkung, A0101_501_SID,
      Alter_Wert, Neuer_Wert, Fehlermeldung, INS_DATE, INS_USER, DELETED, 
      /*DEL_USER, DEL_DATE,*/ FB, USC_ID, ZB, EXTERNE_MELDUNG, BESTAETIGUNG, upd_date, upd_user
    ) VALUES (
      BTS1.Usc(i).ID, BTS1.USC(i).BTS_ID, NULL, BTS1.USC(i).D0101_ID, BTS1.USC(i).usecase,
      BTS1.USC(i).mandant, BTS1.USC(i).user_name, BTS1.USC(i).user_sid, SYSDATE, BTS1.USC(i).gueltig_von, BTS1.USC(i).gueltig_bis,
      BTS1.USC(i).typ, BTS1.USC(i).Aenderungsgrund, BTS1.USC(i).Bemerkung, BTS1.USC(i).A0101_501_SID,
      BTS1.USC(i).Alter_Wert, BTS1.USC(i).Neuer_Wert, NULL, SYSDATE, BTS1.USC(i).user_sid, 0, 
      BTS1.USC(i).FB, NULL, BTS1.USC(i).zb, NULL, 0, SYSDATE, vUser_SID
    );
         
  END LOOP;
  
END;

-- Daten in DB-Speichern  
FUNCTION SaveFinaly(pBTS_ID IN VARCHAR2, pWithOutClear INTEGER := 0) RETURN INTEGER AS
  res INTEGER := 1;
  --vCnt INTEGER;
  vPers d_personal%ROWTYPE;
  vAdr_ID D_ADRESSE.id%TYPE;
  vProt d_protokoll%ROWTYPE;
  vSysdate DATE := SYSDATE;
BEGIN
  IF vBTS_ID = pBTS_ID THEN
    
    -- kompletten Eingangskorb zur Betriebsstaette lschen
    Deletebts(vBTS_ID);
    
    BTS1.bts.ins_date := vSysdate;

    -- Betriebssttte Standortadresse
    IF BTS1.Adr_Sto.id <> '-1' THEN     
      BTS1.bts.Adr_Sto_ID := BTS1.Adr_Sto.id;
      UpdateAllgAdresse( BTS1.Adr_Sto );
    ELSE
      BTS1.bts.Adr_Sto_ID := NULL;
    END IF;

    -- Betriebssttte Postadresse
    IF BTS1.Adr_Pst.id <> '-1' AND BTS1.Adr_Pst.id <> NVL(BTS1.Adr_Sto.id, '-1') THEN
      BTS1.bts.Adr_Pst_ID := BTS1.Adr_Pst.id;    
      UpdateAllgAdresse( BTS1.Adr_Pst );  
    ELSE
      BTS1.bts.Adr_Pst_ID := BTS1.Adr_Sto.id; -- Postadresse wie Standortadresse 
    END IF;
    
    INSERT INTO D_BETRIEBSSTAETTE ( 
    ID, Adr_Pst_ID, Adr_Sto_ID, --Adr_BTR_ID, Adr_Std_ID, 
    BEZEICHNUNG, gueltig_von, gueltig_bis, 
    D0101_ID, ZB, kennzeichen, INS_DATE, 
    Telefon, FAX, Internet, Mobil, EMAIL, weitere,
    bemerkung )
    VALUES (
      BTS1.bts.ID ,
      BTS1.bts.Adr_Pst_ID, 
      BTS1.bts.Adr_Sto_ID, 
--      BTS1.bts.Adr_BTR_ID, 
--      BTS1.bts.Adr_Std_ID, 

      BTS1.bts.BEZEICHNUNG, 
      BTS1.bts.gueltig_von,
      BTS1.bts.gueltig_bis,
      BTS1.bts.d0101_ID,
      BTS1.bts.ZB, 
      BTS1.bts.kennzeichen,
      BTS1.bts.INS_DATE,

      BTS1.bts.Telefon, 
      BTS1.bts.FAX, 
      BTS1.bts.Internet,
      BTS1.bts.Mobil, 
      BTS1.bts.EMAIL,
      BTS1.bts.weitere,
      BTS1.bts.bemerkung);

    -- Protokoll    
    IF BTS1.prot.id <> '-1' THEN
      BTS1.prot.BTS_ID :=  BTS1.bts.id;
      BTS1.prot.ins_date := vSYSDATE;
      
      vProt.ID        := BTS1.prot.ID;
      vProt.BTS_ID    := BTS1.prot.BTS_ID;
      vProt.D0101_ID  := BTS1.prot.D0101_ID;
      vProt.STATUS    := BTS1.prot.STATUS;
      vProt.INS_DATE  := BTS1.prot.INS_DATE;
      vProt.USER_SID  := BTS1.prot.USER_SID;
      vProt.LETZTE_AENDERUNG := BTS1.prot.LETZTE_AENDERUNG;
      vProt.MANDANT   := BTS1.prot.MANDANT;
      vProt.DELETED   := BTS1.prot.DELETED;
      vProt.PARAMETER := BTS1.prot.PARAMETER;
      vProt.DATENHERKUNFT := BTS1.prot.DATENHERKUNFT;
      vProt.UPD_USER  := vUser_SID;
      vProt.UPD_DATE  := vSysdate;
      
      INSERT INTO d_protokoll VALUES vProt;
      --BTS1.prot;
    END IF;
    
    -- usecase    
    InsertUsecase();
    
    -- Betriebsstaette Fachbereiche
    IF  BTS1.FAB.COUNT > 0 THEN
      FOR i IN BTS1.FAB.FIRST .. BTS1.FAB.LAST LOOP
        BTS1.FAB(i).ins_date := vSysdate;
      END LOOP;
      
      FORALL i IN BTS1.FAB.FIRST .. BTS1.FAB.LAST
      INSERT INTO d_fachbereich ( 
        ID, BTS_ID, CODE, A0101_06_SID, gueltig_von, gueltig_bis, D010104_ID, 
        A0115_SID, A0101_01_SID, ERSTKONTROLLTERMIN, INS_DATE )
        VALUES ( 
            BTS1.FAB(i).ID, 
            BTS1.FAB(i).BTS_ID, 
            BTS1.FAB(i).CODE,
            BTS1.FAB(i).A0101_06_SID,
            BTS1.FAB(i).gueltig_von,
            BTS1.FAB(i).gueltig_bis,
            BTS1.FAB(i).D010104_ID,
            BTS1.FAB(i).A0115_SID,
            BTS1.FAB(i).A0101_01_SID,
            BTS1.FAB(i).ERSTKONTROLLTERMIN,
            BTS1.FAB(i).INS_DATE);                  
    END IF;

    -- Betriebsstaette Registrierungen
    IF  BTS1.Reg.COUNT > 0 THEN
      FOR i IN BTS1.Reg.FIRST .. BTS1.Reg.LAST LOOP
        BTS1.Reg(i).ins_date := vSysdate;
      END LOOP;

      FORALL i IN BTS1.Reg.FIRST .. BTS1.Reg.LAST      
      INSERT INTO d_registrierung ( 
        ID, PRS_ID, BTS_ID, TYP, CODE, NUMMER, ZUSATZ, GUELTIG_VON, GUELTIG_BIS, REF_ID, INS_DATE)        
        VALUES ( 
            BTS1.Reg(i).ID, 
            BTS1.Reg(i).PRS_ID, 
            BTS1.Reg(i).BTS_ID,
            BTS1.Reg(i).TYP,
            BTS1.Reg(i).CODE,
            BTS1.Reg(i).NUMMER,
            BTS1.Reg(i).ZUSATZ,
            BTS1.Reg(i).GUELTIG_VON,
            BTS1.Reg(i).GUELTIG_BIS,
            BTS1.Reg(i).REF_ID,
            BTS1.Reg(i).INS_DATE);    
    END IF; 

    -- Betriebsstaette Betriebsarten
    IF  BTS1.Bar.COUNT > 0 THEN
      FOR i IN BTS1.Bar.FIRST .. BTS1.Bar.LAST LOOP
        BTS1.Bar(i).ins_date := vSysdate;
      END LOOP;

      FORALL i IN BTS1.Bar.FIRST .. BTS1.Bar.LAST      
      INSERT INTO d_betriebsart ( 
        ID, BTS_ID, TYP, CODE, BEZEICHNUNG, FB, GUELTIG_VON, GUELTIG_BIS, 
        D010101_ID, GELTUNGSBEREICH, GEWERBSMAESSIG_JN, INS_DATE, ADR_STO_ID
        )  
        VALUES ( 
          BTS1.Bar(i).ID, 
          BTS1.Bar(i).BTS_ID, 
          BTS1.Bar(i).TYP, 
          BTS1.Bar(i).CODE, 
          BTS1.Bar(i).BEZEICHNUNG, 
          BTS1.Bar(i).FB, 
          BTS1.Bar(i).GUELTIG_VON, 
          BTS1.Bar(i).GUELTIG_BIS,
          BTS1.Bar(i).D010101_ID,
          BTS1.Bar(i).GELTUNGSBEREICH,
          BTS1.Bar(i).GEWERBSMAESSIG_JN,
          BTS1.Bar(i).INS_DATE,
          BTS1.Bar(i).ADR_STO_ID);
    END IF; 
       
    -- Betriebssttte Personal
    IF Bts1.fkt_hv.personal.Count > 0 THEN
      FORALL i IN Bts1.fkt_hv.personal.FIRST .. Bts1.fkt_hv.Personal.Last 
      INSERT INTO d_personal VALUES Bts1.fkt_hv.personal(i);
          
      FOR i IN Bts1.fkt_hv.personal.FIRST .. Bts1.fkt_hv.Personal.Last LOOP 
        INSERT INTO d_personalfunktion (
        ID, TYP, PRS_ID, BTS_ID, GUELTIG_VON, GUELTIG_BIS, INS_DATE )
        VALUES (
        SYS_GUID(), 
        CASE WHEN Bts1.fkt_hv.personal(i).hauptansprechpartner_jn = 1 THEN HV ELSE PERSONAL END, 
        Bts1.fkt_hv.personal(i).id, vBTS_ID, NULL, NULL, vSYSDATE 
        );
        
      END LOOP;
      
    END IF;        
    
    -- Betreiber
    IF BTS1.fkt_inh.pers.id <> '-1' THEN
      
      -- Person      
--      IF BTS1.fkt_inh.pers.typ IS NULL THEN
--        IF BTS1.fkt_inh.pers.NACHNAME IS NULL THEN
--          BTS1.fkt_inh.pers.typ := 'JP';
--        ELSE
--          BTS1.fkt_inh.pers.typ := 'NP';          
--        END IF;
--      END IF;
      BTS1.fkt_inh.pers.ins_date := SYSDATE;
        -- werden nach dem Anlegen der Adresse gesetzt
      
      
      IF BTS1.fkt_inh.Adr_Pst.id <> '-1' THEN -- Postadresse des Betreibers
        BTS1.fkt_inh.pers.Adr_Pst_ID := BTS1.fkt_inh.Adr_Pst.id;      
        UpdateAllgAdresse( BTS1.fkt_inh.Adr_Pst );
      ELSE
        BTS1.fkt_inh.pers.Adr_Pst_ID := NULL;
      END IF;
      IF BTS1.fkt_inh.Adr_Sto.id <> '-1' AND BTS1.fkt_inh.Adr_Sto.id  <> NVL(BTS1.fkt_inh.Adr_Pst.id, '-1') THEN -- Standortadresse des Betreibers
        BTS1.fkt_inh.pers.Adr_STZ_ID := BTS1.fkt_inh.Adr_Sto.id;   
        UpdateAllgAdresse( BTS1.fkt_inh.Adr_Sto );
        
      ELSE
        BTS1.fkt_inh.pers.Adr_STZ_ID := BTS1.fkt_inh.Adr_Pst.id;
      END IF;      
      
      INSERT INTO d_personal VALUES BTS1.fkt_inh.pers;

      BTS1.fkt_inh.fkt.BTS_ID := vBTS_ID;
      BTS1.fkt_inh.fkt.prs_id := BTS1.fkt_inh.pers.id; 
      BTS1.fkt_inh.fkt.TYP := vINH;
      BTS1.fkt_inh.fkt.ins_date := SYSDATE;
      INSERT INTO d_personalfunktion VALUES BTS1.fkt_inh.fkt;
    
      -- Betreiber Registrierungen
      IF  BTS1.Btr_Reg.COUNT > 0 THEN
        FOR i IN BTS1.Btr_Reg.FIRST .. BTS1.Btr_Reg.LAST LOOP
          BTS1.Btr_Reg(i).ins_date := vSysdate;
        END LOOP;

        FORALL i IN BTS1.Btr_Reg.FIRST .. BTS1.Btr_Reg.LAST      
        INSERT INTO d_registrierung ( 
          ID, PRS_ID, BTS_ID, TYP, CODE, NUMMER, ZUSATZ, GUELTIG_VON, GUELTIG_BIS, REF_ID, INS_DATE)        
          VALUES ( 
              BTS1.Btr_Reg(i).ID, 
              BTS1.Btr_Reg(i).PRS_ID, 
              BTS1.Btr_Reg(i).BTS_ID,
              BTS1.Btr_Reg(i).TYP,
              BTS1.Btr_Reg(i).CODE,
              BTS1.Btr_Reg(i).NUMMER,
              BTS1.Btr_Reg(i).ZUSATZ,
              BTS1.Btr_Reg(i).GUELTIG_VON,
              BTS1.Btr_Reg(i).GUELTIG_BIS,
              BTS1.Btr_Reg(i).REF_ID,
              BTS1.Btr_Reg(i).INS_DATE);      
      END IF; 

      IF BTS1.Btr_Personal_Adr_Pst.COUNT > 0 THEN -- Betreiber-Personal
        
        FOR iExt IN BTS1.Btr_Personal_Adr_Pst.FIRST .. BTS1.Btr_Personal_Adr_Pst.LAST LOOP 
          IF BTS1.Btr_Personal_Adr_Pst(iExt).ID <> '-1' THEN
            vPers.ID                 := BTS1.Btr_Personal_Adr_Pst(iExt).ID; 
            --vPers.R_TYP            := BTS1.INH_PERSONAL(iExt).R_TYP; 
            vPers.KURZBEZEICHNUNG1   := BTS1.Btr_Personal_Adr_Pst(iExt).KURZBEZEICHNUNG1; 
            vPers.KURZBEZEICHNUNG2   := BTS1.Btr_Personal_Adr_Pst(iExt).KURZBEZEICHNUNG2; 
            IF BTS1.Btr_Personal_Adr_Pst(iExt).TYP IS NULL THEN
              vPers.TYP := vTypeNP;
            ELSE
              vPers.TYP := BTS1.Btr_Personal_Adr_Pst(iExt).TYP;
            END IF; 
            vPers.Anrede            := BTS1.Btr_Personal_Adr_Pst(iExt).Anrede; 
            vPers.TITEL             := BTS1.Btr_Personal_Adr_Pst(iExt).TITEL; 
            vPers.VORNAME           := BTS1.Btr_Personal_Adr_Pst(iExt).VORNAME; 
            vPers.NACHNAME          := BTS1.Btr_Personal_Adr_Pst(iExt).NACHNAME; 
            vPers.Geburtsdatum      := BTS1.Btr_Personal_Adr_Pst(iExt).Geburtsdatum; 
            vPers.Geburtsort        := BTS1.Btr_Personal_Adr_Pst(iExt).Geburtsort; 
            vPers.BEZEICHNUNG       := BTS1.Btr_Personal_Adr_Pst(iExt).BEZEICHNUNG; 
            vPers.BEZEICHNUNG2      := BTS1.Btr_Personal_Adr_Pst(iExt).BEZEICHNUNG2; 
            vPers.RECHTSFORM        := BTS1.Btr_Personal_Adr_Pst(iExt).RECHTSFORM; 
            vPers.VORSATZ_nachname  := BTS1.Btr_Personal_Adr_Pst(iExt).VORSATZ_nachname; 
            vPers.NACHSATZ_NACHNAME := BTS1.Btr_Personal_Adr_Pst(iExt).NACHSATZ_NACHNAME; 
            vPers.HAUPTANSPRECHPARTNER_JN := NVL(BTS1.Btr_Personal_Adr_Pst(iExt).HAUPTANSPRECHPARTNER_JN, 0); 
            vPers.A0101_03_SID      := BTS1.Btr_Personal_Adr_Pst(iExt).A0101_03_SID;            
            vPers.A0101_70_SID      := BTS1.Btr_Personal_Adr_Pst(iExt).A0101_70_SID;            
            vPers.bemerkung         := BTS1.Btr_Personal_Adr_Pst(iExt).bemerkung;            
            
            vPers.Telefon  := BTS1.Btr_Personal_Adr_Pst(iExt).Telefon;
            vPers.fax      := BTS1.Btr_Personal_Adr_Pst(iExt).fax;
            vPers.Mobil    := BTS1.Btr_Personal_Adr_Pst(iExt).Mobil;
            vPers.Internet := BTS1.Btr_Personal_Adr_Pst(iExt).Internet;
            vPers.weitere  := BTS1.Btr_Personal_Adr_Pst(iExt).weitere;
            
            vPers.owner_prs_id := BTS1.fkt_inh.pers.id;
            vPers.owner_TYPE := Personal;
            vPers.ins_date := SYSDATE;

            vPers.Adr_Pst_ID := NULL;
            vPers.Adr_STZ_ID := NULL;

            -- Postadresse anlegen            
            vAdr_ID := UpdateAllgPAdr(BTS1.Btr_Personal_Adr_Pst(iExt)/*, NULL, NULL, BTS1.INH_PERSON_Padr(iExt).ID, vBTRA */);
            IF vAdr_ID <> '-1' THEN
              vPers.Adr_Pst_ID := vAdr_ID;
            END IF;

            INSERT INTO d_personal VALUES vPers;
                                   
          END IF;        
        
        END LOOP;           
      
      END IF;  -- Betreiber-Personal
    
      -- Betreiber-Betreiber Person
      IF BTS1.Btr2_Btr.id <> '-1' THEN
--          TYPE tBtr_Prs IS RECORD(
--        gueltig_von        ein_d_funktion.gueltig_von%TYPE
--      , gueltig_bis        ein_d_funktion.gueltig_bis%TYPE
--      , R_TYP              ein_r_pers_pers.typ%TYPE
        vPers := NULL;
        vPers.ID                 := BTS1.Btr2_Btr.ID;
        vPers.ref_id             := BTS1.Btr2_Btr.ref_id;  -- 20.10.2014
        --vPers.R_TYP            := BTS1.INH_PERSONAL(iExt).R_TYP; 
        vPers.KURZBEZEICHNUNG1   := BTS1.Btr2_Btr.KURZBEZEICHNUNG1;
        vPers.KURZBEZEICHNUNG2   := BTS1.Btr2_Btr.KURZBEZEICHNUNG2;
        IF BTS1.Btr2_Btr.TYP IS NULL THEN
          vPers.TYP := vTypeNP;
        ELSE
          vPers.TYP := BTS1.Btr2_Btr.TYP;
        END IF; 
        vPers.Anrede            := BTS1.Btr2_Btr.Anrede;
        vPers.TITEL             := BTS1.Btr2_Btr.TITEL;
        vPers.VORNAME           := BTS1.Btr2_Btr.VORNAME; 
        vPers.NACHNAME          := BTS1.Btr2_Btr.NACHNAME;
        vPers.Geburtsdatum      := BTS1.Btr2_Btr.Geburtsdatum;
        vPers.Geburtsort        := BTS1.Btr2_Btr.Geburtsort;
        vPers.BEZEICHNUNG       := BTS1.Btr2_Btr.BEZEICHNUNG;
        vPers.BEZEICHNUNG2      := BTS1.Btr2_Btr.BEZEICHNUNG2;
        vPers.RECHTSFORM        := BTS1.Btr2_Btr.RECHTSFORM;
        vPers.VORSATZ_nachname  := BTS1.Btr2_Btr.VORSATZ_nachname;
        vPers.NACHSATZ_NACHNAME := BTS1.Btr2_Btr.NACHSATZ_NACHNAME;
        vPers.A0101_03_SID      := BTS1.Btr2_Btr.A0101_03_SID;       
        vPers.A0101_70_SID      := BTS1.Btr2_Btr.A0101_70_SID;
        vPers.owner_prs_id      := BTS1.fkt_inh.pers.id;
        vPers.owner_type        := Betreiber;
        vPers.ins_date          := SYSDATE;   
        
        vPers.Telefon  := BTS1.Btr2_Btr.Telefon;
        vPers.fax      := BTS1.Btr2_Btr.fax;
        vPers.Mobil    := BTS1.Btr2_Btr.Mobil;
        vPers.Internet := BTS1.Btr2_Btr.Internet;
        vPers.weitere  := BTS1.Btr2_Btr.weitere;        
        vPers.Bemerkung:= Bts1.Btr2_Btr.Bemerkung;
         
        IF BTS1.Btr2_Adr_Pst.ID <> '-1' THEN -- Postadresse Betreiber - Betreiber
          vPers.Adr_Pst_ID := BTS1.Btr2_Adr_Pst.ID; 
          UpdateAllgAdresse( BTS1.Btr2_Adr_Pst );
        ELSE
          vPers.Adr_Pst_ID := NULL;
        END IF;        

        IF BTS1.Btr2_Adr_Sto.ID <> '-1' THEN -- Standortadresse Betreiber - Betreiber
          vPers.Adr_STZ_ID := BTS1.Btr2_Adr_Sto.ID;      
          UpdateAllgAdresse( BTS1.Btr2_Adr_Sto );
        ELSE
          vPers.Adr_STZ_ID := NULL;
        END IF;         
                
        INSERT INTO d_personal VALUES vPers;              
        
        -- Betreiber-Betreiber Personal        
        IF BTS1.Btr2_Personal_Adr_Pst.COUNT > 0 THEN
          FOR iExt IN BTS1.Btr2_Personal_Adr_Pst.FIRST .. BTS1.Btr2_Personal_Adr_Pst.LAST LOOP
            IF BTS1.Btr2_Personal_Adr_Pst(iExt).ID <> '-1' THEN
              BTS1.Btr2_Personal_Adr_Pst(iExt).owner_prs_id := BTS1.Btr2_Btr.ID;
              BTS1.Btr2_Personal_Adr_Pst(iExt).owner_type := Personal;
              -- Postanschrift
              InsertPersonal_PAdr( BTS1.Btr2_Personal_Adr_Pst(iExt)) ;
            END IF;
          END LOOP;
        END IF;    
      END IF;
    ELSE
      res := 0;
    END IF;  -- BTS1.fkt_inh.pers.id <> '-1'
    
    If pWithOutClear = 0 THEN    
      Clear_bts(BTS1);
    END IF;
  ELSE
    res := 0;
  END IF;
  RETURN res;
END;

PROCEDURE AddPlausiMsg(pMsg IN VARCHAR2) AS
BEGIN
  vPlausiMsg := vPlausiMsg || pMsg || vCRLF;
  vPlausiErrCnt := vPlausiErrCnt + 1;
END;

-- Ausfhrung der Plausi, FillBTS1 wurde bereits ausgefhrt
-- Daten sind schon im internen Speichern
-- Plausiprfung fr BTS / BTR deaktivieren
-- pBTS = 0 : keine Plausi fr BTS
-- pBTR = 0 : keine Plausi fr BTR 
PROCEDURE Plausi(pBTS IN INTEGER := 1, pBTR IN INTEGER := 1) AS
--vOK INTEGER := 0;
vPLZExists INTEGER := 0;
  PROCEDURE MsgPLZBetreiber AS
  BEGIN
    AddPlausiMsg('Die PLZ der Sitzadresse des Betreibers muss gefllt sein.');
  END;
BEGIN
  vPlausiErrCnt := 0;
  vPlausiMsg := NULL;
  
  IF BTS1.usc.COUNT = 0 THEN
    RETURN;
  END IF;
/*
--'ANL_BTR' THEN        -- Neuanlage
'AEND_BEZ_BTR'         THEN  -- Zusatzbezeichnung der Betriebssttte
'KOR_BEZ_BTR'          THEN  -- KORREKTUR STANDORTBEZEICHNUNG BETRIEBSSTTTE
'AEND_KOM_BTR'         THEN  -- ndern der Kommunikationsmittel der Betriebssttte
'KOR_KOM_BTR'          THEN  -- KORREKTUR KOMMUNIKATIONSMITTEL BETRIEBSSTTTE        
'AEND_STANDORT_BTR'    THEN  -- ndern der Standortadresse der Betriebssttte
'KOR_STANDORT_BTR'     THEN  -- KORREKTUR STANDORTADRESSE BETRIEBSSTTTE
'KOR_POST_ADR_BTR'     THEN  -- KORREKTUR POSTADRESSE BETRIEBSSTTTE
'AEND_POST_ADR_BTR'    THEN  -- NDERUNG POSTADRESSE BETRIEBSSTTTE

'AEND_NAME_BETREI'     THEN  -- ndern des Namen des Betreibers
'KOR_NAME_BETREI'     THEN  -- ndern des Namen des Betreibers
'AEND_BETREI'          THEN  -- ndern des Betreibers einer Betriebssttte
'AEND_KOM_BETREI'      THEN  -- ndern der Kommunikationsmittel des Betreibers
'KOR_KOM_BETREI'       THEN  -- KORREKTUR KOMMUNIKATIONSMITTEL BETREIBER
'AEND_SITZ_ADR'        THEN  -- NDEURNG SITZADRESSE BETREIBER
'KOR_SITZ_ADR'         THEN  -- KORREKTUR SITZADRESSE BETREIBER
'AEND_POST_ADR_BETREI' THEN  -- ndern der Postadresse des Betreibers
'KOR_POST_ADR_BETREI'  THEN  -- KORREKTUR POSTADRESSE BETEIBER
'KOR_RECHTSFORM'  THEN  -- ndern Rechtsform BETREIBER

*/

  FOR iUsc IN BTS1.usc.FIRST .. BTS1.usc.LAST LOOP
  
    IF BTS1.prot.parameter LIKE '%opt_betreiber=2%' AND pBTR = 1 THEN -- nur bei neuem Betreiber
      -- Betreibers Rechtsform 
      IF EmptyID(BTS1.FKT_INH.PERS.a0101_03_sid) 
      AND BTS1.Usc(iUSC).usecase IN ('ANL_BTR', 'KOR_RECHTSFORM' ) THEN
        AddPlausiMsg('Die Rechtsform muss gesetzt sein.');
      END IF;
      
      -- Betreiber Bezeichnung
--      IF BTS1.fkt_inh.pers.BEZEICHNUNG IS NULL 
--      AND BTS1.Usc(iUSC).usecase IN ('ANL_BTR', 'AEND_NAME_BETREI', 'KOR_NAME_BETREI') THEN
--        AddPlausiMsg('Die Bezeichnung muss gefllt sein.');
--      END IF;

      -- Betreiber Bezeichnung
      IF BTS1.Usc(iUSC).usecase IN ('ANL_BTR', 'AEND_NAME_BETREI', 'KOR_NAME_BETREI') THEN
        CASE
        WHEN BTS1.fkt_inh.pers.BEZEICHNUNG IS NULL        
        AND GetRechtsformTyp( BTS1.FKT_INH.PERS.a0101_03_sid) = 'F'  THEN
          AddPlausiMsg('Die Bezeichnung muss gefllt sein.');
        WHEN BTS1.FKT_INH.PERS.nachname IS NULL 
        AND GetRechtsformTyp( BTS1.FKT_INH.PERS.a0101_03_sid) = 'N' THEN
          AddPlausiMsg('Der Nachname muss gefllt sein.');
        ELSE NULL;    
        END CASE;
      END IF;
         
      -- Betreiber Sitzadresse    
      IF BTS1.fkt_inh.Adr_Sto.PLZ IS NULL 
      AND BTS1.Usc(iUSC).usecase IN ('ANL_BTR', 'AEND_SITZ_ADR', 'KOR_SITZ_ADR') THEN
        IF BTS1.fkt_inh.pers.a0101_03_sid = GBR THEN
          -- Zustzlich Adresse Personal prfen
          IF BTS1.Btr_Personal_Adr_Pst.COUNT = 0 THEN
            MsgPLZBetreiber();
          ELSE
            FOR iStaff IN BTS1.Btr_Personal_Adr_Pst.FIRST .. BTS1.Btr_Personal_Adr_Pst.LAST LOOP
              IF BTS1.Btr_Personal_Adr_Pst(iStaff).PLZ IS NOT NULL THEN -- Personal mit PLZ vorh.
                vPLZExists := 1;
              END IF;
              EXIT WHEN vPLZExists = 1;                
            END LOOP;
            IF vPLZExists = 0 THEN
              MsgPLZBetreiber();
            END IF;
          END IF;
        ELSE
          MsgPLZBetreiber();
        END IF;
      END IF;

      -- Betreiber Postadresse
      IF BTS1.fkt_inh.Adr_Pst.PLZ IS NULL AND BTS1.prot.parameter LIKE '%opt_betreiber_postadresse=1%'  
      AND BTS1.Usc(iUSC).usecase IN ('ANL_BTR', 'AEND_POST_ADR_BETREI', 'KOR_POST_ADR_BETREI') THEN
        AddPlausiMsg('Die PLZ der Postadresse des Betreibers muss gefllt sein.');
      END IF;
    END IF; -- Ende Plausi Betreiber
      
    -- Plausi Betriebssttte
    IF pBTS = 1 THEN
  -- 10.04.2014 Plausi immer ausfhren laut DD  
  --  IF EmptyID(BTS1.prot.d0101_id) THEN -- ID nicht vergeben
  --    vOK := 0;
  --  ELSE
  --    SELECT COUNT(*) INTO vOK  -- darf noch nicht vorhanden sein
  --    FROM vis_d0101 WHERE id = BTS1.prot.d0101_id;  
  --  END IF;
  --  IF vOK = 0 THEN  
      -- Betriebssttte Standortadresse, gilt nicht bei "wechselndem Standort"
      -- 0 : Standard
      -- 1 : wechselnd
      -- 2 : Freitext   
      IF NVL(LENGTH(BTS1.Adr_Sto.GKZ ), 0) < 8 
      AND BTS1.prot.parameter LIKE '%Mode=BS%'
      AND BTS1.prot.parameter LIKE '%opt_betrieb_adresse=0%' 
      AND BTS1.Usc(iUSC).usecase IN ('ANL_BTR', 'AEND_STANDORT_BTR', 'KOR_STANDORT_BTR' ) THEN
        AddPlausiMsg('Die Gemeinde der Standortadresse der Betriebssttte muss gefllt sein.');
      END IF;

      -- Betriebssttte Postadresse, gilt nicht fr "keine Postadresse"
      -- 0 - Postadresse = Sitzadresse
      -- 1 - abweichende 
      -- 2 - keine  
      IF BTS1.prot.parameter LIKE '%Mode=BS%' THEN 
      
        IF BTS1.prot.parameter LIKE '%opt_betrieb_postadresse=0%'  -- Postadresse = Standort
        AND BTS1.Adr_Sto.PLZ IS NULL 
        AND BTS1.Usc(iUSC).usecase IN ('ANL_BTR', 'AEND_STANDORT_BTR', 'KOR_STANDORT_BTR') THEN

         AddPlausiMsg('Die PLZ der Standortadresse der Betriebssttte muss gefllt sein.');
        
        ELSIF BTS1.prot.parameter LIKE '%opt_betrieb_postadresse=1%' -- abweichende Postadresse
        AND BTS1.Adr_Pst.PLZ IS NULL 
        AND BTS1.Usc(iUSC).usecase IN ('ANL_BTR', 'KOR_POST_ADR_BTR', 'AEND_POST_ADR_BTR') THEN           
         
         AddPlausiMsg('Die PLZ der Postadresse der Betriebssttte muss gefllt sein.');
        
        END IF;

        IF BTS1.bts.gueltig_von IS NULL 
        AND BTS1.Usc(iUSC).usecase IN ('ANL_BTR') THEN -- 13.06.2013
          AddPlausiMsg('Das Anmeldedatum der Betriebssttte muss gefllt sein.');
        END IF;    
             
      END IF;
    
      -- Betriebssttte Fachbereiche
      -- nur wenn auch eine Betriebssttte angelegt wurde (nicht nur der Betreiber ohne Betrieb)
      IF BTS1.FAB.COUNT = 0 AND BTS1.prot.parameter LIKE '%Mode=BS%' 
      AND BTS1.Usc(iUSC).usecase IN ('ANL_BTR') THEN
        AddPlausiMsg('Mindestens ein Fachbereich muss gesetzt sein.');
      END IF;
    
    END IF; -- Ende Plausi Betriebssttte  
  
  END LOOP;
  
END Plausi;  

-- Ausfhrung der Plausi incl. Daten lesen 
-- Rckgabe: Anzahl Fehler
--           bei -1 sind techn. Fehler aufgetreten
FUNCTION Plausi(pBTS_ID IN VARCHAR2) RETURN INTEGER AS 
vRes INTEGER := -1;
BEGIN
  IF Fill_BTS1(pBTS_ID) > 0 THEN
    Plausi(1, 1);
    vRes := vPlausiErrCnt;
  END IF; 
  RETURN vRes;
END Plausi;  

-- Ausfhrung der Plausi incl. Lesen der Daten
-- Rckgabe Anzahl Fehler und Fehlermeldungen
-- Bei techn. Fehlern ist pErrorCount = -1 
PROCEDURE Plausi(pBTS_ID IN VARCHAR2, pErrorCount OUT INTEGER, pMessage OUT NOCOPY CLOB) AS
BEGIN
  IF Plausi(pBTS_ID) >= 0 THEN
    pErrorCount := vPlausiErrCnt;
    pMessage := vPlausiMsg;
  ELSE
    pErrorCount := -1;
    pMessage := 'Fehler bei der Ausfhrung der Funktion';
  END IF;
END Plausi;  

-- Rckgabe der Plausi-Fehler der letzten Plausiprfung
FUNCTION PlausiMessage RETURN CLOB AS
BEGIN
  RETURN vPlausiMsg;
END PlausiMessage;  

-- Rckgabe Anzahl der Plausi-Fehler der letzten Plausiprfung
FUNCTION PlausiErrorCount RETURN INTEGER AS
BEGIN
  RETURN vPlausiErrCnt;
END PlausiErrorCount;  

FUNCTION UpdProtocol(pValues IN tPrt) RETURN INTEGER AS
  --vCnt INTEGER := 0;
  vProt tPrt := pValues;
BEGIN
  IF LENGTH(vProt.parameter) = 0 THEN
    vProt.parameter := NULL;
  END IF;
  
  UPDATE d_protokoll
  SET D0101_ID      = NVL(vProt.D0101_id, d0101_id)
    , STATUS        = NVL(vProt.status, status)
    , INS_DATE      = NVL(vProt.ins_date, ins_date)
    , USER_SID      = NVL(vProt.user_sid, user_sid)
    , LETZTE_AENDERUNG  = NVL(vProt.LETZTE_AENDERUNG, LETZTE_AENDERUNG)
    , MANDANT       = NVL(vProt.mandant, mandant)
    , DELETED       = NVL(vProt.deleted, deleted)
    , PARAMETER     = NVL(vProt.parameter, parameter)
    , DATENHERKUNFT = NVL(vProt.DATENHERKUNFT, DATENHERKUNFT)
    , upd_date      = SYSDATE
    , upd_user      = vUser_SID  
  WHERE BTS_ID = vProt.BTS_ID;
  
  --vCnt := SQL%ROWCOUNT;
  RETURN SQL%ROWCOUNT;
END;

-- Adresse aus D0101 in D_ADRESSE anlegen
-- pD0101_ID : vis_d0101.id
-- pTyp : 'S' Standortadresse, 'P' Postadresse
-- Ruckgabe D_ADRESSE.id
FUNCTION InsertAddressFromD0101(pD0101_ID IN VARCHAR2, pTyp IN VARCHAR2, pEmptyOK IN BOOLEAN) RETURN VARCHAR2 AS
vAdr D_ADRESSE%ROWTYPE;
vD0101 vis_d0101%ROWTYPE;
BEGIN
  vAdr.ID := NULL;
  
  --FOR cD0101 IN ( 
  SELECT * INTO vD0101 FROM vis_d0101 WHERE id = pD0101_ID;
  --) LOOP
  
    CASE
    -- Standort/Sitzadresse
    WHEN pTyp = 'S' AND 
    ((vD0101.ort || vD0101.plz || vD0101.strasse || vD0101.adresszusatz || vD0101.hausnr || vD0101.hausnrzusatz IS NOT NULL OR
     vD0101.rechtswert IS NOT NULL OR vD0101.hochwert IS NOT NULL OR 
     vD0101.x_wert IS NOT NULL OR vD0101.y_wert IS NOT NULL
    ) OR pEmptyOK ) 
     THEN
      vAdr.id := SYS_GUID();

      vAdr.TYP := Adr_STRASSE;  -- todo

      CASE vD0101.ambulant_jn
      WHEN 2 THEN  -- Freitext      
        vAdr.FreiText := vD0101.strasse;
        vAdr.TYP := Adr_Free;
      WHEN 1 THEN  -- wechselnder Standort
        --14.08.2014 vAdr.WECHSELNDER_STANDORT := vD0101.strasse;
        vAdr.strasse := vD0101.strasse;
        vAdr.TYP := Adr_WECHSELNDER_STANDORT;
      ELSE
        vAdr.STRASSE := vD0101.strasse;
      END CASE;     
        
      vAdr.gueltig_von  := NULL;
      vAdr.gueltig_bis  := NULL; 
      vAdr.ADRESSZUSATZ := vD0101.adresszusatz;
      --vAdr.BUNDESLAND :=  
      --vAdr.BEZIRK := 
      --vAdr.KREIS := 
      --vAdr.GEMEINDE := 
      vAdr.GKZ           := vD0101.gkz; 
      --vAdr.REGIONALSCHLUESSEL := 
      vAdr.Hausnummer := vD0101.hausnr; 
      vAdr.Hausnummernzusatz := vD0101.hausnrzusatz;
      vAdr.Postfach := NULL; -- Standort ist nie Postfach
     
      IF LENGTH(vD0101.land) > 3 OR vD0101.land IS NULL THEN
        vAdr.Staat := GetLandByA24_SID(vD0101.glo_a24_sid); -- entspricht a24.post
      ELSE
        vAdr.Staat := vD0101.land;       
      END IF;
    
      vAdr.PLZ           := vD0101.plz;
      vAdr.Ort           := vD0101.ort;
      vAdr.Ortsteil      := vD0101.ortsteil; 
      --vAdr.Teilort := vD0101.Teilort;  -- wird nicht verwendet
      vAdr.Flurnummer    := vD0101.flurnummer;
      vAdr.Flurstueck    := vD0101.flurstueck;
      vAdr.Gemarkung     := vD0101.gemarkung;
      vAdr.X_Wert        := vD0101.x_wert;
      vAdr.Y_Wert        := vD0101.y_wert;
      vAdr.Rechtswert    := vD0101.rechtswert;
      vAdr.Hochwert      := vD0101.hochwert;
      vAdr.Koordinatenherkunft := vD0101.gis_quelle;
      vAdr.S09_SID       := vD0101.s09_sid;
      vAdr.INS_DATE      := SYSDATE;
      vAdr.GLO_A24_SID   := vD0101.glo_a24_sid;
        
      INSERT INTO D_ADRESSE VALUES vAdr;
      
    -- Postadresse
    WHEN pTyp = 'P' AND ( vD0101.p_ort || vD0101.p_plz || vD0101.p_strasse IS NOT NULL OR pEmptyOK ) THEN
      vAdr.id := SYS_GUID();   
        
      vAdr.gueltig_von  := NULL;
      vAdr.gueltig_bis  := NULL; 
      vAdr.ADRESSZUSATZ := vD0101.adresszusatz;
      --vAdr.BUNDESLAND :=  
      --vAdr.BEZIRK := 
      --vAdr.KREIS := 
      --vAdr.GEMEINDE := 
      vAdr.GKZ := vD0101.gkz; 
      --vAdr.REGIONALSCHLUESSEL := 
      vAdr.Hausnummer := vD0101.p_hausnr; 
      vAdr.Hausnummernzusatz := vD0101.p_hausnrzusatz;

      IF vD0101.is_postfach = 1 THEN            
        vAdr.Postfach := vD0101.p_strasse; 
        vAdr.TYP := Adr_Postfach;  -- todo
      ELSE
        vAdr.STRASSE := vD0101.p_strasse; 
        vAdr.TYP := Adr_STRASSE;  -- todo
      END IF;
      
      IF LENGTH(vD0101.p_land) > 3 OR vD0101.p_land IS NULL THEN
        vAdr.Staat := GetLandByA24_SID(vD0101.glo_a24_sid2); -- entspricht a24.post
      ELSE
        vAdr.Staat := vD0101.p_land;     
      END IF;      
      
      vAdr.PLZ         := vD0101.p_plz;
      vAdr.Ort         := vD0101.p_ort;
      vAdr.Ortsteil    := vD0101.p_ortsteil; 
      vAdr.INS_DATE    := SYSDATE;
      vAdr.GLO_A24_SID := vD0101.glo_a24_sid2;
      vAdr.S09_SID     := vD0101.s09_sid;
      vAdr.postbezeichnung := vD0101.p_name1;
      
      INSERT INTO D_ADRESSE VALUES vAdr;
    ELSE NULL;

    END CASE;
  
  --END LOOP;  
  
  RETURN vAdr.id;

END;

-- Adresse aus D0102 in D_ADRESSE anlegen
-- pD0102_ID : vis_d0102.id
-- Rckgabe D_ADRESSE.id
FUNCTION InsertAddressFromD0102(pD0102_ID IN VARCHAR2) RETURN VARCHAR2 AS
vAdr D_ADRESSE%ROWTYPE;
vD0102 vis_d0102%ROWTYPE;
BEGIN
  vAdr.ID := NULL;
  
  SELECT d0102.* INTO vD0102 
  FROM vis_d0102 d0102 
  WHERE d0102.id = pD0102_ID;
    
  IF vD0102.ort || vD0102.plz || vD0102.strasse IS NOT NULL THEN
  
    vAdr.id := SYS_GUID();
    vAdr.STRASSE := vD0102.strasse;
        
    vAdr.gueltig_von := NULL;
    vAdr.gueltig_bis := NULL; 
    vAdr.TYP := Adr_STRASSE;  -- todo
    vAdr.ADRESSZUSATZ := NULL;
    --vAddr.BUNDESLAND :=  
    --vAddr.BEZIRK := 
    --vAddr.KREIS := 
    --vAddr.GEMEINDE := 
    vAdr.GKZ := vD0102.gkz; 
    --vAddr.REGIONALSCHLUESSEL := 
    vAdr.Hausnummer := vD0102.hausnr; 
    vAdr.Hausnummernzusatz := vD0102.hausnrzusatz;
    vAdr.Postfach := NULL; -- Standort ist nie Postfach
    
    IF LENGTH(vD0102.land) > 3 OR vD0102.land IS NULL THEN
      vAdr.Staat := GetLandByA24_SID(vDEFAULT_A24_SID); -- entspricht a24.post
    ELSE
      vAdr.Staat := vD0102.land;       
    END IF;
    
    vAdr.PLZ := vD0102.plz;
    vAdr.Ort := vD0102.ort;
    vAdr.Ortsteil := vD0102.ortsteil; 
    --vAddr.Teilort := c1.Teilort;  -- wird nicht verwendet
    vAdr.Flurnummer := NULL;
    vAdr.Flurstueck := NULL;
    vAdr.Gemarkung := NULL;
    vAdr.X_Wert := NULL;
    vAdr.Y_Wert := NULL;
    vAdr.Rechtswert := NULL;
    vAdr.Hochwert := NULL;
    vAdr.Koordinatenherkunft := NULL;
    vAdr.S09_SID := -1;
    vAdr.INS_DATE := SYSDATE;
    vAdr.GLO_A24_SID := vDEFAULT_A24_SID; -- immer D
        
    INSERT INTO D_ADRESSE VALUES vAdr;
      
  END IF;
  
  RETURN vAdr.id;
  
END;

-- Fachbereiche bernehmen
PROCEDURE InsertFAB(pBTS_ID IN VARCHAR2, pD0101_ID IN VARCHAR2) AS
vGuid VARCHAR2(32);
BEGIN
  FOR cD010104 IN (
    SELECT * FROM vis_d010104 d010104
    WHERE d010104.deleted = 0
      AND d010104.d0101_id = pD0101_ID
  ) LOOP
    
    vGUID := SYS_GUID();
    INSERT INTO d_fachbereich (
    ID, BTS_ID, CODE, A0101_06_SID, gueltig_von, gueltig_bis, D010104_ID, A0115_SID, A0101_01_SID, ERSTKONTROLLTERMIN, INS_DATE    
    ) VALUES  (
    vGUID, pBTS_ID, cD010104.fb, cD010104.a0101_06_sid, TRUNC(cD010104.gueltig_von), TRUNC(cD010104.gueltig_bis), cD010104.id, cD010104.a0115_sid, cD010104.a0101_01_sid, NULL, SYSDATE  
    );
    
  END LOOP;
END;

FUNCTION InsertPersonBetreiber(pD0101_ID IN VARCHAR2, pOwner_Prs_ID IN VARCHAR2, pOwner_Type IN VARCHAR2) RETURN VARCHAR2 AS
vPrs d_personal%ROWTYPE;
vD0101 vis_d0101%ROWTYPE;
vEU vis_a0101.feld1%TYPE;  -- 0 Kennzeichen Einzelunternehmen 
BEGIN
  vPrs.ID := NULL;
  IF pD0101_ID <> '-1' THEN
    
    SELECT d0101.* INTO vD0101 
    FROM vis_d0101 d0101
    WHERE d0101.id = pD0101_ID;

     
    vPrs.ID := SYS_GUID();
    vPrs.Adr_STZ_ID := InsertAddressFromD0101(vD0101.id, 'S', True); -- Sitzadresse
    IF vD0101.abw_post = 1 THEN
      vPrs.Adr_Pst_ID := InsertAddressFromD0101(vD0101.id, 'P', True); -- Postadresse
    ELSE
      vPrs.Adr_Pst_ID := vPrs.Adr_STZ_ID;
    END IF; 
    
    vPrs.OWNER_PRS_ID := pOwner_Prs_ID; 
    vPrs.OWNER_TYPE := pOwner_Type; 
    vPrs.KURZBEZEICHNUNG1 := vD0101.hit_bez_1; 
    vPrs.KURZBEZEICHNUNG2 := vD0101.hit_bez_2; 
    vPrs.TYP := CASE WHEN vD0101.bez_art = 'F' THEN vTypeJP ELSE vTypeNP END; 
    
    SELECT ax.feld1, ax.code INTO vEU, vPrs.RECHTSFORM
    FROM vis_a0101 ax WHERE ax.sid = vD0101.a0101_03_sid;  -- todo aktuelle Rechtsform aus BEA verwenden 

    IF vEU = '0' THEN -- bei Einzelunternehmen Namen vom Inhaber ermitteln
      
      BEGIN
        SELECT d0102.anrede, d0102.titel, d0102.vname, d0102.nname, d0102.nachsatz_nname, d0102.vorsatz_nname, D0102.GEB_ORT, d0102.geb_datum, d0102.bem
        INTO vPrs.anrede, vPrs.titel, vPrs.vorname, vPrs.nachname, vPrs.nachsatz_nachname, vPrs.vorsatz_nachname, vPrs.geburtsort, vPrs.geburtsdatum, vPrs.bemerkung
        FROM vis_d010200 d010200
        JOIN vis_d0102 d0102 ON d0102.id = d010200.d0102_id
          AND d010200.d0101_id = vD0101.id
          AND d010200.deleted = 0
          AND d010200.inhaber = 1
          AND d0102.deleted = 0;
        EXCEPTION 
        WHEN NO_DATA_FOUND THEN AddErrMsg('Der Inhaber des Einzelunternehmen ist nicht vorhanden');
        WHEN TOO_MANY_ROWS THEN AddErrMsg('Es sind mehrere Inhaber des Einzelunternehmen vorhanden');
      END;
    ELSE
--      vPrs.Anrede := CASE WHEN vD0101.bez_art = 'F' 
--                          THEN NVL2(vD0101.f_anrede, vD0101.f_anrede, vD0101.anrede) 
--                          ELSE vD0101.anrede END;
      
      IF vD0101.bez_art = 'F'  THEN
        IF vD0101.f_anrede IS NOT NULL THEN
         vPrs.Anrede := vD0101.f_anrede;
        ELSE
          vPrs.Anrede := vD0101.anrede; 
        END IF;
      ELSE
        vPrs.Anrede := vD0101.anrede;
      END IF;
                                  
      vPrs.TITEL := vD0101.titel; 
      vPrs.VORNAME := vD0101.vname; 
      vPrs.NACHNAME := vD0101.nname; 
      vPrs.VORSATZ_nachname := vD0101.vorsatz_nname; 
      vPrs.NACHSATZ_NACHNAME := vD0101.nachsatz_nname;
      vPrs.Geburtsdatum := NULL; 
      vPrs.Geburtsort := NULL; 

    END IF;
    vPrs.BEZEICHNUNG := vD0101.bez; 
    vPrs.BEZEICHNUNG2 := vD0101.Name1; 
    vPrs.bemerkung  := vD0101.bem;
     
    vPrs.PERS_ID := NULL; 
    vPrs.REF_ID := vD0101.ID; 
 
    vPrs.A0101_03_SID := vD0101.a0101_03_sid; 
    vPrs.A0101_70_SID := NULL;  
    vPrs.INS_DATE := SYSDATE; 
    vPrs.Telefon := vD0101.kom_tel; 
    vPrs.FAX := vD0101.kom_fax; 
    vPrs.Internet := vD0101.kom_internet; 
    vPrs.Mobil := vD0101.kom_mobil; 
    vPrs.EMAIL := vD0101.kom_email; 
    vPrs.weitere := vD0101.kom_sonst;
  
    INSERT INTO d_personal VALUES vPrs;
    
  END IF;
  RETURN vPrs.ID;
END;

PROCEDURE InsertPersonBetreiberPersonal(pD0101_ID IN VARCHAR2, pPrs_ID IN VARCHAR2, pBTS_ID IN VARCHAR2, pD010200_ID2 IN VARCHAR2) AS 
vPrs d_personal%ROWTYPE;
vGuid VARCHAR2(32);
BEGIN

  FOR cD0102 IN (
    SELECT d0102.id d0102_id
    , d0102.anrede
    , d0102.titel
    , d0102.nname
    , d0102.vname
    , D0102.NACHSATZ_nname
    , D0102.VORSATZ_nname
    , d0102.pers_id
    , d010200.bem
    , d0102.bez
    --, d010200.HAUPTANSPRECHPARTNER
    , d010200.id d010200_id
    , d010200.kom_tel, d010200.kom_fax, d010200.kom_mobil, d010200.kom_internet, d010200.kom_email, d010200.kom_sonst
    FROM vis_d010200 d010200, vis_d0102 d0102
    WHERE d0102.id = d010200.d0102_id
     AND d0102.deleted = 0 AND d010200.deleted = 0
     AND d010200.d0101_id = pD0101_ID
  ) LOOP
  
    vPrs.ID := SYS_GUID();
    vPrs.Adr_STZ_ID := NULL; 
    vPrs.Adr_Pst_ID := InsertAddressFromD0102(cD0102.d0102_id); -- Postadresse

    vPrs.OWNER_PRS_ID := pPrs_ID; 
    vPrs.OWNER_TYPE := Personal; 
    vPrs.KURZBEZEICHNUNG1 := NULL; 
    vPrs.KURZBEZEICHNUNG2 := NULL; 
    vPrs.TYP := vTypeNP; 
    vPrs.Anrede := cD0102.anrede; 
    vPrs.TITEL := cD0102.titel; 
    vPrs.VORNAME := cD0102.vname; 
    vPrs.NACHNAME := cD0102.nname; 
    vPrs.Geburtsdatum := NULL; 
    vPrs.Geburtsort := NULL; 
    vPrs.BEZEICHNUNG := cD0102.bez; 
    vPrs.BEZEICHNUNG2 := NULL; 
    vPrs.RECHTSFORM := NULL;
    vPrs.PERS_ID := cD0102.pers_id; 
    vPrs.REF_ID := cD0102.D010200_ID; 
    vPrs.VORSATZ_nachname := cD0102.vorsatz_nname; 
    vPrs.NACHSATZ_NACHNAME := cD0102.nachsatz_nname; 
    vPrs.HAUPTANSPRECHPARTNER_JN := CASE WHEN cD0102.D010200_ID = pD010200_ID2 THEN 1 ELSE 0 END;
    vPrs.A0101_03_SID := NULL; 
    vPrs.bemerkung := cD0102.bem;
    --96  Geschftsfhrer
    --62001  Inhaber
    --336001  Vorstandsvorsitzender
    --340001  Gesellschafter        
    SELECT MAX(d010202.a0101_70_SID) INTO vPrs.A0101_70_SID
    FROM vis_d010202 d010202
    WHERE d010202.d010200_id = cD0102.d010200_id
    AND d010202.deleted = 0
    AND d010202.a0101_70_sid IN ( 336001 , 340001, 62001, 96); 
    
    vPrs.INS_DATE := SYSDATE; 
    vPrs.Telefon := cD0102.kom_tel; 
    vPrs.FAX := cD0102.kom_fax; 
    vPrs.Internet := cD0102.kom_internet; 
    vPrs.Mobil := cD0102.kom_mobil; 
    vPrs.EMAIL := cD0102.kom_email; 
    vPrs.weitere := cD0102.kom_sonst;
  
    INSERT INTO d_personal VALUES vPrs;

    IF pBTS_ID <> '-1' THEN
      vGuid := SYS_GUID();
      INSERT INTO d_personalfunktion (
      ID,  TYP, PRS_ID, BTS_ID, gueltig_von, gueltig_bis, INS_DATE
      ) VALUES (
      vGUID, HV, vPrs.ID, pBTS_ID, NULL, NULL, SYSDATE
      );
    END IF;
  END LOOP; 
   
END;

PROCEDURE ParamsUpd(pCode IN VARCHAR2, pValue IN VARCHAR2) IS
vExists INTEGER := 0;
vParam tParams;
BEGIN

  IF vPrt_Params.COUNT() > 0 THEN
  
    FOR i IN vPrt_Params.FIRST .. vPrt_Params.LAST LOOP
      IF vPrt_Params(i).code = pCode THEN
        vPrt_Params(i).wert := pValue;
        vExists := 1;
        EXIT;
      END IF;
    END LOOP;
  
  END IF;
    
  IF vExists = 0 THEN
    vParam.wert := pValue;
    vParam.code := pCode;
    vPrt_Params.EXTEND();
    vPrt_Params(vPrt_Params.LAST) := vParam;  
  END IF;

END;

FUNCTION ParamsGet RETURN VARCHAR2 AS
res d_protokoll.parameter%TYPE := NULL;
BEGIN
  IF vPrt_Params.COUNT() > 0 THEN
    FOR i IN vPrt_Params.FIRST .. vPrt_Params.LAST LOOP
      res := res || vPrt_Params(i).code || '=' || vPrt_Params(i).wert || '!'; 
    END LOOP;
    res := RTRIM(res, '!');
  END IF;
    
  RETURN res;
END;

-- bertragen D0101 in Korb
-- Rckgabe D_BETRIEBSSTAETTE.id
FUNCTION TransferFromD0101(pD0101_ID IN VARCHAR2, pDATENHERKUNFT IN VARCHAR2, pUserSID IN INTEGER := -1, pMandantSID IN INTEGER := NULL, pLastUpdDate IN DATE := NULL ) RETURN VARCHAR2 AS
  vBTS_ID D_BETRIEBSSTAETTE.id%TYPE;
  --vMandantSID INTEGER;
  vbts_Adr_Sto_ID D_BETRIEBSSTAETTE.Adr_Sto_id%type; -- Standortadresse
  vbts_Adr_Pst_ID D_BETRIEBSSTAETTE.Adr_Pst_ID%type; -- Postadresse
  vbts_Adr_BTR_ID D_BETRIEBSSTAETTE.Adr_BTR_ID%type; -- Betreiberadresse
  vbts_Adr_Std_ID D_BETRIEBSSTAETTE.Adr_Std_ID%type; -- Standardadresse
  vPrs_ID d_personal.ID%TYPE;  
  vD010200_ID2 VARCHAR2(32 CHAR);
  vPrt_Parameter d_protokoll.parameter%TYPE;
  vSKZ vis_d0101.skz%TYPE;
  vD0101_ID3 vis_d0101.d0101_id3%TYPE;
  vGuid VARCHAR2(32);
  vSYSDATE DATE := SYSDATE;
BEGIN  

  SELECT skz, d0101_id3
  INTO vSKZ, vD0101_ID3
  FROM vis_d0101
  WHERE id = pD0101_ID;

  vUser_SID := pUserSID;
  
  -- Prfung ob Betrieb getrennt werden muss
  IF vSkz = 1 AND pD0101_ID = vD0101_ID3 AND vD0101_ID3 <> '-1' THEN
    blv_prepair_bea.SplitOperator(pD0101_ID);
  END IF;
  
  FOR cD0101 IN (                       
      SELECT d0101.id d0101_id 
        , d0101.skz d0101_skz
        , d0101.ambulant_jn d0101_ambulant_jn
        , d0101.mandant d0101_mandant        
        , CASE WHEN d0101.daten_herkunft = 'BEA' THEN d0101.name1 
          ELSE d0101.bez || CASE WHEN d0101.name1 IS NOT NULL THEN  ', ' || d0101.name1 END
          END d0101_name1
        , D0101.ABW_POST d0101_abw_post
        , TRUNC(d0101.anmeldung) d0101_anmeldung, TRUNC(d0101.abmeldung) d0101_abmeldung
        , D0101.KOM_TEL d0101_kom_tel, d0101.kom_fax d0101_kom_fax
        , D0101.KOM_INTERNET d0101_kom_internet, D0101.KOM_EMAIL d0101_kom_email
        , d0101.kom_mobil d0101_kom_mobil, D0101.KOM_SONST d0101_kom_sonst
        , d0101.d010200_id2 d0101_d010200_id2  
        , d0101$3.id d0101$3_id 
            
        , D0101.A0101_03_SID    D0101_A0101_03_SID
        , D0101$3.A0101_03_SID  D0101$3_A0101_03_SID  
        , d0101.zb              d0101_zb
        , d0101.gkz             d0101_gkz
        , d0101.glo_a24_sid     d0101_a24_sid
        , d0101.glo_a24_sid2    d0101_p_a24_sid     
        -- 30.10.2014: wenn Betreiber = -1 dann Daten von Betriebssttte bzw. Standardwerte verwenden    
        , CASE WHEN d0101.d0101_id3 = '-1' THEN d0101.zb ELSE d0101$3.zb END d0101$3_zb  
        , CASE WHEN d0101.d0101_id3 = '-1' THEN d0101.gkz ELSE d0101$3.gkz END d0101$3_gkz
        , CASE WHEN d0101.d0101_id3 = '-1' THEN -1 ELSE d0101$3.glo_a24_sid END d0101$3_a24_sid
        , CASE WHEN d0101.d0101_id3 = '-1' THEN -1 ELSE d0101$3.glo_a24_sid2 END d0101$3_p_a24_sid
        , d0101$3.d0101_id3     d0101$3_d0101_id3 
        , CASE WHEN d0101.d0101_id3 = '-1' THEN '-1' ELSE d0101$3.d010200_id2 END d0101$3_d010200_id2  
        , GREATEST( d0101.upd_date, NVL( d0101$3.upd_date, vDateMin) ) upd_date  -- todo 55866090: Betreiber kann -1 mit upd_date = null sein     
        , CASE WHEN d0101.d0101_id3 = '-1' THEN 0 ELSE D0101$3.ABW_POST END d0101$3_abw_post
      from vis_d0101 d0101
      -- 11.11.2014 nur bei SKZ = 1 abweichenden Betreiber verwenden
      join vis_d0101 d0101$3 on d0101$3.id =  CASE WHEN d0101.skz = 1  THEN d0101.d0101_id3 ELSE d0101.id END
      where d0101.id = pD0101_id
  ) LOOP
  
    vPrt_Params := tbParams();
    
    -- Mode=BS/BT   -- Betrieb / nur Betreiber
    IF cD0101.d0101_skz <> 1 THEN -- Betreiber 11.11.2014 war = 99
      ParamsUpd('Mode', 'BT'); -- nur Betreiber 
    ELSE
      ParamsUpd('Mode', 'BS');
    END IF;
    
    -- opt_betrieb_adresse=0/1/2  Standard / wechselnd / Frreitext
    ParamsUpd('opt_betrieb_adresse', cD0101.d0101_ambulant_jn);   
    
    -- opt_betrieb_postadresse=0/1/2  Postadresse = Sitzadresse / abweichende / Keine
    ParamsUpd('opt_betrieb_postadresse', cD0101.d0101_abw_post);   

    -- 'opt_betrieb_adresse_sitz'
    
    -- opt_betreiber=3/1/2  ohne Betreiber / Betreiber vorhanden / Betreiber anlegen
--    IF cD0101.d0101_id = cD0101.d0101$3_id OR cD0101.d0101$3_id = '-1' THEN
--      ParamsUpd('opt_betreiber', 0);
--    ELSE 
--      ParamsUpd('opt_betreiber', 1);
--    END IF; 

    CASE 
    WHEN cD0101.d0101$3_id = '-1' THEN  -- kein Betreiber vorhanden
      ParamsUpd('opt_betreiber', 3);
    WHEN cD0101.d0101_id <> cD0101.d0101$3_id THEN  -- abweichender Betreiber vorh.
      ParamsUpd('opt_betreiber', 1);
    ELSE
      ParamsUpd('opt_betreiber', 2); -- Betrieb = Betreiber -> Betreiber anlegen    
    END CASE; 
    
    -- chk_betreiber_kurzb=0!  nicht ausgewerten
    -- chk_betreiber_kurzb2=0! nicht ausgewertet

    -- opt_betreiber_postadresse=0/1  Betreiber abweichende Postadresse
    ParamsUpd('opt_betreiber_postadresse', cD0101.d0101$3_abw_post);
       
    --  opt_betreiber2_adressfilter_5_3=1!
    --  ActivePage=page5!MaxActivePage=page5!EnabledPages=;page1;page4;page5';
    
    vBTS_ID := SYS_GUID();
    vMandant_SID := NVL(pMandantSID, cD0101.d0101_mandant);
    
    -- Betriebssttte
    -- Standortadresse
    vbts_Adr_Sto_ID := InsertAddressFromD0101(cD0101.d0101_id, 'S', True);    
    -- Postadresse
    IF cD0101.d0101_abw_post = 1 THEN
      vbts_Adr_Pst_ID := InsertAddressFromD0101(cD0101.d0101_id, 'P', True);
    ELSE
      vbts_Adr_Pst_ID := vbts_Adr_Sto_ID;
    END IF;    
    
    INSERT INTO D_BETRIEBSSTAETTE ( id, BEZEICHNUNG, gueltig_von, gueltig_bis, d0101_id, zb, INS_DATE, 
      Telefon, fax, Internet, Mobil, email, weitere,
      Adr_Pst_ID, Adr_Sto_ID, Adr_BTR_ID, Adr_Std_ID
    ) VALUES
    ( vBTS_ID, cD0101.d0101_name1, cD0101.d0101_anmeldung, cD0101.d0101_abmeldung, cD0101.d0101_id, cD0101.d0101_zb, vSYSDATE,
      cD0101.d0101_kom_tel, cD0101.d0101_kom_fax, cD0101.d0101_kom_internet, cD0101.d0101_kom_mobil, cD0101.d0101_kom_email, cD0101.d0101_kom_sonst,
      vbts_Adr_Pst_ID, vbts_Adr_Sto_ID, vbts_Adr_BTR_ID, vbts_Adr_Std_ID 
    );

    -- Fachbereiche
    InsertFAB(vBTS_ID, cD0101.d0101_id);

    -- Betreiber
    vPrs_ID := InsertPersonBetreiber(cD0101.d0101$3_id, NULL, Betreiber);    
    IF vPrs_ID <> '-1' THEN    
      vGuid := SYS_GUID();
      INSERT INTO d_personalfunktion (
      ID, TYP, PRS_ID, BTS_ID, gueltig_von, gueltig_bis, INS_DATE
      ) VALUES (
      vGUID, Betreiber, vPrs_ID, vBTS_ID, NULL, NULL, vSYSDATE
      );
      
      -- Betreiber Personal
      InsertPersonBetreiberPersonal(cD0101.d0101$3_id, vPrs_ID, NULL, cD0101.d0101$3_d010200_id2 );
      
      -- Komplementr Betreiber    
      IF cD0101.d0101$3_d0101_id3 <> '-1' AND cD0101.d0101$3_d0101_id3 <> cD0101.d0101$3_ID THEN -- vorhanden
        vPrs_ID := InsertPersonBetreiber(cD0101.d0101$3_d0101_id3, vPrs_ID, Betreiber);
          
        SELECT d010200_id2 INTO vD010200_ID2 FROM vis_d0101 WHERE id = cD0101.d0101$3_d0101_id3;      
        
        -- Komplementr Betreiber - Personal
        InsertPersonBetreiberPersonal(cD0101.d0101$3_d0101_id3, vPrs_ID, NULL, vD010200_ID2);
        
      END IF;
    END IF;
        
    -- Protokoll anlegen
    vPrt_Parameter := ParamsGet();
    vGuid := SYS_GUID();
    INSERT INTO d_protokoll (ID, BTS_ID, D0101_ID, STATUS, INS_DATE, USER_SID, LETZTE_AENDERUNG, MANDANT, DATENHERKUNFT, PARAMETER, upd_date, upd_user)
    VALUES (vGUID, vBTS_ID, cD0101.d0101_ID, 1 /* nderung*/ , vSYSDATE, vUser_SID, NVL(pLastUpdDate, cD0101.upd_date), vMandant_SID, pDATENHERKUNFT, vPrt_Parameter, vSYSDATE, vUser_SID );
        
  END LOOP; 
  RETURN vBTS_ID;
END;

-- Betriebssttte Kommunikationsmittel
PROCEDURE KOM_BTR(pD0101_ID IN VARCHAR2) AS
vCnt INTEGER := 0; 
BEGIN

  UPDATE vis_d0101
    SET upd_user = vUser_SID
      , upd_date = SYSDATE
      , kom_tel = BTS1.bts.Telefon
      , kom_fax = BTS1.bts.fax
      , kom_email = BTS1.bts.email
      , kom_internet = BTS1.bts.Internet
      , kom_mobil = BTS1.bts.Mobil
      , kom_sonst = BTS1.bts.weitere
  WHERE id = pD0101_ID;
  
  vCnt := SQL%ROWCOUNT;
  IF vCnt <> 1 THEN
    AddErrMsg('Betriebssttte - Kommunikationsmittel wurden nicht gendert.');
  END IF;  

END;

-- Betreiber Kommunikationsmittel
PROCEDURE KOM_BETREI(pD0101_ID IN VARCHAR2) AS
vCnt INTEGER := 0; 
BEGIN

  UPDATE vis_d0101
    SET upd_user = vUser_SID
      , upd_date = SYSDATE
      , kom_tel = BTS1.fkt_inh.pers.Telefon
      , kom_fax = BTS1.fkt_inh.pers.fax
      , kom_email = BTS1.fkt_inh.pers.email
      , kom_internet = BTS1.fkt_inh.pers.Internet
      , kom_mobil = BTS1.fkt_inh.pers.Mobil
      , kom_sonst = BTS1.fkt_inh.pers.weitere
  WHERE id = pD0101_ID;
  
  vCnt := SQL%ROWCOUNT;
  IF vCnt <> 1 THEN
    AddErrMsg('Betreiber - Kommunikationsmittel wurden nicht gendert.');
  END IF;  

END;

-- Betriebssttte Zusatzbezeichnung
PROCEDURE Aend_Bez_BTR(pD0101_ID IN VARCHAR2) AS
vCnt INTEGER := 0; 
vSysdate DATE := SYSDATE;
BEGIN

  UPDATE vis_d0101
    SET upd_user = vUser_SID
      , upd_date = vSYSDATE
      , name1 = BTS1.bts.BEZEICHNUNG
      , p_name1 = CASE WHEN abw_post = 0 THEN BTS1.bts.BEZEICHNUNG ELSE p_name1 END -- 06.10.2014
  WHERE id = pD0101_ID;
  
  vCnt := SQL%ROWCOUNT;
  IF vCnt <> 1 THEN
    AddErrMsg('Betriebssttte - Zusatzbezeichnung wurde nicht gendert.');
  END IF;  

END;

-- Betriebssttte Standortadresse
PROCEDURE Aend_Standort_BTR(pD0101_ID IN VARCHAR2) AS
vCnt INTEGER := 0; 
vD0101 vis_d0101%ROWTYPE;
BEGIN

  IF BTS1.bts.Adr_Sto_ID <> '-1' THEN -- Standortadresse vorhanden
    SELECT * INTO vD0101 
    FROM vis_d0101 WHERE id = pD0101_ID;
    
    vD0101.Land := GetLandByA24_SID(vD0101.GLO_A24_SID); -- 05.08.2013 
    vD0101.plz          := BTS1.Adr_Sto.PLZ;
    vD0101.ort          := BTS1.Adr_Sto.Ort;      
    vD0101.ortsteil     := BTS1.Adr_Sto.Ortsteil;  
    vD0101.hausnr       := BTS1.Adr_Sto.Hausnummer;
    vD0101.hausnrzusatz := BTS1.Adr_Sto.Hausnummernzusatz; 
    vD0101.glo_a24_sid  := NVL(BTS1.Adr_Sto.glo_a24_sid, vDEFAULT_A24_SID);  

    --  opt_betrieb_adresse:
    --  0 : Standard
    --  1 : wechselnd
    --  2 : Freitext  
    IF BTS1.prot.parameter LIKE '%opt_betrieb_adresse=0%' -- Standard
    OR BTS1.prot.parameter LIKE '%opt_betrieb_adresse=2%' THEN -- Freitext

      IF BTS1.prot.parameter LIKE '%opt_betrieb_adresse=2%' THEN -- Freitext
        vD0101.strasse     := BTS1.Adr_Sto.FreiText;
      ELSE
        vD0101.strasse     := BTS1.Adr_Sto.STRASSE;    
      END IF;
    ELSIF BTS1.prot.parameter LIKE '%opt_betrieb_adresse=1%' THEN -- wechselnd
      --14.08.2014 IF BTS1.Adr_Sto.STRASSE IS NOT NULL THEN
        vD0101.strasse := BTS1.Adr_Sto.STRASSE;
      --14.08.2014 ELSE
      --14.08.2014   vD0101.strasse := SUBSTR(BTS1.Adr_Sto.wechselnder_standort, 1, 50);
      --14.08.2014 END IF;    

    END IF;
    -- BTS1.prot.parameter LIKE '%opt_betrieb_adresse=1%' THEN -- wechselnd
    
    vD0101.adresszusatz := BTS1.Adr_Sto.ADRESSZUSATZ;     

    vD0101.gkz         := BTS1.Adr_Sto.gkz;  
    vD0101.flurstueck  := BTS1.Adr_Sto.Flurstueck;
    vD0101.flurnummer  := BTS1.Adr_Sto.Flurnummer;
    vD0101.gemarkung   := BTS1.Adr_Sto.Gemarkung;
    vD0101.rechtswert  := BTS1.Adr_Sto.Rechtswert;
    vD0101.hochwert    := BTS1.Adr_Sto.Hochwert;
    vD0101.x_wert      := BTS1.Adr_Sto.X_Wert;
    vD0101.y_wert      := BTS1.Adr_Sto.Y_Wert;
    vD0101.gis_quelle  := BTS1.Adr_Sto.Koordinatenherkunft;
    vD0101.s09_sid     := NVL(BTS1.Adr_Sto.s09_sid, vDEFAULT_S09_SID);
    
    vD0101.ambulant_jn := CASE WHEN BTS1.prot.parameter LIKE '%opt_betrieb_adresse=1%' THEN 1
                               WHEN BTS1.prot.parameter LIKE '%opt_betrieb_adresse=2%' THEN 2
                               ELSE 0 
                          END;
                              
    IF BTS1.prot.parameter LIKE '%opt_betrieb_postadresse=0%' THEN
      -- keine Postanschrift vorhanden oder gleich
      -- Postanschrift wie Standort setzen
      BETR_POST_DEFA( vD0101 );
      vD0101.p_name1 := BTS1.bts.bezeichnung; -- 06.10.2014 todo 55600090
    ELSE 
      -- falls vorher keine abweichende Postanschrift vorhanden war, wird daurch
      -- die Postanschrift abweichend 
      vD0101.abw_post := 1;
    END IF;
      
    vD0101.upd_user := vUser_SID;
    vD0101.upd_date := SYSDATE;
    --27.11.2014
    IF bts1.bts.zb <> '%' THEN
      vD0101.zb := bts1.bts.zb; 
    END IF;
    UPDATE vis_d0101
      SET ROW = vD0101
    WHERE id = pD0101_ID;
    
    vCnt := SQL%ROWCOUNT;
    IF vCnt <> 1 THEN
      AddErrMsg('Betriebssttte - Standortadresse wurde nicht gendert.');
    END IF;
  ELSE
    AddErrMsg('Betriebssttte - Standortadresse ist nicht vorhanden.');    
  END IF;
  
END;

--Postanschrift Betriebssttte
PROCEDURE Aend_Post_Adr_Btr(pD0101_ID IN VARCHAR2) AS
vD0101 vis_d0101%ROWTYPE;
vCnt INTEGER := 0;
BEGIN
  -- Postadresse vorhanden
  -- oder Postanschrift wie Standort setzen
  IF BTS1.bts.Adr_Pst_ID <> '-1' 
  OR BTS1.prot.parameter LIKE '%opt_betrieb_postadresse=0%' THEN 
    SELECT * INTO vD0101 
    FROM vis_d0101 WHERE id = pD0101_ID;

    --Postanschrift
    --opt_betrieb_postadresse:
    --0 - Postadresse = Sitzadresse
    --1 - abweichende 
    --2 - keine  
    CASE
    WHEN BTS1.prot.parameter LIKE '%opt_betrieb_postadresse=1%' THEN
      -- abweichende Postanschrift
      BETR_POST_KOR(vD0101, BTS1.Adr_Pst);       
    WHEN BTS1.prot.parameter LIKE '%opt_betrieb_postadresse=2%' THEN
      -- Post an Betreiber
      -- wenn Betreiber keine abweichende Postadresse hat, dann Sitzadresse verwenden
      vD0101.D0101_ID2 := vD0101.D0101_ID3;
      BETR_POST_KOR_BETREI(vD0101);
             
--      IF BTS1.prot.parameter LIKE '%opt_betreiber_postadresse=0%' OR BTS1.fkt_inh.Adr_Pst.ID IS NULL THEN
--        BETR_POST_KOR(vD0101, BTS1.fkt_inh.Adr_Sto, NULL);       
--      ELSE  
--        BETR_POST_KOR(vD0101, BTS1.fkt_inh.Adr_Pst, NULL);       
--      END IF;
      
    WHEN BTS1.prot.parameter LIKE '%opt_betrieb_postadresse=0%' THEN
      -- Postanschrift wie Standort setzen
      BETR_POST_DEFA( vD0101 );
      --IF BTS1.Adr_Pst.id <> '-1' THEN -- 30.09.2014
      --  vD0101.p_name1 := BTS1.Adr_Pst.postbezeichnung;
      --END IF;
      vD0101.p_name1 := BTS1.bts.bezeichnung; -- 06.10.2014 todo 55600090
      -- 29.11.2013 vD0101.p_bez_art := 'F';  -- 20.03.2013 Post an Betrieb als Standard
    ELSE NULL;

    END CASE;

    vD0101.upd_user := vUser_SID;
    vD0101.upd_date := SYSDATE;
    
    UPDATE vis_d0101
      SET ROW = vD0101
    WHERE id = pD0101_ID;
    
    vCnt := SQL%ROWCOUNT;
    IF vCnt <> 1 THEN
      AddErrMsg('Betriebssttte - Postadresse wurde nicht gendert.');
    END IF;

  ELSE
    AddErrMsg('Betriebssttte - Postadresse ist nicht vorhanden.');    
  END IF;
END;

-- Sitzanschrift Betreiber
PROCEDURE Aend_Sitz_Adr_Betrei(pD0101_ID IN VARCHAR2) AS
vD0101 vis_d0101%ROWTYPE;
vCnt INTEGER := 0;
BEGIN
  
  IF BTS1.Fkt_Inh.Adr_Sto.ID <> '-1' THEN -- Sitzadresse vorhanden
    SELECT * INTO vD0101 
    FROM vis_d0101 WHERE id = pD0101_ID;
    
    vD0101.GLO_A24_SID  := BTS1.Fkt_Inh.Adr_Sto.glo_a24_sid;

    vD0101.LAND         := GetLandByA24_SID(vD0101.GLO_A24_SID);  
    vD0101.PLZ          := BTS1.Fkt_Inh.Adr_Sto.PLZ;
    vD0101.ORT          := BTS1.Fkt_Inh.Adr_Sto.Ort;
    vD0101.ORTSTEIL     := BTS1.Fkt_Inh.Adr_Sto.Ortsteil;
    vD0101.STRASSE      := BTS1.Fkt_Inh.Adr_Sto.STRASSE; 
    vD0101.HAUSNR       := BTS1.Fkt_Inh.Adr_Sto.Hausnummer;
    vD0101.hausnrzusatz := BTS1.Fkt_Inh.Adr_Sto.Hausnummernzusatz;
    vD0101.adresszusatz := BTS1.Fkt_Inh.Adr_Sto.ADRESSZUSATZ;
    vD0101.FLURSTUECK   := BTS1.Fkt_Inh.Adr_Sto.Flurstueck;
    vD0101.flurnummer   := BTS1.Fkt_Inh.Adr_Sto.Flurnummer;
    vD0101.GEMARKUNG    := BTS1.Fkt_Inh.Adr_Sto.Gemarkung;                          
    vD0101.GKZ          := BTS1.Fkt_Inh.Adr_Sto.gkz;   
    
    --Postanschrift
    if BTS1.prot.parameter LIKE '%opt_betreiber_postadresse=1%' THEN
      -- abweichende Postanschrift
      --BETR_POST_KOR(vD0101, pFKT_INH.Adr_Pst, NULL);
      vD0101.abw_post := 1;  -- knnte gendert worden sein, der Inhalt wird aber nicht angepasst 
    ELSE -- keine Postanschrift vorhanden, Postanschrift wie Standort setzen
      BETR_POST_DEFA( vD0101 );
      vD0101.p_name1 := bts1.fkt_inh.pers.bezeichnung2; -- 06.10.2014 todo 55600090
    END IF;    

    vD0101.HOCHWERT   := BTS1.Fkt_Inh.Adr_Sto.Hochwert;
    vD0101.RECHTSWERT := BTS1.Fkt_Inh.Adr_Sto.Rechtswert; 
    vD0101.X_WERT     := BTS1.Fkt_Inh.Adr_Sto.X_Wert; 
    vD0101.Y_WERT     := BTS1.Fkt_Inh.Adr_Sto.Y_Wert;
    vD0101.gis_quelle := BTS1.Fkt_Inh.Adr_Sto.Koordinatenherkunft;
    vD0101.s09_sid    := NVL(BTS1.Fkt_Inh.Adr_Sto.s09_sid, vDEFAULT_S09_SID);
    
    vD0101.Ambulant_jn:= 0;
         
    vD0101.upd_user := vUser_SID;
    vD0101.upd_date := SYSDATE;
    
    UPDATE vis_d0101
      SET ROW = vD0101
    WHERE id = pD0101_ID;
    
    vCnt := SQL%ROWCOUNT;
    IF vCnt <> 1 THEN
      AddErrMsg('Betreiber - Sitzadresse wurde nicht gendert.');
    END IF;
  ELSE
    AddErrMsg('Betreiber - Sitzadresse ist nicht vorhanden.');    
  END IF;
END;


-- Postanschrift Betreiber
PROCEDURE Aend_Post_Adr_Betrei(pD0101_ID IN VARCHAR2) AS
vD0101 vis_d0101%ROWTYPE;
vCnt INTEGER := 0;
BEGIN
  
  -- Postadresse vorhanden oder keine abw. Postadresse
  IF BTS1.Fkt_Inh.Adr_Pst.ID <> '-1' 
  OR BTS1.prot.parameter LIKE '%opt_betreiber_postadresse=0%' THEN 
    SELECT * INTO vD0101 
    FROM vis_d0101 WHERE id = pD0101_ID;

    -- abweichende Postadresse vorhanden
    IF BTS1.prot.parameter LIKE '%opt_betreiber_postadresse=1%' THEN
      BETR_POST_KOR(vD0101, BTS1.FKT_INH.Adr_Pst);
    ELSE -- keine abweichende Postadresse vorhanden
      BETR_POST_DEFA( vD0101 );
      vD0101.p_name1 := bts1.fkt_inh.pers.bezeichnung2; -- 06.10.2014 todo 55600090
    END IF; 
    vD0101.upd_user := vUser_SID;
    vD0101.upd_date := SYSDATE;
        
    UPDATE vis_d0101
      SET ROW = vD0101
    WHERE id = pD0101_ID;
    
    vCnt := SQL%ROWCOUNT;
    IF vCnt <> 1 THEN
      AddErrMsg('Betreiber - Postadresse wurde nicht gendert.');
    END IF;
  ELSE
    AddErrMsg('Betreiber - Postadresse ist nicht vorhanden.');    
  END IF;
END;


-- pD0101_ID2 aktuelle Betriebssttte, nur im Bereinigungsmodus gesetzt
PROCEDURE Run_Aend_Name_Betrei(pD0101 IN OUT NOCOPY vis_d0101%ROWTYPE, pfkt_inh IN tFnc, pD0101_ID2 IN vis_d0102.id%TYPE) AS
vD0102 vis_d0102%ROWTYPE;
vD010200 vis_d010200%ROWTYPE;
vCnt INTEGER := 0;
BEGIN

  IF pD0101.BEZ_ART = 'F' THEN 
      
    pD0101.TITEL   := pFKT_INH.pers.TITEL;
    pD0101.nname   := pFKT_INH.pers.NACHNAME;
    pD0101.vname   := pFKT_INH.pers.VORNAME;
    pD0101.vorsatz_nname  := pFkt_inh.pers.VORSATZ_nachname;
    pD0101.nachsatz_nname := pFkt_inh.pers.NACHSATZ_NACHNAME;

    IF pFKT_INH.PERS.TYP IN( vTypeJP, 'LP') THEN
      pD0101.F_ANREDE  := pFKT_INH.pers.Anrede;
      pD0101.ANREDE    := NULL; 
    ELSE
      pD0101.F_ANREDE  := NULL;      
      pD0101.ANREDE    := pFKT_INH.pers.Anrede; 
    END IF; 
    --todo 55445090 15.09.2014 nach unten verschoben, gilt immer pD0101.P_ANREDE    := pFKT_INH.pers.Anrede;
    --16.09.2014 nach unten verschoben pD0101.briefanrede := GetBriefanrede(pD0101.p_anrede);    
    pD0101.BEZ         := pFKT_INH.pers.BEZEICHNUNG;
    pD0101.P_NAME      := pFKT_INH.pers.BEZEICHNUNG;
    
    -- im Bereinigungsmodus Inhaber-Flag zurcksetzen damit Personal bearbeitbar wird
    IF pD0101_ID2 IS NOT NULL THEN
      UPDATE vis_d010200
      SET inhaber = 0
        , upd_date = SYSDATE
      WHERE inhaber = 1
      AND d0101_id = pD0101.id;      
    END IF;
    
  ELSIF pFKT_INH.pers.NACHNAME IS NOT NULL THEN
   
    pD0101.bez := CreateD0101Bez( pFKT_INH.pers.NACHNAME,
                                  pFKT_INH.pers.VORNAME, 
                                  pFKT_INH.pers.VORSATZ_nachname, 
                                  pFKT_INH.pers.NACHSATZ_NACHNAME,
                                  pFKT_INH.pers.TITEL); 
        
    BEGIN
    
      SELECT d010200.* INTO vD010200
      FROM vis_d010200 d010200
      WHERE d010200.deleted = 0
      AND d010200.inhaber = 1
      AND d010200.d0101_id = pD0101.id;

      SELECT * INTO vD0102
      FROM vis_d0102 WHERE id = vD010200.d0102_ID;
      
      vCnt := 1;      
      EXCEPTION WHEN NO_DATA_FOUND OR TOO_MANY_ROWS THEN 
        vCnt :=0; 
    END;
    
    IF vCnt = 0 AND pD0101_ID2 IS NOT NULL THEN -- Bereinigungsmodus
      -- vorhandenes Personal ber Namen prfen
      BEGIN
      
        SELECT d010200.* INTO vD010200
        FROM vis_d010200 d010200
        JOIN vis_d0102 d0102 ON d0102.id = d010200.d0102_id
        AND d010200.deleted = 0
        AND UPPER(REPLACE( d0102.nname || d0102.vname || 
                           D0102.VORSATZ_NNAME || D0102.NACHSATZ_NNAME || 
                           d0102.anrede || CHR(9), ' ')) =
           UPPER(REPLACE( pFKT_INH.pers.NACHNAME || pFKT_INH.pers.VORNAME ||  
                          pFKT_INH.pers.VORSATZ_nachname || pFKT_INH.pers.NACHSATZ_NACHNAME ||
                          pFKT_INH.pers.anrede || CHR(9), ' '))
        AND d010200.d0101_id = pD0101.id;

        SELECT * INTO vD0102
        FROM vis_d0102 WHERE id = vD010200.d0102_ID;
        
        vCnt := 1;      
        EXCEPTION WHEN NO_DATA_FOUND OR TOO_MANY_ROWS THEN 
          vCnt :=0; 
      END;
      
    END IF;

    IF vCnt = 0 THEN -- Personal nicht vorhanden -> anlegen
      SELECT * INTO vD010200 FROM vis_d010200 WHERE id = '-1';   
      SELECT * INTO vD0102 FROM vis_d0102 WHERE id = '-1';   

      vD0102.mandant := pD0101.mandant;
      vD0102.ins_user := vUser_SID;
      vD0102.ins_date := SYSDATE;
      vD0102.deleted := 0;
      vD0102.del_user := -1;
      vD0102.del_date := NULL;

      vD010200.mandant := pD0101.mandant;
      vD010200.ins_user := vUser_SID;
      vD010200.ins_date := SYSDATE;
 
      vD010200.deleted := 0;
      vD010200.del_user := -1;
      vD010200.del_date := NULL;
       
    END IF;
    
    vD0102.upd_user := vUser_SID;
    vD0102.upd_date := SYSDATE;
    vD0102.ANREDE         := pFKT_INH.pers.Anrede; 
    vD0102.TITEL          := pFKT_INH.pers.TITEL;
    vD0102.nname          := pFKT_INH.pers.NACHNAME;
    vD0102.vname          := pFKT_INH.pers.VORNAME;
    vD0102.vorsatz_nname  := pFkt_inh.pers.VORSATZ_nachname;
    vD0102.nachsatz_nname := pFkt_inh.pers.NACHSATZ_NACHNAME;
    vD0102.bez            := CreateD0102Bez( pFKT_INH.pers.Anrede, 
                                        pFKT_INH.pers.TITEL,
                                        pFKT_INH.pers.VORNAME,
                                        pFKT_INH.pers.NACHNAME,
                                        pFkt_inh.pers.VORSATZ_nachname,
                                        pFkt_inh.pers.NACHSATZ_NACHNAME);
    vD0102.bem := pFkt_inh.pers.bemerkung; 
    IF vD0102.id = '-1' THEN
      vD0102.id := SYS_GUID();
      INSERT INTO vis_d0102 VALUES vD0102;        
    ELSE        
      UPDATE vis_d0102 
      SET ROW = vD0102
      WHERE id = vD0102.ID;        
    END IF;

    vD010200.bez := vD0102.bez;
    vD010200.upd_user := vUser_SID;
    vD010200.upd_date := SYSDATE;
    vD010200.inhaber := 1;
                  
    IF vD010200.id = '-1' THEN
      vD010200.id := SYS_GUID();
      vD010200.d0102_id := vD0102.id;
      vD010200.d0101_id := pD0101.id;        
      
      vD010200.hauptansprechpartner := 1; 
        
      pD0101.d010200_id2 := vD010200.id; -- Hauptansprechpartner setzen  04.06.2014 bugfix d010200_id
        
      INSERT INTO vis_d010200 VALUES vD010200; 
        
      InsertD010202( pfkt_inh.pers.A0101_03_SID, pD0101.ID, vD010200.ID, pFKT_INH.pers.A0101_70_SID);
                   
    ELSE
      UPDATE vis_d010200 
      SET ROW = vD010200
      WHERE id = vD010200.ID;      
    END IF;  

    -- * 10.07.2014 verschoben nach unten   
        
    IF vD010200.ID = pD0101.d010200_id2 THEN
      pD0101.TITEL          := pFKT_INH.pers.TITEL;
      pD0101.ANREDE         := pFKT_INH.pers.Anrede; 
      pD0101.nname          := pFKT_INH.pers.NACHNAME;
      pD0101.vname          := pFKT_INH.pers.VORNAME;
      pD0101.vorsatz_nname  := pFkt_inh.pers.VORSATZ_nachname;
      pD0101.nachsatz_nname := pFkt_inh.pers.NACHSATZ_NACHNAME;   

      -- 18.04.2014
      -- 16.09.2014
--      pD0101.p_name := 
--        CreateD0101P_Name(pFKT_INH.pers.NACHNAME,
--                          pFKT_INH.pers.VORNAME, 
--                          pFKT_INH.pers.VORSATZ_nachname, 
--                          pFKT_INH.pers.NACHSATZ_NACHNAME,
--                          pFKT_INH.pers.TITEL);         
                   
    END IF;

    -- 16.09.2014
      pD0101.p_name := 
        CreateD0101P_Name(pFKT_INH.pers.NACHNAME,
                          pFKT_INH.pers.VORNAME, 
                          pFKT_INH.pers.VORSATZ_nachname, 
                          pFKT_INH.pers.NACHSATZ_NACHNAME,
                          pFKT_INH.pers.TITEL);         
                   


    -- * 10.07.2014 von oben nach hier verschoben
    -- Aktualisierung Betriebssttten mit Hauptansprechpartner
     pD0101.briefanrede := GetBriefanrede(pD0101.p_anrede); --16.09.2014
    UPDATE vis_d0101
    SET upd_date = SYSDATE
      , upd_user = vUser_SID
      , TITEL         = pFKT_INH.pers.TITEL
      , ANREDE        = pFKT_INH.pers.Anrede 
      , p_anrede      = pFKT_INH.pers.Anrede  -- 16.09.2014
      , f_anrede      = pFKT_INH.pers.Anrede  -- 16.09.2014
      , briefanrede   = pD0101.briefanrede  -- 16.09.2014
      , nname         = pFKT_INH.pers.NACHNAME
      , vname         = pFKT_INH.pers.VORNAME
      , vorsatz_nname = pFkt_inh.pers.VORSATZ_nachname
      , nachsatz_nname= pFkt_inh.pers.NACHSATZ_NACHNAME
      , bez           = pD0101.bez
      , p_name        = pD0101.p_name
    WHERE deleted = 0
    AND d010200_id2 = vD010200.id
    AND daten_herkunft = 'BEA'
    AND id <> pD0101.id;      
                                                          
  END IF;

        
  pD0101.BEZ_ART    := CrtD0101_BEZ_ART( pFKT_INH.pers.TYP, pFKT_INH.pers.a0101_03_sid);
  pD0101.P_BEZ_ART  := pD0101.BEZ_ART;
  pD0101.name1      := pFKT_INH.pers.BEZEICHNUNG2;  
  -- 10.07.2014 pD0101.P_name  := pFKT_INH.pers.BEZEICHNUNG;  
  --todo 55445090 15.09.2014 von oben nach hier, gilt immer 
  pD0101.P_ANREDE    := pFKT_INH.pers.Anrede;
  pD0101.F_ANREDE    := pFKT_INH.pers.Anrede;  --16.09.2014
  pD0101.briefanrede := GetBriefanrede(pD0101.p_anrede); --16.09.2014
    
  IF pD0101.abw_post = 0 THEN
    pD0101.P_name1 := pFKT_INH.pers.BEZEICHNUNG2;
  END IF;    
  --pD0101.P_NAME2      := pFKT_INH.pers.VORNAME;    
           
  pD0101.HIT_BEZ_1 := pFkt_inh.pers.KURZBEZEICHNUNG1; 
  pD0101.HIT_BEZ_2 := pFkt_inh.pers.KURZBEZEICHNUNG2;
  --pD0101.HIT_P_BEZ_1  := pFkt_inh.pers.KURZBEZEICHNUNG1;
  --pD0101.HIT_P_BEZ_2  := pFkt_inh.pers.KURZBEZEICHNUNG2;

  pD0101.upd_user := vUser_SID;
  pD0101.upd_date := SYSDATE;
    
END;

-- ndern BEZEICHNUNG des Betreibers
-- pD0101_ID2 aktuelle Betriebssttte - ist noch nicht BEA, nur im Bereinigungsmodus gesetzt
PROCEDURE Aend_Name_Betrei(pD0101_ID IN VARCHAR2, pD0101_ID2 IN VARCHAR2) AS
vD0101 vis_d0101%ROWTYPE;
--vCnt INTEGER := 0;
BEGIN
  
  IF BTS1.Fkt_Inh.PERS.ID <> '-1' THEN -- Betreiber vorhanden
    SELECT * INTO vD0101 
    FROM vis_d0101 WHERE id = pD0101_ID;

    Run_Aend_Name_Betrei(vD0101, BTS1.Fkt_Inh, pD0101_ID2);
    vD0101.upd_date := SYSDATE;
        
    UPDATE vis_d0101
      SET ROW = vD0101
    WHERE id = pD0101_ID;
    
    IF SQL%ROWCOUNT = 1 THEN

      -- Update Betriebssttten     
      UPDATE vis_d0101
      SET bez = vD0101.bez
        , p_name = vD0101.p_name
        , p_anrede = vD0101.p_anrede  -- 16.09.2014
        , f_anrede = vD0101.p_anrede  -- 16.09.2014
        , briefanrede = vD0101.briefanrede -- 16.09.2014
        , upd_date = SYSDATE
        , upd_user = vUser_SID
        , HIT_BEZ_1 = vD0101.HIT_BEZ_1
        , HIT_BEZ_2 = vD0101.HIT_BEZ_2
      WHERE d0101_id3 = pD0101_id
      AND deleted = 0
      AND skz = 1 -- 12.05.2014 in Absprache mit DD - Betreiber drfen nicht angepasst werden
      AND (daten_herkunft = 'BEA' OR ID = pD0101_ID2);
      
    ELSE
      AddErrMsg('Betreiber wurde nicht gendert.');
    END IF;
  ELSE
    AddErrMsg('Betreiber ist nicht vorhanden.');    
  END IF;
END;

-- ndern Rechtsform des Betreibers
-- pBez_art = 1 : bez_art neu bestimmen und in allen Betriebssttten aktualisieren 
PROCEDURE Aend_Rechtsform(pD0101_ID IN VARCHAR2, pD0101_ID2 IN VARCHAR2, pBez_art IN INTEGER) AS
--vCnt INTEGER;
vBez_art VARCHAR2(1);
BEGIN
  
  IF BTS1.Fkt_Inh.PERS.A0101_03_SID > -1 THEN -- Rechtsform vorhanden, lschen nicht mglich

    IF pBez_art = 1 THEN
      vBez_art := GetRechtsformTyp(BTS1.Fkt_Inh.PERS.A0101_03_SID);
      
      UPDATE vis_d0101
      SET a0101_03_sid = BTS1.Fkt_Inh.PERS.A0101_03_SID
        , bez_art = vBez_art
        , upd_date = SYSDATE
        , upd_user = vUser_SID
      WHERE id = pD0101_id
      AND a0101_03_sid <> BTS1.Fkt_Inh.PERS.A0101_03_SID;
     
      -- alle Betriebssttten aktualisieren
      UPDATE vis_d0101
      SET bez_art = vBez_art
        , upd_date = SYSDATE
        , upd_user = vUser_SID
      WHERE d0101_id3 = pD0101_id
      AND deleted = 0
      AND (daten_herkunft = 'BEA' OR ID = pD0101_ID2);   -- nur BEA oder aktualle Betriebsttte   
      
    ELSE

      UPDATE vis_d0101
      SET a0101_03_sid = BTS1.Fkt_Inh.PERS.A0101_03_SID
        , upd_date = SYSDATE
        , upd_user = vUser_SID
      WHERE id = pD0101_id
      AND a0101_03_sid <> BTS1.Fkt_Inh.PERS.A0101_03_SID;
      
    END IF;
--    vCnt := SQL%ROWCOUNT;
--    IF vCnt = 1 THEN
--      NULL;      
--    ELSE
--      AddErrMsg('Betreiber Rechtsform wurde nicht gendert.');
--    END IF;
  ELSE
    AddErrMsg('Betreiber Rechtsform kann nicht gelscht werden.');
  END IF;
END;

---- ndern des Betreibers einer Betriebssttte
--PROCEDURE Aend_Betrei( pD0101_ID vis_d0101.id%TYPE ) AS
--  vD0101_ID3_old vis_d0101.d0101_id3%TYPE;
--  vCnt INTEGER;
--  vBez vis_d0101.bez%TYPE;
--  vDate DATE := SYSDATE;
--  vDate2 DATE := TRUNC(vDate);
--BEGIN
--
--  SELECT d0101_id3 INTO vD0101_id3_old
--  FROM vis_d0101
--  WHERE id = pD0101_ID;
--  
--  -- alte Betreiber noch weitere Betriebe
--  SELECT COUNT(*) INTO vCnt
--  FROM vis_d0101 d3 
--  WHERE d3.d0101_id3 = vD0101_id3_old
--  AND d3.id <> d3.d0101_id3 -- Betreiber ausschlieen
--  AND d3.id <> pD0101_id -- nicht die gleiche Betriebssttte
--  AND d3.deleted = 0;
--  
--  IF vCnt = 0 THEN -- Betreiber abmelden, wenn keine Betriebssttten vorhanden
--    UPDATE vis_d0101
--    SET abmeldung = vDate2
--      , upd_date = vDate
--      , upd_user = vUser_SID
--    WHERE id = vD0101_id3_old;
--  END IF; 
--  
--  -- neuer Betreiber Abmeldung lschen
--  IF BTS1.fkt_inh.pers.ref_id <> '-1' THEN
--    -- vorhandene Abmeldung lschen
--    UPDATE vis_d0101
--    SET abmeldung = NULL
--      -- 26.05.2014
--      --, upd_date = CASE WHEN abmeldung IS NULL THEN upd_date ELSE  SYSDATE END
--      --, upd_user = CASE WHEN abmeldung IS NULL THEN upd_user ELSE vUser_SID END
--      , upd_date = SYSDATE
--      , upd_user = vUser_SID
--    WHERE id = BTS1.fkt_inh.pers.ref_id
--    RETURN bez INTO vBez;
--    
--    IF SQL%ROWCOUNT = 1 THEN
--      -- neuen Betreiber zuordnen
--      -- vom Betreiber bernehmen: bez, d010200_id2
--      UPDATE vis_d0101
--      SET d0101_id3 = BTS1.fkt_inh.pers.ref_id
--        , upd_date = SYSDATE
--        , upd_user = vUser_SID
--        , (bez, d010200_id2) = ( SELECT d3.bez, d3.d010200_id2 FROM vis_d0101 d3 WHERE d3.id = BTS1.fkt_inh.pers.ref_id)    
--      WHERE id = pD0101_ID;
--    ELSE
--      AddErrMsg('Der neue Betreiber mit der ID ' || BTS1.fkt_inh.pers.ref_id || ' wurde nicht gefunden.');
--    END IF;  
--  ELSE
--    AddErrMsg('Es ist kein neuer Betreiber vorhanden.');
--  END IF;
--
--END;

PROCEDURE AnlageD0308(pUsecase IN tUSC, pD0101_ID IN VARCHAR2) AS
TYPE t1 IS RECORD (
  id vis_d0101.id%TYPE,
  bez VARCHAR2(256 CHAR),
  zb vis_d0101.zb%TYPE,
  mandant vis_d0101.mandant%TYPE );
  
TYPE tb1 IS TABLE OF t1;
vD tb1;  
vD0308 vis_d0308%ROWTYPE;
vCnt INTEGER := 0;
vZB vis_d0101.zb%TYPE;
vText1 CONSTANT VARCHAR2(40) := 'betroffene Betriebssttten:';
BEGIN

  -- Initialisierung
  SELECT * INTO vD0308
  FROM vis_d0308 WHERE id = '-1';
  
  -- nur fr echte Betreiber
  -- alle Betriebssttten des Betreibers ermitteln
  -- Betriebssttten nach ZB zusammenfassen 
  -- und nur eine Meldung fr die 1.Betriebssttte erzeugen 
  -- mit Hinweis auf alle
  SELECT d0101.id
  , LTRIM(d0101.code || ' ') || d0101.bez || CASE WHEN d0101.name1 IS NOT NULL THEN ' / ' || d0101.name1 END bez
  , d0101.zb, d0101.mandant
  BULK COLLECT INTO vD
  FROM vis_d0101 d0101
  WHERE d0101.d0101_id3 = pD0101_ID
  AND d0101.deleted = 0
  AND d0101.skz = 1
  AND d0101.id <> pD0101_ID
  ORDER BY d0101.ZB, d0101.CODE, d0101.bez;            
  
  IF vD.COUNT > 0 THEN
    vD0308.a0307_sid := 1925001; -- Stammdaten
    vD0308.protokolldatum := SYSDATE;
    vD0308.ausfuehrender_id := vUser_SID;
    vD0308.triggeraction := 'U'; -- Update
    vD0308.ins_date := SYSDATE;
    vD0308.ins_user := vUser_SID;
    vD0308.upd_date := SYSDATE;
    vD0308.upd_user := vUser_SID; 
    vD0308.deleted  := 0;
    vD0308.del_date := NULL;
    vD0308.DEL_USER := -1;
    
    vD0308.ZB := vD(1).ZB;
    vD0308.d0101_id := vD(1).ID;
    vZB := vD(1).ZB;
    vD0308.mandant := vMandant_SID;
    vD0308.anzeigewerte := vText1;
    
    vD0308.ALTEWERTE := pUsecase.Alter_wert;
    vD0308.NEUEWERTE := pUsecase.neuer_wert;
    
    vD0308.ID := SYS_GUID();
    vCnt := 0;
        
    BEGIN
      SELECT bez INTO vD0308.bez
      FROM vis_a0101 
      WHERE skz = 502 AND deleted > -2
      AND code = pUsecase.usecase;
      
      EXCEPTION WHEN NO_DATA_FOUND OR TOO_MANY_ROWS THEN 
        vD0308.bez := pUsecase.usecase;
    END;
  
    FOR i IN vD.FIRST .. vD.LAST LOOP
     
      IF vZB <> vD(i).ZB THEN
        INSERT INTO vis_d0308 VALUES vD0308;
        
        vZB := vD(i).ZB;
        vD0308.anzeigewerte := vText1;
        vD0308.D0101_ID := vD(i).ID;
        vD0308.ZB := vD(i).ZB;
        vD0308.ID := SYS_GUID();
     
      END IF;      
      vD0308.anzeigewerte := vD0308.anzeigewerte || vCrLf || vD(i).bez;
      
      IF i = vD.Last THEN
        INSERT INTO vis_d0308 VALUES vD0308;        
      END IF;      
      
    END LOOP;
 
  END IF;
  
END;

-- Betreiber 2. Ordnung speichern
-- 
PROCEDURE SaveBTR2 AS
vD0101 vis_d0101%ROWTYPE;
vD0101_ID3 vis_d0101.d0101_id3%TYPE;
BEGIN

  IF EmptyID(BTS1.BTR2_BTR.ID) THEN  -- keine Daten zur Verabreitung vorhanden
    RETURN;
  END IF;
  IF EmptyID(BTS1.BTR2_BTR.REF_ID) THEN -- Betreiber anlegen
    vD0101_ID3 := AnlageBetreiber_Betreiber(1);    
  ELSE  -- Betreiber aktualisieren
    vD0101_ID3 := AnlageBetreiber_Betreiber(1);        
  END IF;
  
  IF Not EmptyID(vD0101_ID3) THEN -- dem Betreiber 1 zuordnen
    UPDATE vis_d0101
    SET betreiber_abw = 1
      , d0101_id3 = vD0101_ID3
      , upd_date = SYSDATE
    WHERE id = BTS1.FKT_INH.Pers.REF_ID
    AND d0101_id3 <> vD0101_ID3;
  END IF;
  
  vD0101 := NULL;
END;
PROCEDURE TransferToD0101(pBTS_ID IN VARCHAR2) AS 
  vValide_BEA INTEGER := 0;
  vCrtD0308 INTEGER := 0;  -- Meldung erzeugen
  vD0101_SKZ vis_d0101.skz%TYPE; 
  vD0101_Mandant vis_d0101.mandant%TYPE;
  vS07_wert vis_s0702.wert%TYPE;
  vChangeBTR INTEGER := 1;
  vChangeBTS INTEGER := 1;
  vMsgTrigger INTEGER := blv_sys.Get_EnabledMsgTrigger();
  PROCEDURE AddUsecase( pUsecase IN VARCHAR2, pD0101_ID IN VARCHAR2) AS
  vUsc tUsc;
  BEGIN
    vUsc.usecase := pUsecase;
    vUsc.d0101_id := pD0101_ID;
    BTS1.usc.EXTEND();
    BTS1.usc(bts1.usc.last) := vUsc;
  END;
BEGIN

  ClearErrMsg(); 

  SELECT prt.user_sid, prt.mandant 
  INTO vUser_sid, vMandant_SID
  FROM d_protokoll prt
  WHERE prt.BTS_ID = pBTS_ID; 
    
  vMandant_SID := NVL(vMandant_SID, -1);
  vUser_sid := NVL(vUser_SID, -1);
    
  IF Fill_BTS1(pBTS_ID) > 0 THEN
      
    IF BTS1.usc.COUNT = 0 THEN  -- Bereinigung

      blv_sys.Set_EnabledMsgTrigger(0); -- Meldungstrigger ausschalten
      
      IF BTS1.FKT_INH.Pers.REF_ID <> '-9999' THEN -- Betreiber zum Bearbeiten vorhanden
        -- Prfung Bearbeitungsrecht
        SELECT d0101.skz, d0101.mandant 
        , ( SELECT s07.wert
            FROM vis_vs07 s07
            WHERE s07.s07_code = 'OPTIONS'
            AND s07.s0701_code = 'BetreiberBearbeitenNurEigenerMandant'  
          ) s07_wert              
        INTO vD0101_skz, vD0101_mandant, vS07_wert
        FROM vis_d0101 d0101 
        WHERE d0101.id = BTS1.FKT_INH.Pers.REF_ID;        

        IF vD0101_skz = 1 OR (vD0101_mandant <> vMandant_SID AND vS07_wert = '1')
        THEN  -- keine Bearbeitung des Betreibers mglich
          vChangeBTR := 0;
        ELSE

          AddUsecase('KOR_RECHTSFORM', BTS1.FKT_INH.Pers.REF_ID); -- muss als 1. zum Betreiber laufen damit bez_art aktualisiert wird
          AddUsecase('AEND_NAME_BETREI', BTS1.FKT_INH.Pers.REF_ID);
          AddUsecase('AEND_KOM_BETREI', BTS1.FKT_INH.Pers.REF_ID);
          AddUsecase('AEND_SITZ_ADR', BTS1.FKT_INH.Pers.REF_ID);
          AddUsecase('AEND_POST_ADR_BETREI', BTS1.FKT_INH.Pers.REF_ID);
          vChangeBTR := 1;
        END IF;
      END IF;
        
      -- manuelle Bereinigung - Betrieb ist anschlieend valide
      vValide_BEA := 1;
      -- Unterscheidung Betrieb / Betreiber      
      IF BTS1.prot.d0101_id <> BTS1.FKT_INH.Pers.REF_ID THEN -- Betriebssttte zum Bearbeiten vorhanden
        AddUsecase('AEND_BEZ_BTR', BTS1.prot.d0101_id);
        AddUsecase('AEND_KOM_BTR', BTS1.prot.d0101_id);
        AddUsecase('AEND_STANDORT_BTR', BTS1.prot.d0101_id);
        AddUsecase('AEND_POST_ADR_BTR', BTS1.prot.d0101_id);
        vChangeBTS := 1;
      ELSE
        vChangeBTS := 0;
      END IF;
      
      
--      BTS1.usc.EXTEND(9);
--      BTS1.usc( 1).usecase := 'AEND_BEZ_BTR';
--      BTS1.usc( 2).usecase := 'AEND_KOM_BTR';
--      BTS1.usc( 3).usecase := 'AEND_STANDORT_BTR';
--      BTS1.usc( 4).usecase := 'AEND_POST_ADR_BTR';
--      BTS1.usc( 5).usecase := 'KOR_RECHTSFORM'; -- muss als 1. zum Betreiber laufen damit bez_art aktualisiert wird
--      BTS1.usc( 6).usecase := 'AEND_NAME_BETREI';
--      BTS1.usc( 7).usecase := 'AEND_KOM_BETREI';
--      BTS1.usc( 8).usecase := 'AEND_SITZ_ADR';
--      BTS1.usc( 9).usecase := 'AEND_POST_ADR_BETREI';
--        
--      FOR i IN 1 .. 4 LOOP  -- Betrieb  
--        BTS1.usc(i).d0101_id := BTS1.prot.d0101_id;
--      END LOOP;
--        
--      FOR i IN 5 .. 9 LOOP  -- Betreiber  
--        BTS1.usc(i).d0101_id := BTS1.FKT_INH.Pers.REF_ID;
--      END LOOP;

    END IF;
    
    vMandantZB := GetZBbyMandantSID(vMandant_SID);
    Plausi(vChangeBTS, vChangeBTR);
    IF vPlausiErrCnt = 0 THEN
    
      FOR iUsc IN BTS1.usc.FIRST .. BTS1.usc.LAST LOOP
        CASE BTS1.Usc(iUSC).usecase
          
        WHEN 'ANL_BTR' THEN        -- Neuanlage
          AnlageBetriebsstaette(); -- wird hier noch nicht genutzt
                      
        --WHEN 'AEND_BEZ_BTR'         THEN  -- Bezeichnung Betriebssttte
        --  null;
        WHEN 'AEND_BEZ_BTR'         THEN  -- Zusatzbezeichnung der Betriebssttte
          Aend_Bez_Btr( BTS1.Usc(iUSC).D0101_ID );
            
        WHEN 'KOR_BEZ_BTR'          THEN  -- KORREKTUR STANDORTBEZEICHNUNG BETRIEBSSTTTE
          Aend_Bez_Btr( BTS1.Usc(iUSC).D0101_ID );

        WHEN 'AEND_KOM_BTR'         THEN  -- ndern der Kommunikationsmittel der Betriebssttte
          Kom_Btr( BTS1.Usc(iUSC).D0101_ID );
        WHEN 'KOR_KOM_BTR'          THEN  -- KORREKTUR KOMMUNIKATIONSMITTEL BETRIEBSSTTTE        
          Kom_Btr( BTS1.Usc(iUSC).D0101_ID );
            
        WHEN 'AEND_STANDORT_BTR'    THEN  -- ndern der Standortadresse der Betriebssttte
          Aend_Standort_Btr( BTS1.Usc(iUSC).D0101_ID );
        WHEN 'KOR_STANDORT_BTR'     THEN  -- KORREKTUR STANDORTADRESSE BETRIEBSSTTTE
          Aend_Standort_Btr( BTS1.Usc(iUSC).D0101_ID );
          
        WHEN 'KOR_POST_ADR_BTR'     THEN  -- KORREKTUR POSTADRESSE BETRIEBSSTTTE
          Aend_Post_Adr_Btr( BTS1.Usc(iUSC).D0101_ID );
        WHEN 'AEND_POST_ADR_BTR'    THEN  -- NDERUNG POSTADRESSE BETRIEBSSTTTE
          Aend_Post_Adr_Btr( BTS1.Usc(iUSC).D0101_ID );
        ----------------------------------------------------------------------
        -- Betreiber    
        WHEN 'AEND_NAME_BETREI'     THEN  -- ndern des Namen des Betreibers
        
          IF vValide_BEA = 1 THEN
            Aend_Name_Betrei( BTS1.Usc(iUSC).D0101_ID, BTS1.prot.d0101_id  );    
          ELSE
            Aend_Name_Betrei( BTS1.Usc(iUSC).D0101_ID, NULL );              
          END IF;        
          vCrtD0308 := 1;
        WHEN 'KOR_NAME_BETREI'     THEN  -- ndern des Namen des Betreibers
          Aend_Name_Betrei( BTS1.Usc(iUSC).D0101_ID, NULL );
          vCrtD0308 := 1;
            
        --WHEN 'AEND_BETREI'          THEN  -- ndern des Betreibers einer Betriebssttte
        --  Aend_Betrei( BTS1.Usc(iUSC).D0101_ID ); -- Betreiberwechsel wird auerhalb des Package durchgefhrt

        WHEN 'AEND_KOM_BETREI'      THEN  -- ndern der Kommunikationsmittel des Betreibers
          Kom_Betrei( BTS1.Usc(iUSC).D0101_ID );
          vCrtD0308 := 1;
        WHEN 'KOR_KOM_BETREI'       THEN  -- KORREKTUR KOMMUNIKATIONSMITTEL BETREIBER
          Kom_Betrei( BTS1.Usc(iUSC).D0101_ID );
          vCrtD0308 := 1;

        WHEN 'AEND_SITZ_ADR'        THEN  -- NDEURNG SITZADRESSE BETREIBER
          Aend_Sitz_Adr_Betrei( BTS1.Usc(iUSC).D0101_ID );
          vCrtD0308 := 1;
        WHEN 'KOR_SITZ_ADR'         THEN  -- KORREKTUR SITZADRESSE BETREIBER
          Aend_Sitz_Adr_Betrei( BTS1.Usc(iUSC).D0101_ID );
          vCrtD0308 := 1;

        WHEN 'AEND_POST_ADR_BETREI' THEN  -- ndern der Postadresse des Betreibers
          Aend_Post_Adr_Betrei( BTS1.Usc(iUSC).D0101_ID );
          vCrtD0308 := 1;
        WHEN 'KOR_POST_ADR_BETREI'  THEN  -- KORREKTUR POSTADRESSE BETEIBER
          Aend_Post_Adr_Betrei( BTS1.Usc(iUSC).D0101_ID );
          vCrtD0308 := 1;
        WHEN 'KOR_RECHTSFORM'  THEN  -- ndern Rechtsform BETREIBER
          IF vValide_BEA = 1 THEN
            Aend_Rechtsform( BTS1.Usc(iUSC).D0101_ID, BTS1.prot.d0101_id, 1 );
          ELSE
            Aend_Rechtsform( BTS1.Usc(iUSC).D0101_ID, NULL, NULL );
          END IF;
          vCrtD0308 := 1;

        ELSE
          AddErrMsg('Usecase wird nicht untersttzt: ' || BTS1.Usc(iUSC).usecase);
        END CASE;

        IF vCrtD0308 = 1 AND vValide_BEA = 0 THEN
          AnlageD0308( BTS1.Usc(iUSC), BTS1.Usc(iUSC).D0101_ID );
          vCrtD0308 := 0;
        END IF;
                          
      END LOOP;

      -- manuelle Bereinigung
      IF vValide_BEA = 1 THEN
        
        IF vChangeBTS = 1 THEN
          -- DATEN_HERKUNFT BEA setzen
					-- Betreiber bearbeiten nicht mglich
					-- deshalb Daten vom Betreiber hier aktualisieren
          IF vChangeBTR = 0 THEN  

							UPDATE (
							SELECT d1.bez, d1.p_name, d1.p_anrede, d1.f_anrede, d1.briefanrede, d1.hit_bez_1, d1.hit_bez_2,
							 d3.bez bez_3, d3.p_name p_name_3, d3.p_anrede p_anrede_3, d3.f_anrede f_anrede_3, d3.briefanrede briefanrede_3, d3.hit_bez_1 hit_bez_1_3, d3.hit_bez_2 hit_bez_2_3
							FROM vis_d0101 d1
							JOIN vis_d0101 d3 ON d3.id = d1.d0101_id3 
							AND d3.daten_herkunft = 'BEA' 
							AND d1.id =  BTS1.prot.d0101_id)
							SET bez =         bez_3
								, p_name =      p_name_3
								, p_anrede =    p_anrede_3
								, f_anrede =    f_anrede_3
								, briefanrede = briefanrede_3 
								, hit_bez_1 =   hit_bez_1_3
								, hit_bez_2 =   hit_bez_2_3;

					END IF;
												
					UPDATE vis_d0101
					SET daten_herkunft = 'BEA'
						, upd_date = SYSDATE
						, d0101_id2 = d0101_id3 -- Post an Betreiber
					WHERE id IN (  BTS1.prot.d0101_id );
            
          -- WKD_BEA lschen
          --DELETE wkd_bea
          --WHERE d0101_id IN (  BTS1.prot.d0101_id );
          -- UPDATE wegen Replikation
          UPDATE wkd_bea 
          SET result = 1
            , upd_date = SYSDATE
          WHERE d0101_id IN (  BTS1.prot.d0101_id );
        END IF;

        IF vChangeBTR = 1 THEN
          -- DATEN_HERKUNFT BEA setzen
          UPDATE vis_d0101
          SET daten_herkunft = 'BEA'
            , upd_date = SYSDATE
          WHERE id IN ( BTS1.FKT_INH.Pers.REF_ID );

          -- WKD_BEA lschen
          --DELETE wkd_bea
          --WHERE d0101_id IN ( BTS1.FKT_INH.Pers.REF_ID, BTS1.BTR2_BTR.REF_ID ); -- BTR2_BTR 12.05.2014
          -- UPDATE wegen Replikation
          UPDATE wkd_bea 
          SET result = 1
            , upd_date = SYSDATE
          WHERE d0101_id IN ( BTS1.FKT_INH.Pers.REF_ID );
          
          -- Inhaber zurcksetzen wenn keine EinzelU
          UPDATE vis_d010200
          SET inhaber = 0
            , upd_date = SYSDATE
          WHERE inhaber <> 0
          AND d0101_id = BTS1.FKT_INH.Pers.REF_ID
          AND EXISTS(
            SELECT ax.sid 
            FROM vis_a0101 ax
            WHERE ax.sid = BTS1.FKT_INH.Pers.a0101_03_sid
            AND NVL( TRIM(ax.feld1), 'x') <> '0'); -- Feld1 = 0 -> EinzelU
           
          -- Betreiber-Betreiber Logik
          IF NOT EmptyID(BTS1.BTR2_BTR.ID) THEN
          
            SaveBTR2;
          
            UPDATE vis_d0101
            SET daten_herkunft = 'BEA'
              , upd_date = SYSDATE
            WHERE id IN ( BTS1.BTR2_BTR.REF_ID );
                      
            UPDATE wkd_bea 
            SET result = 1
              , upd_date = SYSDATE
            WHERE d0101_id IN ( BTS1.BTR2_BTR.REF_ID );
            
          END IF;   
          
          -- 21.10.2014 todo 55758090 - Neue Analyse der Betriebssttten
          FOR c1 IN (
            SELECT d0101.id
            FROM vis_d0101 d0101
            WHERE d0101.deleted = 0
            AND d0101.d0101_id3 = BTS1.FKT_INH.Pers.REF_ID
            AND d0101.id <> d0101.d0101_id3
            AND NVL(d0101.daten_herkunft, 'x') <> 'BEA' 
          ) LOOP
            IF blv_prepair_bea.CheckD0101(c1.id) > 0 THEN NULL; END IF;
          END LOOP;
                             
        END IF;
        
      END IF;
     
    END IF;
  END IF;
    
  Clear_bts(BTS1);
  blv_sys.Set_EnabledMsgTrigger(vMsgTrigger); -- alter Stand Meldungstrigger herstellen

END;

FUNCTION Version RETURN VARCHAR2 AS
BEGIN
  RETURN '1.23.000';
END;

BEGIN
  -- GKZ2 ermitteln
  SELECT S00.GKZ2 INTO vGKZ2 FROM vis_s00 s00; 
END blv_ein;
/

